Client

Struct Client 

pub struct Client { /* private fields */ }
Client for AWS DevOps Agent Service

Client for invoking operations on AWS DevOps Agent Service. Each operation on AWS DevOps Agent Service is a method on this this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.

Constructing a Client

A Config is required to construct a client. For most use cases, the aws-config crate should be used to automatically resolve this config using aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared across multiple different AWS SDK clients. This config resolution process can be customized by calling aws_config::from_env() instead, which returns a ConfigLoader that uses the builder pattern to customize the default config.

In the simplest case, creating a client looks as follows:

let config = aws_config::load_from_env().await;
let client = aws_sdk_devopsagent::Client::new(&config);

Occasionally, SDKs may have additional service-specific values that can be set on the Config that is absent from SdkConfig, or slightly different settings for a specific client may be desired. The Builder struct implements From<&SdkConfig>, so setting these specific settings can be done as follows:

let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_devopsagent::config::Builder::from(&sdk_config)
    .some_service_specific_setting("value")
    .build();

See the aws-config docs and Config for more information on customizing configuration.

Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.

Using the Client

A client has a function for every operation that can be performed by the service. For example, the AllowVendedLogDeliveryForResource operation has a Client::allow_vended_log_delivery_for_resource, function which returns a builder for that operation. The fluent builder ultimately has a send() function that returns an async future that returns a result, as illustrated below:

let result = client.allow_vended_log_delivery_for_resource()
    .resource_arn_being_authorized("example")
    .send()
    .await;

The underlying HTTP requests that get made by this can be modified with the customize_operation function on the fluent builder. See the customize module for more information.

Implementations

Source

impl Client

pub fn allow_vended_log_delivery_for_resource( &self, ) -> AllowVendedLogDeliveryForResourceFluentBuilder

Constructs a fluent builder for the AllowVendedLogDeliveryForResource operation.

Source

impl Client

pub fn associate_service(&self) -> AssociateServiceFluentBuilder

Constructs a fluent builder for the AssociateService operation.

Source

impl Client

pub fn create_agent_space(&self) -> CreateAgentSpaceFluentBuilder

Constructs a fluent builder for the CreateAgentSpace operation.

Source

impl Client

pub fn create_backlog_task(&self) -> CreateBacklogTaskFluentBuilder

Constructs a fluent builder for the CreateBacklogTask operation.

Source

impl Client

pub fn create_chat(&self) -> CreateChatFluentBuilder

Constructs a fluent builder for the CreateChat operation.

Source

impl Client

pub fn create_private_connection(&self) -> CreatePrivateConnectionFluentBuilder

Constructs a fluent builder for the CreatePrivateConnection operation.

Source

impl Client

pub fn delete_agent_space(&self) -> DeleteAgentSpaceFluentBuilder

Constructs a fluent builder for the DeleteAgentSpace operation.

Source

impl Client

pub fn delete_private_connection(&self) -> DeletePrivateConnectionFluentBuilder

Constructs a fluent builder for the DeletePrivateConnection operation.

Source

impl Client

pub fn deregister_service(&self) -> DeregisterServiceFluentBuilder

Constructs a fluent builder for the DeregisterService operation.

Source

impl Client

pub fn describe_private_connection( &self, ) -> DescribePrivateConnectionFluentBuilder

Constructs a fluent builder for the DescribePrivateConnection operation.

Source

impl Client

pub fn disable_operator_app(&self) -> DisableOperatorAppFluentBuilder

Constructs a fluent builder for the DisableOperatorApp operation.

Source

impl Client

pub fn disassociate_service(&self) -> DisassociateServiceFluentBuilder

Constructs a fluent builder for the DisassociateService operation.

Source

impl Client

pub fn enable_operator_app(&self) -> EnableOperatorAppFluentBuilder

Constructs a fluent builder for the EnableOperatorApp operation.

Source

impl Client

pub fn get_account_usage(&self) -> GetAccountUsageFluentBuilder

Constructs a fluent builder for the GetAccountUsage operation.

Source

impl Client

pub fn get_agent_space(&self) -> GetAgentSpaceFluentBuilder

Constructs a fluent builder for the GetAgentSpace operation.

Source

impl Client

pub fn get_association(&self) -> GetAssociationFluentBuilder

Constructs a fluent builder for the GetAssociation operation.

Source

impl Client

pub fn get_backlog_task(&self) -> GetBacklogTaskFluentBuilder

Constructs a fluent builder for the GetBacklogTask operation.

Source

impl Client

pub fn get_operator_app(&self) -> GetOperatorAppFluentBuilder

Constructs a fluent builder for the GetOperatorApp operation.

Source

impl Client

pub fn get_recommendation(&self) -> GetRecommendationFluentBuilder

Constructs a fluent builder for the GetRecommendation operation.

Source

impl Client

pub fn get_service(&self) -> GetServiceFluentBuilder

Constructs a fluent builder for the GetService operation.

Source

impl Client

pub fn list_agent_spaces(&self) -> ListAgentSpacesFluentBuilder

Constructs a fluent builder for the ListAgentSpaces operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_associations(&self) -> ListAssociationsFluentBuilder

Constructs a fluent builder for the ListAssociations operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_backlog_tasks(&self) -> ListBacklogTasksFluentBuilder

Constructs a fluent builder for the ListBacklogTasks operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_chats(&self) -> ListChatsFluentBuilder

Constructs a fluent builder for the ListChats operation.

Source

impl Client

pub fn list_executions(&self) -> ListExecutionsFluentBuilder

Constructs a fluent builder for the ListExecutions operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_goals(&self) -> ListGoalsFluentBuilder

Constructs a fluent builder for the ListGoals operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_journal_records(&self) -> ListJournalRecordsFluentBuilder

Constructs a fluent builder for the ListJournalRecords operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_pending_messages(&self) -> ListPendingMessagesFluentBuilder

Constructs a fluent builder for the ListPendingMessages operation.

Source

impl Client

pub fn list_private_connections(&self) -> ListPrivateConnectionsFluentBuilder

Constructs a fluent builder for the ListPrivateConnections operation.

Source

impl Client

pub fn list_recommendations(&self) -> ListRecommendationsFluentBuilder

Constructs a fluent builder for the ListRecommendations operation.

Source

impl Client

pub fn list_services(&self) -> ListServicesFluentBuilder

Constructs a fluent builder for the ListServices operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_tags_for_resource(&self) -> ListTagsForResourceFluentBuilder

Constructs a fluent builder for the ListTagsForResource operation.

Source

impl Client

pub fn list_webhooks(&self) -> ListWebhooksFluentBuilder

Constructs a fluent builder for the ListWebhooks operation.

Source

impl Client

pub fn register_service(&self) -> RegisterServiceFluentBuilder

Constructs a fluent builder for the RegisterService operation.

Source

impl Client

pub fn send_message(&self) -> SendMessageFluentBuilder

Constructs a fluent builder for the SendMessage operation.

Source

impl Client

pub fn tag_resource(&self) -> TagResourceFluentBuilder

Constructs a fluent builder for the TagResource operation.

Source

impl Client

pub fn untag_resource(&self) -> UntagResourceFluentBuilder

Constructs a fluent builder for the UntagResource operation.

Source

impl Client

pub fn update_agent_space(&self) -> UpdateAgentSpaceFluentBuilder

Constructs a fluent builder for the UpdateAgentSpace operation.

Source

impl Client

pub fn update_association(&self) -> UpdateAssociationFluentBuilder

Constructs a fluent builder for the UpdateAssociation operation.

Source

impl Client

pub fn update_backlog_task(&self) -> UpdateBacklogTaskFluentBuilder

Constructs a fluent builder for the UpdateBacklogTask operation.

Source

impl Client

pub fn update_goal(&self) -> UpdateGoalFluentBuilder

Constructs a fluent builder for the UpdateGoal operation.

Source

impl Client

pub fn update_operator_app_idp_config( &self, ) -> UpdateOperatorAppIdpConfigFluentBuilder

Constructs a fluent builder for the UpdateOperatorAppIdpConfig operation.

Source

impl Client

pub fn update_private_connection_certificate( &self, ) -> UpdatePrivateConnectionCertificateFluentBuilder

Constructs a fluent builder for the UpdatePrivateConnectionCertificate operation.

Source

impl Client

pub fn update_recommendation(&self) -> UpdateRecommendationFluentBuilder

Constructs a fluent builder for the UpdateRecommendation operation.

Source

impl Client

pub fn validate_aws_associations(&self) -> ValidateAwsAssociationsFluentBuilder

Constructs a fluent builder for the ValidateAwsAssociations operation.

Source

impl Client

pub fn from_conf(conf: Config) -> Self

Creates a new client from the service Config.

Panics

This method will panic in the following cases:

  • Retries or timeouts are enabled without a sleep_impl configured.
  • Identity caching is enabled without a sleep_impl and time_source configured.
  • No behavior_version is provided.

The panic message for each of these will have instructions on how to resolve them.

pub fn config(&self) -> &Config

Returns the client’s configuration.

Source

impl Client

pub fn new(sdk_config: &SdkConfig) -> Self

Creates a new client from an SDK Config.

Panics
  • This method will panic if the sdk_config is missing an async sleep implementation. If you experience this panic, set the sleep_impl on the Config passed into this function to fix it.
  • This method will panic if the sdk_config is missing an HTTP connector. If you experience this panic, set the http_connector on the Config passed into this function to fix it.
  • This method will panic if no BehaviorVersion is provided. If you experience this panic, set behavior_version on the Config or enable the behavior-version-latest Cargo feature.