RuntimePlugin

Trait RuntimePlugin 

pub trait RuntimePlugin:
    Debug
    + Send
    + Sync {
    // Provided methods
    fn order(&self) -> Order { ... }
    fn config(&self) -> Option<FrozenLayer> { ... }
    fn runtime_components(
        &self,
        current_components: &RuntimeComponentsBuilder,
    ) -> Cow<'_, RuntimeComponentsBuilder> { ... }
}
Runtime plugin trait

A RuntimePlugin is the unit of configuration for augmenting the client with new behavior.

Runtime plugins can register interceptors, set runtime components, and modify configuration.

Provided Methods

fn order(&self) -> Order

Runtime plugin ordering.

There are two runtime plugin “levels” that run in the following order:

  1. Service runtime plugins - runtime plugins that pertain to the entire service.
  2. Operation runtime plugins - runtime plugins relevant only to a single operation.

This function is used to determine runtime plugin order within those levels. So regardless of this Order value, service runtime plugins will still always execute before operation runtime plugins. However, Defaults service runtime plugins will run before Overrides service runtime plugins.

fn config(&self) -> Option<FrozenLayer>

Optionally returns additional config that should be added to the ConfigBag.

As a best practice, a frozen layer should be stored on the runtime plugin instance as a member, and then cloned upon return since that clone is cheap. Constructing a new Layer and freezing it will require a lot of allocations.

fn runtime_components( &self, current_components: &RuntimeComponentsBuilder, ) -> Cow<'_, RuntimeComponentsBuilder>

Returns a RuntimeComponentsBuilder to incorporate into the final runtime components.

The order of runtime plugins determines which runtime components “win”. Components set by later runtime plugins will override those set by earlier runtime plugins.

If no runtime component changes are desired, just return an empty builder.

This method returns a Cow for flexibility. Some implementers may want to store the components builder as a member and return a reference to it, while others may need to create the builder every call. If possible, returning a reference is preferred for performance.

Components configured by previous runtime plugins are in the current_components argument, and can be used to create nested/wrapped components, such as a connector calling into an inner (customer provided) connector.

Implementations on Foreign Types

Source

impl RuntimePlugin for PayloadSigningOverrideRuntimePlugin

Source

impl RuntimePlugin for NoAuthRuntimePluginV2

Source

impl RuntimePlugin for EnforceContentLengthRuntimePlugin

Source

impl RuntimePlugin for MetricsRuntimePlugin

Source

impl RuntimePlugin for CannedResponseDeserializer

Source

impl RuntimePlugin for CannedRequestSerializer

Implementors

Source

impl RuntimePlugin for AllowVendedLogDeliveryForResource

Source

impl RuntimePlugin for AssociateService

Source

impl RuntimePlugin for CreateAgentSpace

Source

impl RuntimePlugin for CreateBacklogTask

Source

impl RuntimePlugin for CreateChat

Source

impl RuntimePlugin for CreatePrivateConnection

Source

impl RuntimePlugin for DeleteAgentSpace

Source

impl RuntimePlugin for DeletePrivateConnection

Source

impl RuntimePlugin for DeregisterService

Source

impl RuntimePlugin for DescribePrivateConnection

Source

impl RuntimePlugin for DescribeSupportLevel

Source

impl RuntimePlugin for DisableOperatorApp

Source

impl RuntimePlugin for DisassociateService

Source

impl RuntimePlugin for EnableOperatorApp

Source

impl RuntimePlugin for EndChatForCase

Source

impl RuntimePlugin for GetAccountUsage

Source

impl RuntimePlugin for GetAgentSpace

Source

impl RuntimePlugin for GetAssociation

Source

impl RuntimePlugin for GetBacklogTask

Source

impl RuntimePlugin for GetOperatorApp

Source

impl RuntimePlugin for GetRecommendation

Source

impl RuntimePlugin for GetService

Source

impl RuntimePlugin for InitiateChatForCase

Source

impl RuntimePlugin for ListAgentSpaces

Source

impl RuntimePlugin for ListAssociations

Source

impl RuntimePlugin for ListBacklogTasks

Source

impl RuntimePlugin for ListChats

Source

impl RuntimePlugin for ListExecutions

Source

impl RuntimePlugin for ListGoals

Source

impl RuntimePlugin for ListJournalRecords

Source

impl RuntimePlugin for ListPendingMessages

Source

impl RuntimePlugin for ListPrivateConnections

Source

impl RuntimePlugin for ListRecommendations

Source

impl RuntimePlugin for ListServices

Source

impl RuntimePlugin for ListTagsForResource

Source

impl RuntimePlugin for ListWebhooks

Source

impl RuntimePlugin for RegisterService

Source

impl RuntimePlugin for SendMessage

Source

impl RuntimePlugin for TagResource

Source

impl RuntimePlugin for UntagResource

Source

impl RuntimePlugin for UpdateAgentSpace

Source

impl RuntimePlugin for UpdateAssociation

Source

impl RuntimePlugin for UpdateBacklogTask

Source

impl RuntimePlugin for UpdateGoal

Source

impl RuntimePlugin for UpdateOperatorAppIdpConfig

Source

impl RuntimePlugin for UpdatePrivateConnectionCertificate

Source

impl RuntimePlugin for UpdateRecommendation

Source

impl RuntimePlugin for ValidateAwsAssociations

Source

impl RuntimePlugin for StaticRuntimePlugin

Source

impl RuntimePlugin for SharedRuntimePlugin