Module associate_service

Module associate_service 

Types for the AssociateService operation.

Modules

builders
Builders

Structs

AssociateService
Orchestration and serialization glue logic for AssociateService.
AssociateServiceInput
Input for creating a new service association within an AgentSpace.
AssociateServiceOutput
Output containing the newly created association and optional webhook configuration.

Enums

AssociateServiceError
Error type for the AssociateServiceError operation.