pub struct AssociateServiceFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to AssociateService.
Adds a specific service association to an AgentSpace. It overwrites the existing association of the same service. Returns 201 Created on success.
Implementations
Sourceimpl AssociateServiceFluentBuilder
impl AssociateServiceFluentBuilder
Sourcepub fn as_input(&self) -> &AssociateServiceInputBuilder
pub fn as_input(&self) -> &AssociateServiceInputBuilder
Access the AssociateService as a reference.
Sourcepub async fn send(
self,
) -> Result<AssociateServiceOutput, SdkError<AssociateServiceError, HttpResponse>>
pub async fn send( self, ) -> Result<AssociateServiceOutput, SdkError<AssociateServiceError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<AssociateServiceOutput, AssociateServiceError, Self>
pub fn customize( self, ) -> CustomizableOperation<AssociateServiceOutput, AssociateServiceError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the AgentSpace
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the AgentSpace
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the AgentSpace
Sourcepub fn service_id(self, input: impl Into<String>) -> Self
pub fn service_id(self, input: impl Into<String>) -> Self
The unique identifier of the service.
Sourcepub fn set_service_id(self, input: Option<String>) -> Self
pub fn set_service_id(self, input: Option<String>) -> Self
The unique identifier of the service.
Sourcepub fn get_service_id(&self) -> &Option<String>
pub fn get_service_id(&self) -> &Option<String>
The unique identifier of the service.
Sourcepub fn configuration(self, input: ServiceConfiguration) -> Self
pub fn configuration(self, input: ServiceConfiguration) -> Self
The configuration that directs how AgentSpace interacts with the given service.
Sourcepub fn set_configuration(self, input: Option<ServiceConfiguration>) -> Self
pub fn set_configuration(self, input: Option<ServiceConfiguration>) -> Self
The configuration that directs how AgentSpace interacts with the given service.
Sourcepub fn get_configuration(&self) -> &Option<ServiceConfiguration>
pub fn get_configuration(&self) -> &Option<ServiceConfiguration>
The configuration that directs how AgentSpace interacts with the given service.