#[non_exhaustive]pub struct CreateAgentSpaceInputBuilder { /* private fields */ }Expand description
A builder for CreateAgentSpaceInput.
Implementations
Sourceimpl CreateAgentSpaceInputBuilder
impl CreateAgentSpaceInputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the AgentSpace. This field is required.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the AgentSpace.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the AgentSpace.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the AgentSpace.
Sourcepub fn locale(self, input: impl Into<String>) -> Self
pub fn locale(self, input: impl Into<String>) -> Self
The locale for the AgentSpace, which determines the language used in agent responses.
Sourcepub fn set_locale(self, input: Option<String>) -> Self
pub fn set_locale(self, input: Option<String>) -> Self
The locale for the AgentSpace, which determines the language used in agent responses.
Sourcepub fn get_locale(&self) -> &Option<String>
pub fn get_locale(&self) -> &Option<String>
The locale for the AgentSpace, which determines the language used in agent responses.
Sourcepub fn kms_key_arn(self, input: impl Into<String>) -> Self
pub fn kms_key_arn(self, input: impl Into<String>) -> Self
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn set_kms_key_arn(self, input: Option<String>) -> Self
pub fn set_kms_key_arn(self, input: Option<String>) -> Self
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn get_kms_key_arn(&self) -> &Option<String>
pub fn get_kms_key_arn(&self) -> &Option<String>
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
Client-provided token to ensure request idempotency. When the same token is provided in subsequent calls, the same response is returned within a 8-hour window.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
Client-provided token to ensure request idempotency. When the same token is provided in subsequent calls, the same response is returned within a 8-hour window.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
Client-provided token to ensure request idempotency. When the same token is provided in subsequent calls, the same response is returned within a 8-hour window.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
Tags to add to the AgentSpace at creation time.
Tags to add to the AgentSpace at creation time.
Tags to add to the AgentSpace at creation time.
Sourcepub fn build(self) -> Result<CreateAgentSpaceInput, BuildError>
pub fn build(self) -> Result<CreateAgentSpaceInput, BuildError>
Consumes the builder and constructs a CreateAgentSpaceInput.
Sourceimpl CreateAgentSpaceInputBuilder
impl CreateAgentSpaceInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateAgentSpaceOutput, SdkError<CreateAgentSpaceError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateAgentSpaceOutput, SdkError<CreateAgentSpaceError, HttpResponse>>
Sends a request with this input using the given client.