#[non_exhaustive]pub struct CreateAgentSpaceOutputBuilder { /* private fields */ }Expand description
A builder for CreateAgentSpaceOutput.
Implementations
Sourceimpl CreateAgentSpaceOutputBuilder
impl CreateAgentSpaceOutputBuilder
Sourcepub fn agent_space(self, input: AgentSpace) -> Self
pub fn agent_space(self, input: AgentSpace) -> Self
Represents a complete AgentSpace with all its properties, timestamps, encryption settings, and unique identifier. This field is required.
Sourcepub fn set_agent_space(self, input: Option<AgentSpace>) -> Self
pub fn set_agent_space(self, input: Option<AgentSpace>) -> Self
Represents a complete AgentSpace with all its properties, timestamps, encryption settings, and unique identifier.
Sourcepub fn get_agent_space(&self) -> &Option<AgentSpace>
pub fn get_agent_space(&self) -> &Option<AgentSpace>
Represents a complete AgentSpace with all its properties, timestamps, encryption settings, and unique identifier.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
Tags associated with the created AgentSpace.
Tags associated with the created AgentSpace.
Tags associated with the created AgentSpace.
Sourcepub fn build(self) -> CreateAgentSpaceOutput
pub fn build(self) -> CreateAgentSpaceOutput
Consumes the builder and constructs a CreateAgentSpaceOutput.