#[non_exhaustive]pub struct CreateAgentSpaceInput {
pub name: Option<String>,
pub description: Option<String>,
pub locale: Option<String>,
pub kms_key_arn: Option<String>,
pub client_token: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Expand description
Input for creating a new AgentSpace.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the AgentSpace.
description: Option<String>The description of the AgentSpace.
locale: Option<String>The locale for the AgentSpace, which determines the language used in agent responses.
kms_key_arn: Option<String>The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
client_token: Option<String>Client-provided token to ensure request idempotency. When the same token is provided in subsequent calls, the same response is returned within a 8-hour window.
Tags to add to the AgentSpace at creation time.
Implementations
Sourceimpl CreateAgentSpaceInput
impl CreateAgentSpaceInput
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the AgentSpace.
Sourcepub fn locale(&self) -> Option<&str>
pub fn locale(&self) -> Option<&str>
The locale for the AgentSpace, which determines the language used in agent responses.
Sourcepub fn kms_key_arn(&self) -> Option<&str>
pub fn kms_key_arn(&self) -> Option<&str>
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Client-provided token to ensure request idempotency. When the same token is provided in subsequent calls, the same response is returned within a 8-hour window.
Tags to add to the AgentSpace at creation time.
Sourceimpl CreateAgentSpaceInput
impl CreateAgentSpaceInput
Sourcepub fn builder() -> CreateAgentSpaceInputBuilder
pub fn builder() -> CreateAgentSpaceInputBuilder
Creates a new builder-style object to manufacture CreateAgentSpaceInput.