#[non_exhaustive]pub struct CreateAgentSpaceOutput {
pub agent_space: Option<AgentSpace>,
pub tags: Option<HashMap<String, String>>,
/* private fields */
}Expand description
Output containing the newly created AgentSpace.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space: Option<AgentSpace>Represents a complete AgentSpace with all its properties, timestamps, encryption settings, and unique identifier.
Tags associated with the created AgentSpace.
Implementations
Sourceimpl CreateAgentSpaceOutput
impl CreateAgentSpaceOutput
Sourcepub fn agent_space(&self) -> Option<&AgentSpace>
pub fn agent_space(&self) -> Option<&AgentSpace>
Represents a complete AgentSpace with all its properties, timestamps, encryption settings, and unique identifier.
Tags associated with the created AgentSpace.
Sourceimpl CreateAgentSpaceOutput
impl CreateAgentSpaceOutput
Sourcepub fn builder() -> CreateAgentSpaceOutputBuilder
pub fn builder() -> CreateAgentSpaceOutputBuilder
Creates a new builder-style object to manufacture CreateAgentSpaceOutput.