pub struct CreateAssetFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateAsset.
Creates a new asset in the specified agent space
Implementations
Sourceimpl CreateAssetFluentBuilder
impl CreateAssetFluentBuilder
Sourcepub fn as_input(&self) -> &CreateAssetInputBuilder
pub fn as_input(&self) -> &CreateAssetInputBuilder
Access the CreateAsset as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateAssetOutput, SdkError<CreateAssetError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateAssetOutput, SdkError<CreateAssetError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateAssetOutput, CreateAssetError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateAssetOutput, CreateAssetError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space where the asset will be created
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space where the asset will be created
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space where the asset will be created
Sourcepub fn asset_type(self, input: impl Into<String>) -> Self
pub fn asset_type(self, input: impl Into<String>) -> Self
The type of asset to create
Sourcepub fn set_asset_type(self, input: Option<String>) -> Self
pub fn set_asset_type(self, input: Option<String>) -> Self
The type of asset to create
Sourcepub fn get_asset_type(&self) -> &Option<String>
pub fn get_asset_type(&self) -> &Option<String>
The type of asset to create
Sourcepub fn set_metadata(self, input: Option<Document>) -> Self
pub fn set_metadata(self, input: Option<Document>) -> Self
The metadata describing this asset
Sourcepub fn get_metadata(&self) -> &Option<Document>
pub fn get_metadata(&self) -> &Option<Document>
The metadata describing this asset
Sourcepub fn content(self, input: AssetContent) -> Self
pub fn content(self, input: AssetContent) -> Self
The content for the asset. Provide a single file or a zip bundle.
Sourcepub fn set_content(self, input: Option<AssetContent>) -> Self
pub fn set_content(self, input: Option<AssetContent>) -> Self
The content for the asset. Provide a single file or a zip bundle.
Sourcepub fn get_content(&self) -> &Option<AssetContent>
pub fn get_content(&self) -> &Option<AssetContent>
The content for the asset. Provide a single file or a zip bundle.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier used for idempotent asset creation
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier used for idempotent asset creation
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier used for idempotent asset creation