#[non_exhaustive]pub struct CreateAssetInputBuilder { /* private fields */ }Expand description
A builder for CreateAssetInput.
Implementations
Sourceimpl CreateAssetInputBuilder
impl CreateAssetInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space where the asset will be created
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space where the asset will be created
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space where the asset will be created
Sourcepub fn asset_type(self, input: impl Into<String>) -> Self
pub fn asset_type(self, input: impl Into<String>) -> Self
The type of asset to create
This field is required.Sourcepub fn set_asset_type(self, input: Option<String>) -> Self
pub fn set_asset_type(self, input: Option<String>) -> Self
The type of asset to create
Sourcepub fn get_asset_type(&self) -> &Option<String>
pub fn get_asset_type(&self) -> &Option<String>
The type of asset to create
Sourcepub fn set_metadata(self, input: Option<Document>) -> Self
pub fn set_metadata(self, input: Option<Document>) -> Self
The metadata describing this asset
Sourcepub fn get_metadata(&self) -> &Option<Document>
pub fn get_metadata(&self) -> &Option<Document>
The metadata describing this asset
Sourcepub fn content(self, input: AssetContent) -> Self
pub fn content(self, input: AssetContent) -> Self
The content for the asset. Provide a single file or a zip bundle.
This field is required.Sourcepub fn set_content(self, input: Option<AssetContent>) -> Self
pub fn set_content(self, input: Option<AssetContent>) -> Self
The content for the asset. Provide a single file or a zip bundle.
Sourcepub fn get_content(&self) -> &Option<AssetContent>
pub fn get_content(&self) -> &Option<AssetContent>
The content for the asset. Provide a single file or a zip bundle.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier used for idempotent asset creation
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier used for idempotent asset creation
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier used for idempotent asset creation
Sourcepub fn build(self) -> Result<CreateAssetInput, BuildError>
pub fn build(self) -> Result<CreateAssetInput, BuildError>
Consumes the builder and constructs a CreateAssetInput.
Sourceimpl CreateAssetInputBuilder
impl CreateAssetInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateAssetOutput, SdkError<CreateAssetError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateAssetOutput, SdkError<CreateAssetError, HttpResponse>>
Sends a request with this input using the given client.