#[non_exhaustive]pub struct CreateAssetInput {
pub agent_space_id: Option<String>,
pub asset_type: Option<String>,
pub metadata: Option<Document>,
pub content: Option<AssetContent>,
pub client_token: Option<String>,
}Expand description
Request structure for creating a new asset
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier for the agent space where the asset will be created
asset_type: Option<String>The type of asset to create
metadata: Option<Document>The metadata describing this asset
content: Option<AssetContent>The content for the asset. Provide a single file or a zip bundle.
client_token: Option<String>A unique, case-sensitive identifier used for idempotent asset creation
Implementations
Sourceimpl CreateAssetInput
impl CreateAssetInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier for the agent space where the asset will be created
Sourcepub fn asset_type(&self) -> Option<&str>
pub fn asset_type(&self) -> Option<&str>
The type of asset to create
Sourcepub fn content(&self) -> Option<&AssetContent>
pub fn content(&self) -> Option<&AssetContent>
The content for the asset. Provide a single file or a zip bundle.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier used for idempotent asset creation
Sourceimpl CreateAssetInput
impl CreateAssetInput
Sourcepub fn builder() -> CreateAssetInputBuilder
pub fn builder() -> CreateAssetInputBuilder
Creates a new builder-style object to manufacture CreateAssetInput.