#[non_exhaustive]pub struct CreateAssetFileInputBuilder { /* private fields */ }Expand description
A builder for CreateAssetFileInput.
Implementations
Sourceimpl CreateAssetFileInputBuilder
impl CreateAssetFileInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space containing the asset
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space containing the asset
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space containing the asset
Sourcepub fn asset_id(self, input: impl Into<String>) -> Self
pub fn asset_id(self, input: impl Into<String>) -> Self
The unique identifier of the asset to create the file in
This field is required.Sourcepub fn set_asset_id(self, input: Option<String>) -> Self
pub fn set_asset_id(self, input: Option<String>) -> Self
The unique identifier of the asset to create the file in
Sourcepub fn get_asset_id(&self) -> &Option<String>
pub fn get_asset_id(&self) -> &Option<String>
The unique identifier of the asset to create the file in
Sourcepub fn path(self, input: impl Into<String>) -> Self
pub fn path(self, input: impl Into<String>) -> Self
The path of the file within the asset
This field is required.Sourcepub fn content(self, input: AssetFileBody) -> Self
pub fn content(self, input: AssetFileBody) -> Self
The content of the file to create
This field is required.Sourcepub fn set_content(self, input: Option<AssetFileBody>) -> Self
pub fn set_content(self, input: Option<AssetFileBody>) -> Self
The content of the file to create
Sourcepub fn get_content(&self) -> &Option<AssetFileBody>
pub fn get_content(&self) -> &Option<AssetFileBody>
The content of the file to create
Sourcepub fn set_metadata(self, input: Option<Document>) -> Self
pub fn set_metadata(self, input: Option<Document>) -> Self
Optional metadata describing this file
Sourcepub fn get_metadata(&self) -> &Option<Document>
pub fn get_metadata(&self) -> &Option<Document>
Optional metadata describing this file
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier used for idempotent asset file creation
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier used for idempotent asset file creation
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier used for idempotent asset file creation
Sourcepub fn build(self) -> Result<CreateAssetFileInput, BuildError>
pub fn build(self) -> Result<CreateAssetFileInput, BuildError>
Consumes the builder and constructs a CreateAssetFileInput.
Sourceimpl CreateAssetFileInputBuilder
impl CreateAssetFileInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateAssetFileOutput, SdkError<CreateAssetFileError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateAssetFileOutput, SdkError<CreateAssetFileError, HttpResponse>>
Sends a request with this input using the given client.