#[non_exhaustive]pub struct CreateAssetFileInput {
pub agent_space_id: Option<String>,
pub asset_id: Option<String>,
pub path: Option<String>,
pub content: Option<AssetFileBody>,
pub metadata: Option<Document>,
pub client_token: Option<String>,
}Expand description
Request structure for creating an asset file
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier for the agent space containing the asset
asset_id: Option<String>The unique identifier of the asset to create the file in
path: Option<String>The path of the file within the asset
content: Option<AssetFileBody>The content of the file to create
metadata: Option<Document>Optional metadata describing this file
client_token: Option<String>A unique, case-sensitive identifier used for idempotent asset file creation
Implementations
Sourceimpl CreateAssetFileInput
impl CreateAssetFileInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier for the agent space containing the asset
Sourcepub fn asset_id(&self) -> Option<&str>
pub fn asset_id(&self) -> Option<&str>
The unique identifier of the asset to create the file in
Sourcepub fn content(&self) -> Option<&AssetFileBody>
pub fn content(&self) -> Option<&AssetFileBody>
The content of the file to create
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier used for idempotent asset file creation
Sourceimpl CreateAssetFileInput
impl CreateAssetFileInput
Sourcepub fn builder() -> CreateAssetFileInputBuilder
pub fn builder() -> CreateAssetFileInputBuilder
Creates a new builder-style object to manufacture CreateAssetFileInput.