pub struct CreateBacklogTaskFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateBacklogTask.
Creates a new backlog task in the specified agent space
Implementations
Sourceimpl CreateBacklogTaskFluentBuilder
impl CreateBacklogTaskFluentBuilder
Sourcepub fn as_input(&self) -> &CreateBacklogTaskInputBuilder
pub fn as_input(&self) -> &CreateBacklogTaskInputBuilder
Access the CreateBacklogTask as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateBacklogTaskOutput, SdkError<CreateBacklogTaskError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateBacklogTaskOutput, SdkError<CreateBacklogTaskError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateBacklogTaskOutput, CreateBacklogTaskError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateBacklogTaskOutput, CreateBacklogTaskError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space where the task will be created
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space where the task will be created
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space where the task will be created
Sourcepub fn reference(self, input: ReferenceInput) -> Self
pub fn reference(self, input: ReferenceInput) -> Self
Optional reference information for the task
Sourcepub fn set_reference(self, input: Option<ReferenceInput>) -> Self
pub fn set_reference(self, input: Option<ReferenceInput>) -> Self
Optional reference information for the task
Sourcepub fn get_reference(&self) -> &Option<ReferenceInput>
pub fn get_reference(&self) -> &Option<ReferenceInput>
Optional reference information for the task
Sourcepub fn set_task_type(self, input: Option<TaskType>) -> Self
pub fn set_task_type(self, input: Option<TaskType>) -> Self
The type of task being created
Sourcepub fn get_task_type(&self) -> &Option<TaskType>
pub fn get_task_type(&self) -> &Option<TaskType>
The type of task being created
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
Optional detailed description of the task
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
Optional detailed description of the task
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
Optional detailed description of the task
Sourcepub fn set_priority(self, input: Option<Priority>) -> Self
pub fn set_priority(self, input: Option<Priority>) -> Self
The priority level of the task
Sourcepub fn get_priority(&self) -> &Option<Priority>
pub fn get_priority(&self) -> &Option<Priority>
The priority level of the task
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
Client-provided token for idempotent operations
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
Client-provided token for idempotent operations
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
Client-provided token for idempotent operations