#[non_exhaustive]pub struct CreateBacklogTaskInputBuilder { /* private fields */ }Expand description
A builder for CreateBacklogTaskInput.
Implementations
Sourceimpl CreateBacklogTaskInputBuilder
impl CreateBacklogTaskInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space where the task will be created This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space where the task will be created
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space where the task will be created
Sourcepub fn reference(self, input: ReferenceInput) -> Self
pub fn reference(self, input: ReferenceInput) -> Self
Optional reference information for the task
Sourcepub fn set_reference(self, input: Option<ReferenceInput>) -> Self
pub fn set_reference(self, input: Option<ReferenceInput>) -> Self
Optional reference information for the task
Sourcepub fn get_reference(&self) -> &Option<ReferenceInput>
pub fn get_reference(&self) -> &Option<ReferenceInput>
Optional reference information for the task
Sourcepub fn task_type(self, input: TaskType) -> Self
pub fn task_type(self, input: TaskType) -> Self
The type of task being created This field is required.
Sourcepub fn set_task_type(self, input: Option<TaskType>) -> Self
pub fn set_task_type(self, input: Option<TaskType>) -> Self
The type of task being created
Sourcepub fn get_task_type(&self) -> &Option<TaskType>
pub fn get_task_type(&self) -> &Option<TaskType>
The type of task being created
Sourcepub fn title(self, input: impl Into<String>) -> Self
pub fn title(self, input: impl Into<String>) -> Self
The title of the backlog task This field is required.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
Optional detailed description of the task
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
Optional detailed description of the task
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
Optional detailed description of the task
Sourcepub fn priority(self, input: Priority) -> Self
pub fn priority(self, input: Priority) -> Self
The priority level of the task This field is required.
Sourcepub fn set_priority(self, input: Option<Priority>) -> Self
pub fn set_priority(self, input: Option<Priority>) -> Self
The priority level of the task
Sourcepub fn get_priority(&self) -> &Option<Priority>
pub fn get_priority(&self) -> &Option<Priority>
The priority level of the task
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
Client-provided token for idempotent operations
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
Client-provided token for idempotent operations
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
Client-provided token for idempotent operations
Sourcepub fn build(self) -> Result<CreateBacklogTaskInput, BuildError>
pub fn build(self) -> Result<CreateBacklogTaskInput, BuildError>
Consumes the builder and constructs a CreateBacklogTaskInput.
Sourceimpl CreateBacklogTaskInputBuilder
impl CreateBacklogTaskInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateBacklogTaskOutput, SdkError<CreateBacklogTaskError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateBacklogTaskOutput, SdkError<CreateBacklogTaskError, HttpResponse>>
Sends a request with this input using the given client.