pub struct CreateChatFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateChat.
Creates a new chat execution in the specified agent space
Implementations
Sourceimpl CreateChatFluentBuilder
impl CreateChatFluentBuilder
Sourcepub fn as_input(&self) -> &CreateChatInputBuilder
pub fn as_input(&self) -> &CreateChatInputBuilder
Access the CreateChat as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateChatOutput, SdkError<CreateChatError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateChatOutput, SdkError<CreateChatError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateChatOutput, CreateChatError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateChatOutput, CreateChatError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)
Sourcepub fn set_user_id(self, input: Option<String>) -> Self
pub fn set_user_id(self, input: Option<String>) -> Self
The user identifier for the chat
Sourcepub fn get_user_id(&self) -> &Option<String>
pub fn get_user_id(&self) -> &Option<String>
The user identifier for the chat
Sourcepub fn set_user_type(self, input: Option<UserType>) -> Self
pub fn set_user_type(self, input: Option<UserType>) -> Self
The authentication type of the user
Sourcepub fn get_user_type(&self) -> &Option<UserType>
pub fn get_user_type(&self) -> &Option<UserType>
The authentication type of the user