#[non_exhaustive]pub struct CreateChatInputBuilder { /* private fields */ }Expand description
A builder for CreateChatInput.
Implementations
Sourceimpl CreateChatInputBuilder
impl CreateChatInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters) This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)
Sourcepub fn user_id(self, input: impl Into<String>) -> Self
pub fn user_id(self, input: impl Into<String>) -> Self
The user identifier for the chat This field is required.
Sourcepub fn set_user_id(self, input: Option<String>) -> Self
pub fn set_user_id(self, input: Option<String>) -> Self
The user identifier for the chat
Sourcepub fn get_user_id(&self) -> &Option<String>
pub fn get_user_id(&self) -> &Option<String>
The user identifier for the chat
Sourcepub fn set_user_type(self, input: Option<UserType>) -> Self
pub fn set_user_type(self, input: Option<UserType>) -> Self
The authentication type of the user
Sourcepub fn get_user_type(&self) -> &Option<UserType>
pub fn get_user_type(&self) -> &Option<UserType>
The authentication type of the user
Sourcepub fn build(self) -> Result<CreateChatInput, BuildError>
pub fn build(self) -> Result<CreateChatInput, BuildError>
Consumes the builder and constructs a CreateChatInput.
Sourceimpl CreateChatInputBuilder
impl CreateChatInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateChatOutput, SdkError<CreateChatError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateChatOutput, SdkError<CreateChatError, HttpResponse>>
Sends a request with this input using the given client.