#[non_exhaustive]pub struct CreateChatOutputBuilder { /* private fields */ }Expand description
A builder for CreateChatOutput.
Implementations
Sourceimpl CreateChatOutputBuilder
impl CreateChatOutputBuilder
Sourcepub fn execution_id(self, input: impl Into<String>) -> Self
pub fn execution_id(self, input: impl Into<String>) -> Self
The unique identifier for the created execution This field is required.
Sourcepub fn set_execution_id(self, input: Option<String>) -> Self
pub fn set_execution_id(self, input: Option<String>) -> Self
The unique identifier for the created execution
Sourcepub fn get_execution_id(&self) -> &Option<String>
pub fn get_execution_id(&self) -> &Option<String>
The unique identifier for the created execution
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
Timestamp when the chat was created This field is required.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
Timestamp when the chat was created
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
Timestamp when the chat was created
Sourcepub fn build(self) -> Result<CreateChatOutput, BuildError>
pub fn build(self) -> Result<CreateChatOutput, BuildError>
Consumes the builder and constructs a CreateChatOutput.
This method will fail if any of the following fields are not set: