pub struct CreateTriggerFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateTrigger.
Creates a new Trigger in the specified agent space
Implementations
Sourceimpl CreateTriggerFluentBuilder
impl CreateTriggerFluentBuilder
Sourcepub fn as_input(&self) -> &CreateTriggerInputBuilder
pub fn as_input(&self) -> &CreateTriggerInputBuilder
Access the CreateTrigger as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateTriggerOutput, SdkError<CreateTriggerError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateTriggerOutput, SdkError<CreateTriggerError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateTriggerOutput, CreateTriggerError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateTriggerOutput, CreateTriggerError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space where the Trigger will be created
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space where the Trigger will be created
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space where the Trigger will be created
Sourcepub fn condition(self, input: TriggerCondition) -> Self
pub fn condition(self, input: TriggerCondition) -> Self
The condition that fires the new Trigger
Sourcepub fn set_condition(self, input: Option<TriggerCondition>) -> Self
pub fn set_condition(self, input: Option<TriggerCondition>) -> Self
The condition that fires the new Trigger
Sourcepub fn get_condition(&self) -> &Option<TriggerCondition>
pub fn get_condition(&self) -> &Option<TriggerCondition>
The condition that fires the new Trigger
Sourcepub fn set_action(self, input: Option<Document>) -> Self
pub fn set_action(self, input: Option<Document>) -> Self
The action the new Trigger performs when it fires
Sourcepub fn get_action(&self) -> &Option<Document>
pub fn get_action(&self) -> &Option<Document>
The action the new Trigger performs when it fires
Sourcepub fn set_status(self, input: Option<String>) -> Self
pub fn set_status(self, input: Option<String>) -> Self
The initial status of the Trigger
Sourcepub fn get_status(&self) -> &Option<String>
pub fn get_status(&self) -> &Option<String>
The initial status of the Trigger
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier used for idempotent Trigger creation
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier used for idempotent Trigger creation
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier used for idempotent Trigger creation