#[non_exhaustive]pub struct CreateTriggerInputBuilder { /* private fields */ }Expand description
A builder for CreateTriggerInput.
Implementations
Sourceimpl CreateTriggerInputBuilder
impl CreateTriggerInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space where the Trigger will be created
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space where the Trigger will be created
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space where the Trigger will be created
Sourcepub fn type(self, input: impl Into<String>) -> Self
pub fn type(self, input: impl Into<String>) -> Self
How the new Trigger fires
This field is required.Sourcepub fn condition(self, input: TriggerCondition) -> Self
pub fn condition(self, input: TriggerCondition) -> Self
The condition that fires the new Trigger
This field is required.Sourcepub fn set_condition(self, input: Option<TriggerCondition>) -> Self
pub fn set_condition(self, input: Option<TriggerCondition>) -> Self
The condition that fires the new Trigger
Sourcepub fn get_condition(&self) -> &Option<TriggerCondition>
pub fn get_condition(&self) -> &Option<TriggerCondition>
The condition that fires the new Trigger
Sourcepub fn action(self, input: Document) -> Self
pub fn action(self, input: Document) -> Self
The action the new Trigger performs when it fires
This field is required.Sourcepub fn set_action(self, input: Option<Document>) -> Self
pub fn set_action(self, input: Option<Document>) -> Self
The action the new Trigger performs when it fires
Sourcepub fn get_action(&self) -> &Option<Document>
pub fn get_action(&self) -> &Option<Document>
The action the new Trigger performs when it fires
Sourcepub fn set_status(self, input: Option<String>) -> Self
pub fn set_status(self, input: Option<String>) -> Self
The initial status of the Trigger
Sourcepub fn get_status(&self) -> &Option<String>
pub fn get_status(&self) -> &Option<String>
The initial status of the Trigger
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier used for idempotent Trigger creation
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier used for idempotent Trigger creation
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier used for idempotent Trigger creation
Sourcepub fn build(self) -> Result<CreateTriggerInput, BuildError>
pub fn build(self) -> Result<CreateTriggerInput, BuildError>
Consumes the builder and constructs a CreateTriggerInput.
Sourceimpl CreateTriggerInputBuilder
impl CreateTriggerInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateTriggerOutput, SdkError<CreateTriggerError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateTriggerOutput, SdkError<CreateTriggerError, HttpResponse>>
Sends a request with this input using the given client.