#[non_exhaustive]pub struct DeleteAssetFileInput {
pub agent_space_id: Option<String>,
pub asset_id: Option<String>,
pub path: Option<String>,
}Expand description
Request structure for deleting an asset file
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier for the agent space containing the asset
asset_id: Option<String>The unique identifier of the asset containing the file
path: Option<String>The path of the file within the asset to delete
Implementations
Sourceimpl DeleteAssetFileInput
impl DeleteAssetFileInput
Sourcepub fn builder() -> DeleteAssetFileInputBuilder
pub fn builder() -> DeleteAssetFileInputBuilder
Creates a new builder-style object to manufacture DeleteAssetFileInput.