#[non_exhaustive]pub struct DescribeSupportLevelInput {
pub agent_space_id: Option<String>,
pub task_id: Option<String>,
}Expand description
Request structure for desribing support level for an account
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier for the agent space containing the task
task_id: Option<String>The unique identifier for this task
Implementations
Sourceimpl DescribeSupportLevelInput
impl DescribeSupportLevelInput
Sourcepub fn builder() -> DescribeSupportLevelInputBuilder
pub fn builder() -> DescribeSupportLevelInputBuilder
Creates a new builder-style object to manufacture DescribeSupportLevelInput.