#[non_exhaustive]pub struct EndChatForCaseInput {
pub agent_space_id: Option<String>,
pub task_id: Option<String>,
pub reason: Option<String>,
pub requester: Option<String>,
pub client_token: Option<String>,
}Expand description
Request structure for ending a chat session
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier for the agent space containing the task
task_id: Option<String>The unique identifier for the task execution to end
reason: Option<String>Reason for ending the chat session (optional, defaults to ‘Chat Ended by CloudSmith’)
requester: Option<String>Who initiated the chat end request (optional, defaults to ‘CloudSmith’)
client_token: Option<String>Client-provided token for idempotent operations
Implementations
Sourceimpl EndChatForCaseInput
impl EndChatForCaseInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier for the agent space containing the task
Sourcepub fn reason(&self) -> Option<&str>
pub fn reason(&self) -> Option<&str>
Reason for ending the chat session (optional, defaults to ‘Chat Ended by CloudSmith’)
Sourcepub fn requester(&self) -> Option<&str>
pub fn requester(&self) -> Option<&str>
Who initiated the chat end request (optional, defaults to ‘CloudSmith’)
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Client-provided token for idempotent operations
Sourceimpl EndChatForCaseInput
impl EndChatForCaseInput
Sourcepub fn builder() -> EndChatForCaseInputBuilder
pub fn builder() -> EndChatForCaseInputBuilder
Creates a new builder-style object to manufacture EndChatForCaseInput.