#[non_exhaustive]pub struct GetAccountUsageOutput {
pub monthly_account_investigation_hours: Option<UsageMetric>,
pub monthly_account_evaluation_hours: Option<UsageMetric>,
pub monthly_account_system_learning_hours: Option<UsageMetric>,
pub usage_period_start_time: DateTime,
pub usage_period_end_time: DateTime,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.monthly_account_investigation_hours: Option<UsageMetric>Monthly investigation hours usage and limit for an account
monthly_account_evaluation_hours: Option<UsageMetric>Monthly evaluation hours usage and limit for an account
monthly_account_system_learning_hours: Option<UsageMetric>Monthly system learning hours usage and limit for an account
usage_period_start_time: DateTimeThe start time of the usage tracking period
usage_period_end_time: DateTimeThe end time of the usage tracking period
Implementations
Sourceimpl GetAccountUsageOutput
impl GetAccountUsageOutput
Sourcepub fn monthly_account_investigation_hours(&self) -> Option<&UsageMetric>
pub fn monthly_account_investigation_hours(&self) -> Option<&UsageMetric>
Monthly investigation hours usage and limit for an account
Sourcepub fn monthly_account_evaluation_hours(&self) -> Option<&UsageMetric>
pub fn monthly_account_evaluation_hours(&self) -> Option<&UsageMetric>
Monthly evaluation hours usage and limit for an account
Sourcepub fn monthly_account_system_learning_hours(&self) -> Option<&UsageMetric>
pub fn monthly_account_system_learning_hours(&self) -> Option<&UsageMetric>
Monthly system learning hours usage and limit for an account
Sourcepub fn usage_period_start_time(&self) -> &DateTime
pub fn usage_period_start_time(&self) -> &DateTime
The start time of the usage tracking period
Sourcepub fn usage_period_end_time(&self) -> &DateTime
pub fn usage_period_end_time(&self) -> &DateTime
The end time of the usage tracking period
Sourceimpl GetAccountUsageOutput
impl GetAccountUsageOutput
Sourcepub fn builder() -> GetAccountUsageOutputBuilder
pub fn builder() -> GetAccountUsageOutputBuilder
Creates a new builder-style object to manufacture GetAccountUsageOutput.