#[non_exhaustive]pub struct GetAssetInput {
pub agent_space_id: Option<String>,
pub asset_id: Option<String>,
pub asset_version: Option<i32>,
}Expand description
Request structure for getting an asset
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier for the agent space containing the asset
asset_id: Option<String>The unique identifier of the asset to retrieve
asset_version: Option<i32>The specific version of the asset to retrieve. If omitted, the latest version is returned.
Implementations
Sourceimpl GetAssetInput
impl GetAssetInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier for the agent space containing the asset
Sourcepub fn asset_version(&self) -> Option<i32>
pub fn asset_version(&self) -> Option<i32>
The specific version of the asset to retrieve. If omitted, the latest version is returned.
Sourceimpl GetAssetInput
impl GetAssetInput
Sourcepub fn builder() -> GetAssetInputBuilder
pub fn builder() -> GetAssetInputBuilder
Creates a new builder-style object to manufacture GetAssetInput.