#[non_exhaustive]pub struct GetAssociationOutputBuilder { /* private fields */ }Expand description
A builder for GetAssociationOutput.
Implementations
Sourceimpl GetAssociationOutputBuilder
impl GetAssociationOutputBuilder
Sourcepub fn association(self, input: Association) -> Self
pub fn association(self, input: Association) -> Self
Represents a service association within an AgentSpace, defining how the agent interacts with external services. This field is required.
Sourcepub fn set_association(self, input: Option<Association>) -> Self
pub fn set_association(self, input: Option<Association>) -> Self
Represents a service association within an AgentSpace, defining how the agent interacts with external services.
Sourcepub fn get_association(&self) -> &Option<Association>
pub fn get_association(&self) -> &Option<Association>
Represents a service association within an AgentSpace, defining how the agent interacts with external services.
Sourcepub fn build(self) -> GetAssociationOutput
pub fn build(self) -> GetAssociationOutput
Consumes the builder and constructs a GetAssociationOutput.