#[non_exhaustive]pub struct GetAssociationOutput {
pub association: Option<Association>,
/* private fields */
}Expand description
Output containing the requested association details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.association: Option<Association>Represents a service association within an AgentSpace, defining how the agent interacts with external services.
Implementations
Sourceimpl GetAssociationOutput
impl GetAssociationOutput
Sourcepub fn association(&self) -> Option<&Association>
pub fn association(&self) -> Option<&Association>
Represents a service association within an AgentSpace, defining how the agent interacts with external services.
Sourceimpl GetAssociationOutput
impl GetAssociationOutput
Sourcepub fn builder() -> GetAssociationOutputBuilder
pub fn builder() -> GetAssociationOutputBuilder
Creates a new builder-style object to manufacture GetAssociationOutput.