#[non_exhaustive]pub enum GetBacklogTaskError {
AccessDeniedException(AccessDeniedException),
ConflictException(ConflictException),
InternalServerException(InternalServerException),
ResourceNotFoundException(ResourceNotFoundException),
ThrottlingException(ThrottlingException),
ValidationException(ValidationException),
ContentSizeExceededException(ContentSizeExceededException),
InvalidParameterException(InvalidParameterException),
ServiceQuotaExceededException(ServiceQuotaExceededException),
Unhandled(Unhandled),
}Expand description
Error type for the GetBacklogTaskError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
Access to the requested resource is denied due to insufficient permissions.
ConflictException(ConflictException)
The request conflicts with the current state of the resource.
InternalServerException(InternalServerException)
This exception is thrown when an unexpected error occurs in the processing of a request.
ResourceNotFoundException(ResourceNotFoundException)
The requested resource could not be found.
ThrottlingException(ThrottlingException)
The request was throttled due to too many requests. Please slow down and try again.
ValidationException(ValidationException)
A standard error for input validation failures. This should be thrown by services when a member of the input structure falls outside of the modeled or documented constraints.
ContentSizeExceededException(ContentSizeExceededException)
This exception is thrown when the content size exceeds the allowed limit.
InvalidParameterException(InvalidParameterException)
One or more parameters provided in the request are invalid.
ServiceQuotaExceededException(ServiceQuotaExceededException)
The request would exceed the service quota limit.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl GetBacklogTaskError
impl GetBacklogTaskError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the GetBacklogTaskError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the GetBacklogTaskError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is GetBacklogTaskError::AccessDeniedException.
Sourcepub fn is_conflict_exception(&self) -> bool
pub fn is_conflict_exception(&self) -> bool
Returns true if the error kind is GetBacklogTaskError::ConflictException.
Sourcepub fn is_internal_server_exception(&self) -> bool
pub fn is_internal_server_exception(&self) -> bool
Returns true if the error kind is GetBacklogTaskError::InternalServerException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is GetBacklogTaskError::ResourceNotFoundException.
Sourcepub fn is_throttling_exception(&self) -> bool
pub fn is_throttling_exception(&self) -> bool
Returns true if the error kind is GetBacklogTaskError::ThrottlingException.
Sourcepub fn is_validation_exception(&self) -> bool
pub fn is_validation_exception(&self) -> bool
Returns true if the error kind is GetBacklogTaskError::ValidationException.
Sourcepub fn is_content_size_exceeded_exception(&self) -> bool
pub fn is_content_size_exceeded_exception(&self) -> bool
Returns true if the error kind is GetBacklogTaskError::ContentSizeExceededException.
Sourcepub fn is_invalid_parameter_exception(&self) -> bool
pub fn is_invalid_parameter_exception(&self) -> bool
Returns true if the error kind is GetBacklogTaskError::InvalidParameterException.
Sourcepub fn is_service_quota_exceeded_exception(&self) -> bool
pub fn is_service_quota_exceeded_exception(&self) -> bool
Returns true if the error kind is GetBacklogTaskError::ServiceQuotaExceededException.