#[non_exhaustive]pub struct ListBacklogTasksInputBuilder { /* private fields */ }Expand description
A builder for ListBacklogTasksInput.
Implementations
Sourceimpl ListBacklogTasksInputBuilder
impl ListBacklogTasksInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space containing the tasks This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space containing the tasks
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space containing the tasks
Sourcepub fn filter(self, input: TaskFilter) -> Self
pub fn filter(self, input: TaskFilter) -> Self
Filter criteria to apply when listing tasks Filtering restrictions: - Each filter field list is limited to a single value - Filtering by Priority and Status at the same time when not filtering by Type is not permitted - Timestamp filters (createdAfter, createdBefore) can be combined with other filters when not sorting by priority
Sourcepub fn set_filter(self, input: Option<TaskFilter>) -> Self
pub fn set_filter(self, input: Option<TaskFilter>) -> Self
Filter criteria to apply when listing tasks Filtering restrictions: - Each filter field list is limited to a single value - Filtering by Priority and Status at the same time when not filtering by Type is not permitted - Timestamp filters (createdAfter, createdBefore) can be combined with other filters when not sorting by priority
Sourcepub fn get_filter(&self) -> &Option<TaskFilter>
pub fn get_filter(&self) -> &Option<TaskFilter>
Filter criteria to apply when listing tasks Filtering restrictions: - Each filter field list is limited to a single value - Filtering by Priority and Status at the same time when not filtering by Type is not permitted - Timestamp filters (createdAfter, createdBefore) can be combined with other filters when not sorting by priority
Sourcepub fn limit(self, input: i32) -> Self
pub fn limit(self, input: i32) -> Self
Maximum number of tasks to return in a single response (1-1000, default: 100)
Sourcepub fn set_limit(self, input: Option<i32>) -> Self
pub fn set_limit(self, input: Option<i32>) -> Self
Maximum number of tasks to return in a single response (1-1000, default: 100)
Sourcepub fn get_limit(&self) -> &Option<i32>
pub fn get_limit(&self) -> &Option<i32>
Maximum number of tasks to return in a single response (1-1000, default: 100)
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
Token for retrieving the next page of results
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
Token for retrieving the next page of results
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
Token for retrieving the next page of results
Sourcepub fn sort_field(self, input: TaskSortField) -> Self
pub fn sort_field(self, input: TaskSortField) -> Self
Field to sort by Sorting restrictions: - Only sorting on createdAt is supported when using priority or status filters alone. - Sorting by priority is not supported when using Timestamp filters (createdAfter, createdBefore)
Sourcepub fn set_sort_field(self, input: Option<TaskSortField>) -> Self
pub fn set_sort_field(self, input: Option<TaskSortField>) -> Self
Field to sort by Sorting restrictions: - Only sorting on createdAt is supported when using priority or status filters alone. - Sorting by priority is not supported when using Timestamp filters (createdAfter, createdBefore)
Sourcepub fn get_sort_field(&self) -> &Option<TaskSortField>
pub fn get_sort_field(&self) -> &Option<TaskSortField>
Field to sort by Sorting restrictions: - Only sorting on createdAt is supported when using priority or status filters alone. - Sorting by priority is not supported when using Timestamp filters (createdAfter, createdBefore)
Sourcepub fn order(self, input: TaskSortOrder) -> Self
pub fn order(self, input: TaskSortOrder) -> Self
Sort order for the tasks based on sortField (default: DESC)
Sourcepub fn set_order(self, input: Option<TaskSortOrder>) -> Self
pub fn set_order(self, input: Option<TaskSortOrder>) -> Self
Sort order for the tasks based on sortField (default: DESC)
Sourcepub fn get_order(&self) -> &Option<TaskSortOrder>
pub fn get_order(&self) -> &Option<TaskSortOrder>
Sort order for the tasks based on sortField (default: DESC)
Sourcepub fn build(self) -> Result<ListBacklogTasksInput, BuildError>
pub fn build(self) -> Result<ListBacklogTasksInput, BuildError>
Consumes the builder and constructs a ListBacklogTasksInput.
Sourceimpl ListBacklogTasksInputBuilder
impl ListBacklogTasksInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListBacklogTasksOutput, SdkError<ListBacklogTasksError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListBacklogTasksOutput, SdkError<ListBacklogTasksError, HttpResponse>>
Sends a request with this input using the given client.