#[non_exhaustive]pub struct ListBacklogTasksOutputBuilder { /* private fields */ }Expand description
A builder for ListBacklogTasksOutput.
Implementations
Sourceimpl ListBacklogTasksOutputBuilder
impl ListBacklogTasksOutputBuilder
Sourcepub fn tasks(self, input: Task) -> Self
pub fn tasks(self, input: Task) -> Self
Appends an item to tasks.
To override the contents of this collection use set_tasks.
List of backlog tasks
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
Token for retrieving the next page of results, if more results are available
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
Token for retrieving the next page of results, if more results are available
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
Token for retrieving the next page of results, if more results are available
Sourcepub fn build(self) -> Result<ListBacklogTasksOutput, BuildError>
pub fn build(self) -> Result<ListBacklogTasksOutput, BuildError>
Consumes the builder and constructs a ListBacklogTasksOutput.
This method will fail if any of the following fields are not set: