#[non_exhaustive]pub struct ListBacklogTasksInput {
pub agent_space_id: Option<String>,
pub filter: Option<TaskFilter>,
pub limit: Option<i32>,
pub next_token: Option<String>,
pub sort_field: Option<TaskSortField>,
pub order: Option<TaskSortOrder>,
}Expand description
Request structure for listing backlog tasks with filtering, sorting, and pagination support
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier for the agent space containing the tasks
filter: Option<TaskFilter>Filter criteria to apply when listing tasks Filtering restrictions: - Each filter field list is limited to a single value - Filtering by Priority and Status at the same time when not filtering by Type is not permitted - Timestamp filters (createdAfter, createdBefore) can be combined with other filters when not sorting by priority
limit: Option<i32>Maximum number of tasks to return in a single response (1-1000, default: 100)
next_token: Option<String>Token for retrieving the next page of results
sort_field: Option<TaskSortField>Field to sort by Sorting restrictions: - Only sorting on createdAt is supported when using priority or status filters alone. - Sorting by priority is not supported when using Timestamp filters (createdAfter, createdBefore)
order: Option<TaskSortOrder>Sort order for the tasks based on sortField (default: DESC)
Implementations
Sourceimpl ListBacklogTasksInput
impl ListBacklogTasksInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier for the agent space containing the tasks
Sourcepub fn filter(&self) -> Option<&TaskFilter>
pub fn filter(&self) -> Option<&TaskFilter>
Filter criteria to apply when listing tasks Filtering restrictions: - Each filter field list is limited to a single value - Filtering by Priority and Status at the same time when not filtering by Type is not permitted - Timestamp filters (createdAfter, createdBefore) can be combined with other filters when not sorting by priority
Sourcepub fn limit(&self) -> Option<i32>
pub fn limit(&self) -> Option<i32>
Maximum number of tasks to return in a single response (1-1000, default: 100)
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
Token for retrieving the next page of results
Sourcepub fn sort_field(&self) -> Option<&TaskSortField>
pub fn sort_field(&self) -> Option<&TaskSortField>
Field to sort by Sorting restrictions: - Only sorting on createdAt is supported when using priority or status filters alone. - Sorting by priority is not supported when using Timestamp filters (createdAfter, createdBefore)
Sourcepub fn order(&self) -> Option<&TaskSortOrder>
pub fn order(&self) -> Option<&TaskSortOrder>
Sort order for the tasks based on sortField (default: DESC)
Sourceimpl ListBacklogTasksInput
impl ListBacklogTasksInput
Sourcepub fn builder() -> ListBacklogTasksInputBuilder
pub fn builder() -> ListBacklogTasksInputBuilder
Creates a new builder-style object to manufacture ListBacklogTasksInput.