#[non_exhaustive]pub struct ListChatsInputBuilder { /* private fields */ }Expand description
A builder for ListChatsInput.
Implementations
Sourceimpl ListChatsInputBuilder
impl ListChatsInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters) This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)
Sourcepub fn user_id(self, input: impl Into<String>) -> Self
👎Deprecated since 2026-04-15: userId is managed by the service and should not be provided by the caller
pub fn user_id(self, input: impl Into<String>) -> Self
userId is managed by the service and should not be provided by the caller
The user identifier to list chats for. This field is deprecated and will be ignored — the service resolves user identity from the authenticated session.
Sourcepub fn set_user_id(self, input: Option<String>) -> Self
👎Deprecated since 2026-04-15: userId is managed by the service and should not be provided by the caller
pub fn set_user_id(self, input: Option<String>) -> Self
userId is managed by the service and should not be provided by the caller
The user identifier to list chats for. This field is deprecated and will be ignored — the service resolves user identity from the authenticated session.
Sourcepub fn get_user_id(&self) -> &Option<String>
👎Deprecated since 2026-04-15: userId is managed by the service and should not be provided by the caller
pub fn get_user_id(&self) -> &Option<String>
userId is managed by the service and should not be provided by the caller
The user identifier to list chats for. This field is deprecated and will be ignored — the service resolves user identity from the authenticated session.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
Maximum number of results to return
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
Maximum number of results to return
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
Maximum number of results to return
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
Token for pagination
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
Token for pagination
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
Token for pagination
Sourcepub fn build(self) -> Result<ListChatsInput, BuildError>
pub fn build(self) -> Result<ListChatsInput, BuildError>
Consumes the builder and constructs a ListChatsInput.
Sourceimpl ListChatsInputBuilder
impl ListChatsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListChatsOutput, SdkError<ListChatsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListChatsOutput, SdkError<ListChatsError, HttpResponse>>
Sends a request with this input using the given client.