#[non_exhaustive]pub struct ListGoalsInputBuilder { /* private fields */ }Expand description
A builder for ListGoalsInput.
Implementations
Sourceimpl ListGoalsInputBuilder
impl ListGoalsInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space
Sourcepub fn status(self, input: GoalStatus) -> Self
pub fn status(self, input: GoalStatus) -> Self
Filter goals by goal status
Sourcepub fn set_status(self, input: Option<GoalStatus>) -> Self
pub fn set_status(self, input: Option<GoalStatus>) -> Self
Filter goals by goal status
Sourcepub fn get_status(&self) -> &Option<GoalStatus>
pub fn get_status(&self) -> &Option<GoalStatus>
Filter goals by goal status
Sourcepub fn set_goal_type(self, input: Option<GoalType>) -> Self
pub fn set_goal_type(self, input: Option<GoalType>) -> Self
Filter goals by goal type
Sourcepub fn get_goal_type(&self) -> &Option<GoalType>
pub fn get_goal_type(&self) -> &Option<GoalType>
Filter goals by goal type
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
Pagination token for the next set of results
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
Pagination token for the next set of results
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
Pagination token for the next set of results
Sourcepub fn build(self) -> Result<ListGoalsInput, BuildError>
pub fn build(self) -> Result<ListGoalsInput, BuildError>
Consumes the builder and constructs a ListGoalsInput.
Sourceimpl ListGoalsInputBuilder
impl ListGoalsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListGoalsOutput, SdkError<ListGoalsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListGoalsOutput, SdkError<ListGoalsError, HttpResponse>>
Sends a request with this input using the given client.