#[non_exhaustive]pub struct ListGoalsOutputBuilder { /* private fields */ }Expand description
A builder for ListGoalsOutput.
Implementations
Sourceimpl ListGoalsOutputBuilder
impl ListGoalsOutputBuilder
Sourcepub fn goals(self, input: Goal) -> Self
pub fn goals(self, input: Goal) -> Self
Appends an item to goals.
To override the contents of this collection use set_goals.
List of goals matching the criteria
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
Pagination token for the next set of results
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
Pagination token for the next set of results
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
Pagination token for the next set of results
Sourcepub fn build(self) -> Result<ListGoalsOutput, BuildError>
pub fn build(self) -> Result<ListGoalsOutput, BuildError>
Consumes the builder and constructs a ListGoalsOutput.
This method will fail if any of the following fields are not set: