#[non_exhaustive]pub enum ListGoalsError {
AccessDeniedException(AccessDeniedException),
InternalServerException(InternalServerException),
ThrottlingException(ThrottlingException),
ValidationException(ValidationException),
ConflictException(ConflictException),
ContentSizeExceededException(ContentSizeExceededException),
InvalidParameterException(InvalidParameterException),
ResourceNotFoundException(ResourceNotFoundException),
ServiceQuotaExceededException(ServiceQuotaExceededException),
Unhandled(Unhandled),
}Expand description
Error type for the ListGoalsError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
Access to the requested resource is denied due to insufficient permissions.
InternalServerException(InternalServerException)
This exception is thrown when an unexpected error occurs in the processing of a request.
ThrottlingException(ThrottlingException)
The request was throttled due to too many requests. Please slow down and try again.
ValidationException(ValidationException)
A standard error for input validation failures. This should be thrown by services when a member of the input structure falls outside of the modeled or documented constraints.
ConflictException(ConflictException)
The request conflicts with the current state of the resource.
ContentSizeExceededException(ContentSizeExceededException)
This exception is thrown when the content size exceeds the allowed limit.
InvalidParameterException(InvalidParameterException)
One or more parameters provided in the request are invalid.
ResourceNotFoundException(ResourceNotFoundException)
The requested resource could not be found.
ServiceQuotaExceededException(ServiceQuotaExceededException)
The request would exceed the service quota limit.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl ListGoalsError
impl ListGoalsError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the ListGoalsError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the ListGoalsError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is ListGoalsError::AccessDeniedException.
Sourcepub fn is_internal_server_exception(&self) -> bool
pub fn is_internal_server_exception(&self) -> bool
Returns true if the error kind is ListGoalsError::InternalServerException.
Sourcepub fn is_throttling_exception(&self) -> bool
pub fn is_throttling_exception(&self) -> bool
Returns true if the error kind is ListGoalsError::ThrottlingException.
Sourcepub fn is_validation_exception(&self) -> bool
pub fn is_validation_exception(&self) -> bool
Returns true if the error kind is ListGoalsError::ValidationException.
Sourcepub fn is_conflict_exception(&self) -> bool
pub fn is_conflict_exception(&self) -> bool
Returns true if the error kind is ListGoalsError::ConflictException.
Sourcepub fn is_content_size_exceeded_exception(&self) -> bool
pub fn is_content_size_exceeded_exception(&self) -> bool
Returns true if the error kind is ListGoalsError::ContentSizeExceededException.
Sourcepub fn is_invalid_parameter_exception(&self) -> bool
pub fn is_invalid_parameter_exception(&self) -> bool
Returns true if the error kind is ListGoalsError::InvalidParameterException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is ListGoalsError::ResourceNotFoundException.
Sourcepub fn is_service_quota_exceeded_exception(&self) -> bool
pub fn is_service_quota_exceeded_exception(&self) -> bool
Returns true if the error kind is ListGoalsError::ServiceQuotaExceededException.