#[non_exhaustive]pub struct ListRecommendationsInputBuilder { /* private fields */ }Expand description
A builder for ListRecommendationsInput.
Implementations
Sourceimpl ListRecommendationsInputBuilder
impl ListRecommendationsInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space containing the recommendations This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space containing the recommendations
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space containing the recommendations
Sourcepub fn task_id(self, input: impl Into<String>) -> Self
pub fn task_id(self, input: impl Into<String>) -> Self
Optional task ID to filter recommendations by specific task
Sourcepub fn set_task_id(self, input: Option<String>) -> Self
pub fn set_task_id(self, input: Option<String>) -> Self
Optional task ID to filter recommendations by specific task
Sourcepub fn get_task_id(&self) -> &Option<String>
pub fn get_task_id(&self) -> &Option<String>
Optional task ID to filter recommendations by specific task
Sourcepub fn goal_id(self, input: impl Into<String>) -> Self
pub fn goal_id(self, input: impl Into<String>) -> Self
Optional goal ID to filter recommendations by specific goal
Sourcepub fn set_goal_id(self, input: Option<String>) -> Self
pub fn set_goal_id(self, input: Option<String>) -> Self
Optional goal ID to filter recommendations by specific goal
Sourcepub fn get_goal_id(&self) -> &Option<String>
pub fn get_goal_id(&self) -> &Option<String>
Optional goal ID to filter recommendations by specific goal
Sourcepub fn status(self, input: RecommendationStatus) -> Self
pub fn status(self, input: RecommendationStatus) -> Self
Optional status to filter recommendations by their current status
Sourcepub fn set_status(self, input: Option<RecommendationStatus>) -> Self
pub fn set_status(self, input: Option<RecommendationStatus>) -> Self
Optional status to filter recommendations by their current status
Sourcepub fn get_status(&self) -> &Option<RecommendationStatus>
pub fn get_status(&self) -> &Option<RecommendationStatus>
Optional status to filter recommendations by their current status
Sourcepub fn priority(self, input: RecommendationPriority) -> Self
pub fn priority(self, input: RecommendationPriority) -> Self
Optional priority to filter recommendations by priority level
Sourcepub fn set_priority(self, input: Option<RecommendationPriority>) -> Self
pub fn set_priority(self, input: Option<RecommendationPriority>) -> Self
Optional priority to filter recommendations by priority level
Sourcepub fn get_priority(&self) -> &Option<RecommendationPriority>
pub fn get_priority(&self) -> &Option<RecommendationPriority>
Optional priority to filter recommendations by priority level
Sourcepub fn limit(self, input: i32) -> Self
pub fn limit(self, input: i32) -> Self
Maximum number of recommendations to return in a single response
Sourcepub fn set_limit(self, input: Option<i32>) -> Self
pub fn set_limit(self, input: Option<i32>) -> Self
Maximum number of recommendations to return in a single response
Sourcepub fn get_limit(&self) -> &Option<i32>
pub fn get_limit(&self) -> &Option<i32>
Maximum number of recommendations to return in a single response
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
Token for retrieving the next page of results
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
Token for retrieving the next page of results
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
Token for retrieving the next page of results
Sourcepub fn build(self) -> Result<ListRecommendationsInput, BuildError>
pub fn build(self) -> Result<ListRecommendationsInput, BuildError>
Consumes the builder and constructs a ListRecommendationsInput.
Sourceimpl ListRecommendationsInputBuilder
impl ListRecommendationsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListRecommendationsOutput, SdkError<ListRecommendationsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListRecommendationsOutput, SdkError<ListRecommendationsError, HttpResponse>>
Sends a request with this input using the given client.