#[non_exhaustive]pub struct ListRecommendationsInput {
pub agent_space_id: Option<String>,
pub task_id: Option<String>,
pub goal_id: Option<String>,
pub status: Option<RecommendationStatus>,
pub priority: Option<RecommendationPriority>,
pub limit: Option<i32>,
pub next_token: Option<String>,
}Expand description
Request structure for listing recommendations with filtering and pagination support
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier for the agent space containing the recommendations
task_id: Option<String>Optional task ID to filter recommendations by specific task
goal_id: Option<String>Optional goal ID to filter recommendations by specific goal
status: Option<RecommendationStatus>Optional status to filter recommendations by their current status
priority: Option<RecommendationPriority>Optional priority to filter recommendations by priority level
limit: Option<i32>Maximum number of recommendations to return in a single response
next_token: Option<String>Token for retrieving the next page of results
Implementations
Sourceimpl ListRecommendationsInput
impl ListRecommendationsInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier for the agent space containing the recommendations
Sourcepub fn task_id(&self) -> Option<&str>
pub fn task_id(&self) -> Option<&str>
Optional task ID to filter recommendations by specific task
Sourcepub fn goal_id(&self) -> Option<&str>
pub fn goal_id(&self) -> Option<&str>
Optional goal ID to filter recommendations by specific goal
Sourcepub fn status(&self) -> Option<&RecommendationStatus>
pub fn status(&self) -> Option<&RecommendationStatus>
Optional status to filter recommendations by their current status
Sourcepub fn priority(&self) -> Option<&RecommendationPriority>
pub fn priority(&self) -> Option<&RecommendationPriority>
Optional priority to filter recommendations by priority level
Sourcepub fn limit(&self) -> Option<i32>
pub fn limit(&self) -> Option<i32>
Maximum number of recommendations to return in a single response
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
Token for retrieving the next page of results
Sourceimpl ListRecommendationsInput
impl ListRecommendationsInput
Sourcepub fn builder() -> ListRecommendationsInputBuilder
pub fn builder() -> ListRecommendationsInputBuilder
Creates a new builder-style object to manufacture ListRecommendationsInput.