pub struct ListServicesFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListServices.
List a list of registered service on the account level.
Implementations
Sourceimpl ListServicesFluentBuilder
impl ListServicesFluentBuilder
Sourcepub fn as_input(&self) -> &ListServicesInputBuilder
pub fn as_input(&self) -> &ListServicesInputBuilder
Access the ListServices as a reference.
Sourcepub async fn send(
self,
) -> Result<ListServicesOutput, SdkError<ListServicesError, HttpResponse>>
pub async fn send( self, ) -> Result<ListServicesOutput, SdkError<ListServicesError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListServicesOutput, ListServicesError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListServicesOutput, ListServicesError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListServicesPaginator
pub fn into_paginator(self) -> ListServicesPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
Maximum number of results to return in a single call.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
Maximum number of results to return in a single call.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
Maximum number of results to return in a single call.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
Token for the next page of results.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
Token for the next page of results.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
Token for the next page of results.
Sourcepub fn filter_service_type(self, input: Service) -> Self
pub fn filter_service_type(self, input: Service) -> Self
Optional filter to list only services of a specific type.
Sourcepub fn set_filter_service_type(self, input: Option<Service>) -> Self
pub fn set_filter_service_type(self, input: Option<Service>) -> Self
Optional filter to list only services of a specific type.
Sourcepub fn get_filter_service_type(&self) -> &Option<Service>
pub fn get_filter_service_type(&self) -> &Option<Service>
Optional filter to list only services of a specific type.