#[non_exhaustive]pub struct ListTriggersInput {
pub agent_space_id: Option<String>,
pub status: Option<String>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Expand description
Request structure for listing Triggers in an agent space
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier for the agent space whose Triggers should be listed
status: Option<String>Filter results to Triggers in this status
next_token: Option<String>Pagination token from a previous response to retrieve the next page of results
max_results: Option<i32>The maximum number of results to return in a single response
Implementations
Sourceimpl ListTriggersInput
impl ListTriggersInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier for the agent space whose Triggers should be listed
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
Pagination token from a previous response to retrieve the next page of results
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return in a single response
Sourceimpl ListTriggersInput
impl ListTriggersInput
Sourcepub fn builder() -> ListTriggersInputBuilder
pub fn builder() -> ListTriggersInputBuilder
Creates a new builder-style object to manufacture ListTriggersInput.