pub struct RegisterServiceFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to RegisterService.
This operation registers the specified service
Implementations
Sourceimpl RegisterServiceFluentBuilder
impl RegisterServiceFluentBuilder
Sourcepub fn as_input(&self) -> &RegisterServiceInputBuilder
pub fn as_input(&self) -> &RegisterServiceInputBuilder
Access the RegisterService as a reference.
Sourcepub async fn send(
self,
) -> Result<RegisterServiceOutput, SdkError<RegisterServiceError, HttpResponse>>
pub async fn send( self, ) -> Result<RegisterServiceOutput, SdkError<RegisterServiceError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<RegisterServiceOutput, RegisterServiceError, Self>
pub fn customize( self, ) -> CustomizableOperation<RegisterServiceOutput, RegisterServiceError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn service(self, input: PostRegisterServiceSupportedService) -> Self
pub fn service(self, input: PostRegisterServiceSupportedService) -> Self
Services that can be registered via the post-registration API (excludes OAuth 3LO services).
Sourcepub fn set_service(
self,
input: Option<PostRegisterServiceSupportedService>,
) -> Self
pub fn set_service( self, input: Option<PostRegisterServiceSupportedService>, ) -> Self
Services that can be registered via the post-registration API (excludes OAuth 3LO services).
Sourcepub fn get_service(&self) -> &Option<PostRegisterServiceSupportedService>
pub fn get_service(&self) -> &Option<PostRegisterServiceSupportedService>
Services that can be registered via the post-registration API (excludes OAuth 3LO services).
Sourcepub fn service_details(self, input: ServiceDetails) -> Self
pub fn service_details(self, input: ServiceDetails) -> Self
Service-specific authorization configuration parameters
Sourcepub fn set_service_details(self, input: Option<ServiceDetails>) -> Self
pub fn set_service_details(self, input: Option<ServiceDetails>) -> Self
Service-specific authorization configuration parameters
Sourcepub fn get_service_details(&self) -> &Option<ServiceDetails>
pub fn get_service_details(&self) -> &Option<ServiceDetails>
Service-specific authorization configuration parameters
Sourcepub fn kms_key_arn(self, input: impl Into<String>) -> Self
pub fn kms_key_arn(self, input: impl Into<String>) -> Self
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn set_kms_key_arn(self, input: Option<String>) -> Self
pub fn set_kms_key_arn(self, input: Option<String>) -> Self
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn get_kms_key_arn(&self) -> &Option<String>
pub fn get_kms_key_arn(&self) -> &Option<String>
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn private_connection_name(self, input: impl Into<String>) -> Self
pub fn private_connection_name(self, input: impl Into<String>) -> Self
The name of the private connection to use for VPC connectivity.
Sourcepub fn set_private_connection_name(self, input: Option<String>) -> Self
pub fn set_private_connection_name(self, input: Option<String>) -> Self
The name of the private connection to use for VPC connectivity.
Sourcepub fn get_private_connection_name(&self) -> &Option<String>
pub fn get_private_connection_name(&self) -> &Option<String>
The name of the private connection to use for VPC connectivity.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The display name for the service registration.
Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The display name for the service registration.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
Tags to add to the Service at registration time.
Tags to add to the Service at registration time.
Tags to add to the Service at registration time.