#[non_exhaustive]pub struct RegisterServiceInputBuilder { /* private fields */ }Expand description
A builder for RegisterServiceInput.
Implementations
Sourceimpl RegisterServiceInputBuilder
impl RegisterServiceInputBuilder
Sourcepub fn service(self, input: PostRegisterServiceSupportedService) -> Self
pub fn service(self, input: PostRegisterServiceSupportedService) -> Self
Services that can be registered via the post-registration API (excludes OAuth 3LO services). This field is required.
Sourcepub fn set_service(
self,
input: Option<PostRegisterServiceSupportedService>,
) -> Self
pub fn set_service( self, input: Option<PostRegisterServiceSupportedService>, ) -> Self
Services that can be registered via the post-registration API (excludes OAuth 3LO services).
Sourcepub fn get_service(&self) -> &Option<PostRegisterServiceSupportedService>
pub fn get_service(&self) -> &Option<PostRegisterServiceSupportedService>
Services that can be registered via the post-registration API (excludes OAuth 3LO services).
Sourcepub fn service_details(self, input: ServiceDetails) -> Self
pub fn service_details(self, input: ServiceDetails) -> Self
Service-specific authorization configuration parameters This field is required.
Sourcepub fn set_service_details(self, input: Option<ServiceDetails>) -> Self
pub fn set_service_details(self, input: Option<ServiceDetails>) -> Self
Service-specific authorization configuration parameters
Sourcepub fn get_service_details(&self) -> &Option<ServiceDetails>
pub fn get_service_details(&self) -> &Option<ServiceDetails>
Service-specific authorization configuration parameters
Sourcepub fn kms_key_arn(self, input: impl Into<String>) -> Self
pub fn kms_key_arn(self, input: impl Into<String>) -> Self
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn set_kms_key_arn(self, input: Option<String>) -> Self
pub fn set_kms_key_arn(self, input: Option<String>) -> Self
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn get_kms_key_arn(&self) -> &Option<String>
pub fn get_kms_key_arn(&self) -> &Option<String>
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn private_connection_name(self, input: impl Into<String>) -> Self
pub fn private_connection_name(self, input: impl Into<String>) -> Self
The name of the private connection to use for VPC connectivity.
Sourcepub fn set_private_connection_name(self, input: Option<String>) -> Self
pub fn set_private_connection_name(self, input: Option<String>) -> Self
The name of the private connection to use for VPC connectivity.
Sourcepub fn get_private_connection_name(&self) -> &Option<String>
pub fn get_private_connection_name(&self) -> &Option<String>
The name of the private connection to use for VPC connectivity.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The display name for the service registration.
Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The display name for the service registration.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
Tags to add to the Service at registration time.
Tags to add to the Service at registration time.
Tags to add to the Service at registration time.
Sourcepub fn build(self) -> Result<RegisterServiceInput, BuildError>
pub fn build(self) -> Result<RegisterServiceInput, BuildError>
Consumes the builder and constructs a RegisterServiceInput.
Sourceimpl RegisterServiceInputBuilder
impl RegisterServiceInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<RegisterServiceOutput, SdkError<RegisterServiceError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<RegisterServiceOutput, SdkError<RegisterServiceError, HttpResponse>>
Sends a request with this input using the given client.