#[non_exhaustive]pub struct RegisterServiceOutputBuilder { /* private fields */ }Expand description
A builder for RegisterServiceOutput.
Implementations
Sourceimpl RegisterServiceOutputBuilder
impl RegisterServiceOutputBuilder
Sourcepub fn service_id(self, input: impl Into<String>) -> Self
pub fn service_id(self, input: impl Into<String>) -> Self
Service ID - present when registration is complete, absent when additional steps are required
Sourcepub fn set_service_id(self, input: Option<String>) -> Self
pub fn set_service_id(self, input: Option<String>) -> Self
Service ID - present when registration is complete, absent when additional steps are required
Sourcepub fn get_service_id(&self) -> &Option<String>
pub fn get_service_id(&self) -> &Option<String>
Service ID - present when registration is complete, absent when additional steps are required
Sourcepub fn additional_step(self, input: AdditionalServiceRegistrationStep) -> Self
pub fn additional_step(self, input: AdditionalServiceRegistrationStep) -> Self
Indicates if additional steps are required to complete service registration (e.g., 3-legged OAuth)
Sourcepub fn set_additional_step(
self,
input: Option<AdditionalServiceRegistrationStep>,
) -> Self
pub fn set_additional_step( self, input: Option<AdditionalServiceRegistrationStep>, ) -> Self
Indicates if additional steps are required to complete service registration (e.g., 3-legged OAuth)
Sourcepub fn get_additional_step(&self) -> &Option<AdditionalServiceRegistrationStep>
pub fn get_additional_step(&self) -> &Option<AdditionalServiceRegistrationStep>
Indicates if additional steps are required to complete service registration (e.g., 3-legged OAuth)
Sourcepub fn kms_key_arn(self, input: impl Into<String>) -> Self
pub fn kms_key_arn(self, input: impl Into<String>) -> Self
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn set_kms_key_arn(self, input: Option<String>) -> Self
pub fn set_kms_key_arn(self, input: Option<String>) -> Self
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn get_kms_key_arn(&self) -> &Option<String>
pub fn get_kms_key_arn(&self) -> &Option<String>
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
Tags associated with the registered Service.
Tags associated with the registered Service.
Tags associated with the registered Service.
Sourcepub fn build(self) -> RegisterServiceOutput
pub fn build(self) -> RegisterServiceOutput
Consumes the builder and constructs a RegisterServiceOutput.