#[non_exhaustive]pub struct RegisterServiceInput {
pub service: Option<PostRegisterServiceSupportedService>,
pub service_details: Option<ServiceDetails>,
pub kms_key_arn: Option<String>,
pub private_connection_name: Option<String>,
pub name: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Expand description
Input for registering a new service with the platform.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service: Option<PostRegisterServiceSupportedService>Services that can be registered via the post-registration API (excludes OAuth 3LO services).
service_details: Option<ServiceDetails>Service-specific authorization configuration parameters
kms_key_arn: Option<String>The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
private_connection_name: Option<String>The name of the private connection to use for VPC connectivity.
name: Option<String>The display name for the service registration.
Tags to add to the Service at registration time.
Implementations
Sourceimpl RegisterServiceInput
impl RegisterServiceInput
Sourcepub fn service(&self) -> Option<&PostRegisterServiceSupportedService>
pub fn service(&self) -> Option<&PostRegisterServiceSupportedService>
Services that can be registered via the post-registration API (excludes OAuth 3LO services).
Sourcepub fn service_details(&self) -> Option<&ServiceDetails>
pub fn service_details(&self) -> Option<&ServiceDetails>
Service-specific authorization configuration parameters
Sourcepub fn kms_key_arn(&self) -> Option<&str>
pub fn kms_key_arn(&self) -> Option<&str>
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn private_connection_name(&self) -> Option<&str>
pub fn private_connection_name(&self) -> Option<&str>
The name of the private connection to use for VPC connectivity.
Tags to add to the Service at registration time.
Sourceimpl RegisterServiceInput
impl RegisterServiceInput
Sourcepub fn builder() -> RegisterServiceInputBuilder
pub fn builder() -> RegisterServiceInputBuilder
Creates a new builder-style object to manufacture RegisterServiceInput.