#[non_exhaustive]pub struct RegisterServiceOutput {
pub service_id: Option<String>,
pub additional_step: Option<AdditionalServiceRegistrationStep>,
pub kms_key_arn: Option<String>,
pub tags: Option<HashMap<String, String>>,
/* private fields */
}Expand description
Output containing the service ID and any additional steps required for registration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service_id: Option<String>Service ID - present when registration is complete, absent when additional steps are required
additional_step: Option<AdditionalServiceRegistrationStep>Indicates if additional steps are required to complete service registration (e.g., 3-legged OAuth)
kms_key_arn: Option<String>The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Tags associated with the registered Service.
Implementations
Sourceimpl RegisterServiceOutput
impl RegisterServiceOutput
Sourcepub fn service_id(&self) -> Option<&str>
pub fn service_id(&self) -> Option<&str>
Service ID - present when registration is complete, absent when additional steps are required
Sourcepub fn additional_step(&self) -> Option<&AdditionalServiceRegistrationStep>
pub fn additional_step(&self) -> Option<&AdditionalServiceRegistrationStep>
Indicates if additional steps are required to complete service registration (e.g., 3-legged OAuth)
Sourcepub fn kms_key_arn(&self) -> Option<&str>
pub fn kms_key_arn(&self) -> Option<&str>
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Tags associated with the registered Service.
Sourceimpl RegisterServiceOutput
impl RegisterServiceOutput
Sourcepub fn builder() -> RegisterServiceOutputBuilder
pub fn builder() -> RegisterServiceOutputBuilder
Creates a new builder-style object to manufacture RegisterServiceOutput.