pub struct SendMessageFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to SendMessage.
Sends a chat message and streams the response for the specified agent space execution
Implementations
Sourceimpl SendMessageFluentBuilder
impl SendMessageFluentBuilder
Sourcepub fn as_input(&self) -> &SendMessageInputBuilder
pub fn as_input(&self) -> &SendMessageInputBuilder
Access the SendMessage as a reference.
Sourcepub async fn send(
self,
) -> Result<SendMessageOutput, SdkError<SendMessageError, HttpResponse>>
pub async fn send( self, ) -> Result<SendMessageOutput, SdkError<SendMessageError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<SendMessageOutput, SendMessageError, Self>
pub fn customize( self, ) -> CustomizableOperation<SendMessageOutput, SendMessageError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The agent space identifier
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The agent space identifier
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The agent space identifier
Sourcepub fn execution_id(self, input: impl Into<String>) -> Self
pub fn execution_id(self, input: impl Into<String>) -> Self
The execution identifier for the chat session
Sourcepub fn set_execution_id(self, input: Option<String>) -> Self
pub fn set_execution_id(self, input: Option<String>) -> Self
The execution identifier for the chat session
Sourcepub fn get_execution_id(&self) -> &Option<String>
pub fn get_execution_id(&self) -> &Option<String>
The execution identifier for the chat session
Sourcepub fn set_content(self, input: Option<String>) -> Self
pub fn set_content(self, input: Option<String>) -> Self
The user message content
Sourcepub fn get_content(&self) -> &Option<String>
pub fn get_content(&self) -> &Option<String>
The user message content
Sourcepub fn context(self, input: SendMessageContext) -> Self
pub fn context(self, input: SendMessageContext) -> Self
Optional context for the message
Sourcepub fn set_context(self, input: Option<SendMessageContext>) -> Self
pub fn set_context(self, input: Option<SendMessageContext>) -> Self
Optional context for the message
Sourcepub fn get_context(&self) -> &Option<SendMessageContext>
pub fn get_context(&self) -> &Option<SendMessageContext>
Optional context for the message
Sourcepub fn set_user_id(self, input: Option<String>) -> Self
pub fn set_user_id(self, input: Option<String>) -> Self
Required user identifier
Sourcepub fn get_user_id(&self) -> &Option<String>
pub fn get_user_id(&self) -> &Option<String>
Required user identifier