#[non_exhaustive]pub struct SendMessageInputBuilder { /* private fields */ }Expand description
A builder for SendMessageInput.
Implementations
Sourceimpl SendMessageInputBuilder
impl SendMessageInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The agent space identifier This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The agent space identifier
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The agent space identifier
Sourcepub fn execution_id(self, input: impl Into<String>) -> Self
pub fn execution_id(self, input: impl Into<String>) -> Self
The execution identifier for the chat session This field is required.
Sourcepub fn set_execution_id(self, input: Option<String>) -> Self
pub fn set_execution_id(self, input: Option<String>) -> Self
The execution identifier for the chat session
Sourcepub fn get_execution_id(&self) -> &Option<String>
pub fn get_execution_id(&self) -> &Option<String>
The execution identifier for the chat session
Sourcepub fn content(self, input: impl Into<String>) -> Self
pub fn content(self, input: impl Into<String>) -> Self
The user message content This field is required.
Sourcepub fn set_content(self, input: Option<String>) -> Self
pub fn set_content(self, input: Option<String>) -> Self
The user message content
Sourcepub fn get_content(&self) -> &Option<String>
pub fn get_content(&self) -> &Option<String>
The user message content
Sourcepub fn context(self, input: SendMessageContext) -> Self
pub fn context(self, input: SendMessageContext) -> Self
Optional context for the message
Sourcepub fn set_context(self, input: Option<SendMessageContext>) -> Self
pub fn set_context(self, input: Option<SendMessageContext>) -> Self
Optional context for the message
Sourcepub fn get_context(&self) -> &Option<SendMessageContext>
pub fn get_context(&self) -> &Option<SendMessageContext>
Optional context for the message
Sourcepub fn user_id(self, input: impl Into<String>) -> Self
pub fn user_id(self, input: impl Into<String>) -> Self
Required user identifier This field is required.
Sourcepub fn set_user_id(self, input: Option<String>) -> Self
pub fn set_user_id(self, input: Option<String>) -> Self
Required user identifier
Sourcepub fn get_user_id(&self) -> &Option<String>
pub fn get_user_id(&self) -> &Option<String>
Required user identifier
Sourcepub fn build(self) -> Result<SendMessageInput, BuildError>
pub fn build(self) -> Result<SendMessageInput, BuildError>
Consumes the builder and constructs a SendMessageInput.
Sourceimpl SendMessageInputBuilder
impl SendMessageInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<SendMessageOutput, SdkError<SendMessageError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<SendMessageOutput, SdkError<SendMessageError, HttpResponse>>
Sends a request with this input using the given client.