#[non_exhaustive]pub struct UpdateAgentSpaceInputBuilder { /* private fields */ }Expand description
A builder for UpdateAgentSpaceInput.
Implementations
Sourceimpl UpdateAgentSpaceInputBuilder
impl UpdateAgentSpaceInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the AgentSpace This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the AgentSpace
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the AgentSpace
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The updated description of the AgentSpace.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The updated description of the AgentSpace.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The updated description of the AgentSpace.
Sourcepub fn locale(self, input: impl Into<String>) -> Self
pub fn locale(self, input: impl Into<String>) -> Self
The updated locale for the AgentSpace, which determines the language used in agent responses.
Sourcepub fn set_locale(self, input: Option<String>) -> Self
pub fn set_locale(self, input: Option<String>) -> Self
The updated locale for the AgentSpace, which determines the language used in agent responses.
Sourcepub fn get_locale(&self) -> &Option<String>
pub fn get_locale(&self) -> &Option<String>
The updated locale for the AgentSpace, which determines the language used in agent responses.
Sourcepub fn build(self) -> Result<UpdateAgentSpaceInput, BuildError>
pub fn build(self) -> Result<UpdateAgentSpaceInput, BuildError>
Consumes the builder and constructs a UpdateAgentSpaceInput.
Sourceimpl UpdateAgentSpaceInputBuilder
impl UpdateAgentSpaceInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateAgentSpaceOutput, SdkError<UpdateAgentSpaceError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateAgentSpaceOutput, SdkError<UpdateAgentSpaceError, HttpResponse>>
Sends a request with this input using the given client.