#[non_exhaustive]pub struct UpdateAgentSpaceOutput {
pub agent_space: Option<AgentSpace>,
/* private fields */
}Expand description
Output containing the updated AgentSpace.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space: Option<AgentSpace>Represents a complete AgentSpace with all its properties, timestamps, encryption settings, and unique identifier.
Implementations
Sourceimpl UpdateAgentSpaceOutput
impl UpdateAgentSpaceOutput
Sourcepub fn agent_space(&self) -> Option<&AgentSpace>
pub fn agent_space(&self) -> Option<&AgentSpace>
Represents a complete AgentSpace with all its properties, timestamps, encryption settings, and unique identifier.
Sourceimpl UpdateAgentSpaceOutput
impl UpdateAgentSpaceOutput
Sourcepub fn builder() -> UpdateAgentSpaceOutputBuilder
pub fn builder() -> UpdateAgentSpaceOutputBuilder
Creates a new builder-style object to manufacture UpdateAgentSpaceOutput.