#[non_exhaustive]pub struct UpdateAssetInputBuilder { /* private fields */ }Expand description
A builder for UpdateAssetInput.
Implementations
Sourceimpl UpdateAssetInputBuilder
impl UpdateAssetInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space containing the asset
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space containing the asset
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space containing the asset
Sourcepub fn asset_id(self, input: impl Into<String>) -> Self
pub fn asset_id(self, input: impl Into<String>) -> Self
The unique identifier of the asset to update
This field is required.Sourcepub fn set_asset_id(self, input: Option<String>) -> Self
pub fn set_asset_id(self, input: Option<String>) -> Self
The unique identifier of the asset to update
Sourcepub fn get_asset_id(&self) -> &Option<String>
pub fn get_asset_id(&self) -> &Option<String>
The unique identifier of the asset to update
Sourcepub fn metadata(self, input: Document) -> Self
pub fn metadata(self, input: Document) -> Self
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
Sourcepub fn set_metadata(self, input: Option<Document>) -> Self
pub fn set_metadata(self, input: Option<Document>) -> Self
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
Sourcepub fn get_metadata(&self) -> &Option<Document>
pub fn get_metadata(&self) -> &Option<Document>
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
Sourcepub fn content(self, input: AssetContent) -> Self
pub fn content(self, input: AssetContent) -> Self
Optional content to set or replace. A single file adds or replaces one file; a zip replaces all files.
Sourcepub fn set_content(self, input: Option<AssetContent>) -> Self
pub fn set_content(self, input: Option<AssetContent>) -> Self
Optional content to set or replace. A single file adds or replaces one file; a zip replaces all files.
Sourcepub fn get_content(&self) -> &Option<AssetContent>
pub fn get_content(&self) -> &Option<AssetContent>
Optional content to set or replace. A single file adds or replaces one file; a zip replaces all files.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier used for idempotent asset update
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier used for idempotent asset update
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier used for idempotent asset update
Sourcepub fn build(self) -> Result<UpdateAssetInput, BuildError>
pub fn build(self) -> Result<UpdateAssetInput, BuildError>
Consumes the builder and constructs a UpdateAssetInput.
Sourceimpl UpdateAssetInputBuilder
impl UpdateAssetInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateAssetOutput, SdkError<UpdateAssetError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateAssetOutput, SdkError<UpdateAssetError, HttpResponse>>
Sends a request with this input using the given client.