#[non_exhaustive]pub struct UpdateAssetInput {
pub agent_space_id: Option<String>,
pub asset_id: Option<String>,
pub metadata: Option<Document>,
pub content: Option<AssetContent>,
pub client_token: Option<String>,
}Expand description
Request structure for updating an asset
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier for the agent space containing the asset
asset_id: Option<String>The unique identifier of the asset to update
metadata: Option<Document>Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
content: Option<AssetContent>Optional content update. A single file adds or replaces one file; a zip replaces all files; a sourceUrl re-syncs from the original source.
client_token: Option<String>A unique, case-sensitive identifier used for idempotent asset update
Implementations
Sourceimpl UpdateAssetInput
impl UpdateAssetInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier for the agent space containing the asset
Sourcepub fn metadata(&self) -> Option<&Document>
pub fn metadata(&self) -> Option<&Document>
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
Sourcepub fn content(&self) -> Option<&AssetContent>
pub fn content(&self) -> Option<&AssetContent>
Optional content update. A single file adds or replaces one file; a zip replaces all files; a sourceUrl re-syncs from the original source.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier used for idempotent asset update
Sourceimpl UpdateAssetInput
impl UpdateAssetInput
Sourcepub fn builder() -> UpdateAssetInputBuilder
pub fn builder() -> UpdateAssetInputBuilder
Creates a new builder-style object to manufacture UpdateAssetInput.