Types for the UpdateAssetFile operation.
Modules
- builders
- Builders
Structs
- Update
Asset File - Orchestration and serialization glue logic for
UpdateAssetFile. - Update
Asset File Input Request structure for updating an asset file
- Update
Asset File Output Response structure for updating an asset file
Enums
- Update
Asset File Error - Error type for the
UpdateAssetFileErroroperation.