pub struct UpdateAssetFileFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateAssetFile.
Updates a file in an asset
Implementations
Sourceimpl UpdateAssetFileFluentBuilder
impl UpdateAssetFileFluentBuilder
Sourcepub fn as_input(&self) -> &UpdateAssetFileInputBuilder
pub fn as_input(&self) -> &UpdateAssetFileInputBuilder
Access the UpdateAssetFile as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateAssetFileOutput, SdkError<UpdateAssetFileError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateAssetFileOutput, SdkError<UpdateAssetFileError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateAssetFileOutput, UpdateAssetFileError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateAssetFileOutput, UpdateAssetFileError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space containing the asset
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space containing the asset
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space containing the asset
Sourcepub fn asset_id(self, input: impl Into<String>) -> Self
pub fn asset_id(self, input: impl Into<String>) -> Self
The unique identifier of the asset containing the file
Sourcepub fn set_asset_id(self, input: Option<String>) -> Self
pub fn set_asset_id(self, input: Option<String>) -> Self
The unique identifier of the asset containing the file
Sourcepub fn get_asset_id(&self) -> &Option<String>
pub fn get_asset_id(&self) -> &Option<String>
The unique identifier of the asset containing the file
Sourcepub fn path(self, input: impl Into<String>) -> Self
pub fn path(self, input: impl Into<String>) -> Self
The path of the file within the asset to update
Sourcepub fn set_path(self, input: Option<String>) -> Self
pub fn set_path(self, input: Option<String>) -> Self
The path of the file within the asset to update
Sourcepub fn content(self, input: AssetFileBody) -> Self
pub fn content(self, input: AssetFileBody) -> Self
Updated file content. If omitted, the existing content is unchanged.
Sourcepub fn set_content(self, input: Option<AssetFileBody>) -> Self
pub fn set_content(self, input: Option<AssetFileBody>) -> Self
Updated file content. If omitted, the existing content is unchanged.
Sourcepub fn get_content(&self) -> &Option<AssetFileBody>
pub fn get_content(&self) -> &Option<AssetFileBody>
Updated file content. If omitted, the existing content is unchanged.
Sourcepub fn metadata(self, input: Document) -> Self
pub fn metadata(self, input: Document) -> Self
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
Sourcepub fn set_metadata(self, input: Option<Document>) -> Self
pub fn set_metadata(self, input: Option<Document>) -> Self
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
Sourcepub fn get_metadata(&self) -> &Option<Document>
pub fn get_metadata(&self) -> &Option<Document>
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier used for idempotent asset file update
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier used for idempotent asset file update
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier used for idempotent asset file update