#[non_exhaustive]pub struct UpdateAssetFileInputBuilder { /* private fields */ }Expand description
A builder for UpdateAssetFileInput.
Implementations
Sourceimpl UpdateAssetFileInputBuilder
impl UpdateAssetFileInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space containing the asset
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space containing the asset
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space containing the asset
Sourcepub fn asset_id(self, input: impl Into<String>) -> Self
pub fn asset_id(self, input: impl Into<String>) -> Self
The unique identifier of the asset containing the file
This field is required.Sourcepub fn set_asset_id(self, input: Option<String>) -> Self
pub fn set_asset_id(self, input: Option<String>) -> Self
The unique identifier of the asset containing the file
Sourcepub fn get_asset_id(&self) -> &Option<String>
pub fn get_asset_id(&self) -> &Option<String>
The unique identifier of the asset containing the file
Sourcepub fn path(self, input: impl Into<String>) -> Self
pub fn path(self, input: impl Into<String>) -> Self
The path of the file within the asset to update
This field is required.Sourcepub fn set_path(self, input: Option<String>) -> Self
pub fn set_path(self, input: Option<String>) -> Self
The path of the file within the asset to update
Sourcepub fn content(self, input: AssetFileBody) -> Self
pub fn content(self, input: AssetFileBody) -> Self
Updated file content. If omitted, the existing content is unchanged.
Sourcepub fn set_content(self, input: Option<AssetFileBody>) -> Self
pub fn set_content(self, input: Option<AssetFileBody>) -> Self
Updated file content. If omitted, the existing content is unchanged.
Sourcepub fn get_content(&self) -> &Option<AssetFileBody>
pub fn get_content(&self) -> &Option<AssetFileBody>
Updated file content. If omitted, the existing content is unchanged.
Sourcepub fn metadata(self, input: Document) -> Self
pub fn metadata(self, input: Document) -> Self
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
Sourcepub fn set_metadata(self, input: Option<Document>) -> Self
pub fn set_metadata(self, input: Option<Document>) -> Self
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
Sourcepub fn get_metadata(&self) -> &Option<Document>
pub fn get_metadata(&self) -> &Option<Document>
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier used for idempotent asset file update
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier used for idempotent asset file update
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier used for idempotent asset file update
Sourcepub fn build(self) -> Result<UpdateAssetFileInput, BuildError>
pub fn build(self) -> Result<UpdateAssetFileInput, BuildError>
Consumes the builder and constructs a UpdateAssetFileInput.
Sourceimpl UpdateAssetFileInputBuilder
impl UpdateAssetFileInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateAssetFileOutput, SdkError<UpdateAssetFileError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateAssetFileOutput, SdkError<UpdateAssetFileError, HttpResponse>>
Sends a request with this input using the given client.