#[non_exhaustive]pub struct UpdateAssetFileInput {
pub agent_space_id: Option<String>,
pub asset_id: Option<String>,
pub path: Option<String>,
pub content: Option<AssetFileBody>,
pub metadata: Option<Document>,
pub client_token: Option<String>,
}Expand description
Request structure for updating an asset file
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier for the agent space containing the asset
asset_id: Option<String>The unique identifier of the asset containing the file
path: Option<String>The path of the file within the asset to update
content: Option<AssetFileBody>Updated file content. If omitted, the existing content is unchanged.
metadata: Option<Document>Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
client_token: Option<String>A unique, case-sensitive identifier used for idempotent asset file update
Implementations
Sourceimpl UpdateAssetFileInput
impl UpdateAssetFileInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier for the agent space containing the asset
Sourcepub fn content(&self) -> Option<&AssetFileBody>
pub fn content(&self) -> Option<&AssetFileBody>
Updated file content. If omitted, the existing content is unchanged.
Sourcepub fn metadata(&self) -> Option<&Document>
pub fn metadata(&self) -> Option<&Document>
Metadata fields to update. Only the fields present in this document are updated. Omitted fields retain their current values.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier used for idempotent asset file update
Sourceimpl UpdateAssetFileInput
impl UpdateAssetFileInput
Sourcepub fn builder() -> UpdateAssetFileInputBuilder
pub fn builder() -> UpdateAssetFileInputBuilder
Creates a new builder-style object to manufacture UpdateAssetFileInput.