#[non_exhaustive]pub struct UpdateAssociationOutputBuilder { /* private fields */ }Expand description
A builder for UpdateAssociationOutput.
Implementations
Sourceimpl UpdateAssociationOutputBuilder
impl UpdateAssociationOutputBuilder
Sourcepub fn association(self, input: Association) -> Self
pub fn association(self, input: Association) -> Self
Represents a service association within an AgentSpace, defining how the agent interacts with external services. This field is required.
Sourcepub fn set_association(self, input: Option<Association>) -> Self
pub fn set_association(self, input: Option<Association>) -> Self
Represents a service association within an AgentSpace, defining how the agent interacts with external services.
Sourcepub fn get_association(&self) -> &Option<Association>
pub fn get_association(&self) -> &Option<Association>
Represents a service association within an AgentSpace, defining how the agent interacts with external services.
Sourcepub fn webhook(self, input: GenericWebhook) -> Self
pub fn webhook(self, input: GenericWebhook) -> Self
Generic webhook configuration
Sourcepub fn set_webhook(self, input: Option<GenericWebhook>) -> Self
pub fn set_webhook(self, input: Option<GenericWebhook>) -> Self
Generic webhook configuration
Sourcepub fn get_webhook(&self) -> &Option<GenericWebhook>
pub fn get_webhook(&self) -> &Option<GenericWebhook>
Generic webhook configuration
Sourcepub fn build(self) -> UpdateAssociationOutput
pub fn build(self) -> UpdateAssociationOutput
Consumes the builder and constructs a UpdateAssociationOutput.