pub struct UpdateGoalFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateGoal.
Update an existing goal
Implementations
Sourceimpl UpdateGoalFluentBuilder
impl UpdateGoalFluentBuilder
Sourcepub fn as_input(&self) -> &UpdateGoalInputBuilder
pub fn as_input(&self) -> &UpdateGoalInputBuilder
Access the UpdateGoal as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateGoalOutput, SdkError<UpdateGoalError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateGoalOutput, SdkError<UpdateGoalError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateGoalOutput, UpdateGoalError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateGoalOutput, UpdateGoalError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space containing the goal
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space containing the goal
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space containing the goal
Sourcepub fn goal_id(self, input: impl Into<String>) -> Self
pub fn goal_id(self, input: impl Into<String>) -> Self
The unique identifier of the goal to update
Sourcepub fn set_goal_id(self, input: Option<String>) -> Self
pub fn set_goal_id(self, input: Option<String>) -> Self
The unique identifier of the goal to update
Sourcepub fn get_goal_id(&self) -> &Option<String>
pub fn get_goal_id(&self) -> &Option<String>
The unique identifier of the goal to update
Sourcepub fn evaluation_schedule(self, input: GoalScheduleInput) -> Self
pub fn evaluation_schedule(self, input: GoalScheduleInput) -> Self
Update goal schedule state
Sourcepub fn set_evaluation_schedule(self, input: Option<GoalScheduleInput>) -> Self
pub fn set_evaluation_schedule(self, input: Option<GoalScheduleInput>) -> Self
Update goal schedule state
Sourcepub fn get_evaluation_schedule(&self) -> &Option<GoalScheduleInput>
pub fn get_evaluation_schedule(&self) -> &Option<GoalScheduleInput>
Update goal schedule state
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
Client-provided token for idempotent operations
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
Client-provided token for idempotent operations
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
Client-provided token for idempotent operations