#[non_exhaustive]pub struct UpdateGoalInputBuilder { /* private fields */ }Expand description
A builder for UpdateGoalInput.
Implementations
Sourceimpl UpdateGoalInputBuilder
impl UpdateGoalInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space containing the goal This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space containing the goal
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space containing the goal
Sourcepub fn goal_id(self, input: impl Into<String>) -> Self
pub fn goal_id(self, input: impl Into<String>) -> Self
The unique identifier of the goal to update This field is required.
Sourcepub fn set_goal_id(self, input: Option<String>) -> Self
pub fn set_goal_id(self, input: Option<String>) -> Self
The unique identifier of the goal to update
Sourcepub fn get_goal_id(&self) -> &Option<String>
pub fn get_goal_id(&self) -> &Option<String>
The unique identifier of the goal to update
Sourcepub fn evaluation_schedule(self, input: GoalScheduleInput) -> Self
pub fn evaluation_schedule(self, input: GoalScheduleInput) -> Self
Update goal schedule state
Sourcepub fn set_evaluation_schedule(self, input: Option<GoalScheduleInput>) -> Self
pub fn set_evaluation_schedule(self, input: Option<GoalScheduleInput>) -> Self
Update goal schedule state
Sourcepub fn get_evaluation_schedule(&self) -> &Option<GoalScheduleInput>
pub fn get_evaluation_schedule(&self) -> &Option<GoalScheduleInput>
Update goal schedule state
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
Client-provided token for idempotent operations
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
Client-provided token for idempotent operations
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
Client-provided token for idempotent operations
Sourcepub fn build(self) -> Result<UpdateGoalInput, BuildError>
pub fn build(self) -> Result<UpdateGoalInput, BuildError>
Consumes the builder and constructs a UpdateGoalInput.
Sourceimpl UpdateGoalInputBuilder
impl UpdateGoalInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateGoalOutput, SdkError<UpdateGoalError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateGoalOutput, SdkError<UpdateGoalError, HttpResponse>>
Sends a request with this input using the given client.