#[non_exhaustive]pub struct UpdateGoalInput {
pub agent_space_id: Option<String>,
pub goal_id: Option<String>,
pub evaluation_schedule: Option<GoalScheduleInput>,
pub client_token: Option<String>,
}Expand description
Request structure for updating a goal
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier for the agent space containing the goal
goal_id: Option<String>The unique identifier of the goal to update
evaluation_schedule: Option<GoalScheduleInput>Update goal schedule state
client_token: Option<String>Client-provided token for idempotent operations
Implementations
Sourceimpl UpdateGoalInput
impl UpdateGoalInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier for the agent space containing the goal
Sourcepub fn evaluation_schedule(&self) -> Option<&GoalScheduleInput>
pub fn evaluation_schedule(&self) -> Option<&GoalScheduleInput>
Update goal schedule state
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Client-provided token for idempotent operations
Sourceimpl UpdateGoalInput
impl UpdateGoalInput
Sourcepub fn builder() -> UpdateGoalInputBuilder
pub fn builder() -> UpdateGoalInputBuilder
Creates a new builder-style object to manufacture UpdateGoalInput.