pub struct UpdateRecommendationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateRecommendation.
Updates an existing recommendation with new content, status, or metadata
Implementations
Sourceimpl UpdateRecommendationFluentBuilder
impl UpdateRecommendationFluentBuilder
Sourcepub fn as_input(&self) -> &UpdateRecommendationInputBuilder
pub fn as_input(&self) -> &UpdateRecommendationInputBuilder
Access the UpdateRecommendation as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateRecommendationOutput, SdkError<UpdateRecommendationError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateRecommendationOutput, SdkError<UpdateRecommendationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateRecommendationOutput, UpdateRecommendationError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateRecommendationOutput, UpdateRecommendationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space containing the recommendation
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space containing the recommendation
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space containing the recommendation
Sourcepub fn recommendation_id(self, input: impl Into<String>) -> Self
pub fn recommendation_id(self, input: impl Into<String>) -> Self
The unique identifier for the recommendation to update
Sourcepub fn set_recommendation_id(self, input: Option<String>) -> Self
pub fn set_recommendation_id(self, input: Option<String>) -> Self
The unique identifier for the recommendation to update
Sourcepub fn get_recommendation_id(&self) -> &Option<String>
pub fn get_recommendation_id(&self) -> &Option<String>
The unique identifier for the recommendation to update
Sourcepub fn status(self, input: RecommendationStatus) -> Self
pub fn status(self, input: RecommendationStatus) -> Self
Current status of the recommendation
Sourcepub fn set_status(self, input: Option<RecommendationStatus>) -> Self
pub fn set_status(self, input: Option<RecommendationStatus>) -> Self
Current status of the recommendation
Sourcepub fn get_status(&self) -> &Option<RecommendationStatus>
pub fn get_status(&self) -> &Option<RecommendationStatus>
Current status of the recommendation
Sourcepub fn additional_context(self, input: impl Into<String>) -> Self
pub fn additional_context(self, input: impl Into<String>) -> Self
Additional context for recommendation
Sourcepub fn set_additional_context(self, input: Option<String>) -> Self
pub fn set_additional_context(self, input: Option<String>) -> Self
Additional context for recommendation
Sourcepub fn get_additional_context(&self) -> &Option<String>
pub fn get_additional_context(&self) -> &Option<String>
Additional context for recommendation
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique token that ensures idempotency of the request
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique token that ensures idempotency of the request
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique token that ensures idempotency of the request