#[non_exhaustive]pub struct UpdateRecommendationInputBuilder { /* private fields */ }Expand description
A builder for UpdateRecommendationInput.
Implementations
Sourceimpl UpdateRecommendationInputBuilder
impl UpdateRecommendationInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space containing the recommendation This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space containing the recommendation
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space containing the recommendation
Sourcepub fn recommendation_id(self, input: impl Into<String>) -> Self
pub fn recommendation_id(self, input: impl Into<String>) -> Self
The unique identifier for the recommendation to update This field is required.
Sourcepub fn set_recommendation_id(self, input: Option<String>) -> Self
pub fn set_recommendation_id(self, input: Option<String>) -> Self
The unique identifier for the recommendation to update
Sourcepub fn get_recommendation_id(&self) -> &Option<String>
pub fn get_recommendation_id(&self) -> &Option<String>
The unique identifier for the recommendation to update
Sourcepub fn status(self, input: RecommendationStatus) -> Self
pub fn status(self, input: RecommendationStatus) -> Self
Current status of the recommendation
Sourcepub fn set_status(self, input: Option<RecommendationStatus>) -> Self
pub fn set_status(self, input: Option<RecommendationStatus>) -> Self
Current status of the recommendation
Sourcepub fn get_status(&self) -> &Option<RecommendationStatus>
pub fn get_status(&self) -> &Option<RecommendationStatus>
Current status of the recommendation
Sourcepub fn additional_context(self, input: impl Into<String>) -> Self
pub fn additional_context(self, input: impl Into<String>) -> Self
Additional context for recommendation
Sourcepub fn set_additional_context(self, input: Option<String>) -> Self
pub fn set_additional_context(self, input: Option<String>) -> Self
Additional context for recommendation
Sourcepub fn get_additional_context(&self) -> &Option<String>
pub fn get_additional_context(&self) -> &Option<String>
Additional context for recommendation
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique token that ensures idempotency of the request
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique token that ensures idempotency of the request
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique token that ensures idempotency of the request
Sourcepub fn build(self) -> Result<UpdateRecommendationInput, BuildError>
pub fn build(self) -> Result<UpdateRecommendationInput, BuildError>
Consumes the builder and constructs a UpdateRecommendationInput.
Sourceimpl UpdateRecommendationInputBuilder
impl UpdateRecommendationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateRecommendationOutput, SdkError<UpdateRecommendationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateRecommendationOutput, SdkError<UpdateRecommendationError, HttpResponse>>
Sends a request with this input using the given client.