#[non_exhaustive]pub struct UpdateRecommendationInput {
pub agent_space_id: Option<String>,
pub recommendation_id: Option<String>,
pub status: Option<RecommendationStatus>,
pub additional_context: Option<String>,
pub client_token: Option<String>,
}Expand description
Request structure for updating an existing recommendation
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier for the agent space containing the recommendation
recommendation_id: Option<String>The unique identifier for the recommendation to update
status: Option<RecommendationStatus>Current status of the recommendation
additional_context: Option<String>Additional context for recommendation
client_token: Option<String>A unique token that ensures idempotency of the request
Implementations
Sourceimpl UpdateRecommendationInput
impl UpdateRecommendationInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier for the agent space containing the recommendation
Sourcepub fn recommendation_id(&self) -> Option<&str>
pub fn recommendation_id(&self) -> Option<&str>
The unique identifier for the recommendation to update
Sourcepub fn status(&self) -> Option<&RecommendationStatus>
pub fn status(&self) -> Option<&RecommendationStatus>
Current status of the recommendation
Sourcepub fn additional_context(&self) -> Option<&str>
pub fn additional_context(&self) -> Option<&str>
Additional context for recommendation
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique token that ensures idempotency of the request
Sourceimpl UpdateRecommendationInput
impl UpdateRecommendationInput
Sourcepub fn builder() -> UpdateRecommendationInputBuilder
pub fn builder() -> UpdateRecommendationInputBuilder
Creates a new builder-style object to manufacture UpdateRecommendationInput.