pub struct UpdateTriggerFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateTrigger.
Updates the status of an existing Trigger
Implementations
Sourceimpl UpdateTriggerFluentBuilder
impl UpdateTriggerFluentBuilder
Sourcepub fn as_input(&self) -> &UpdateTriggerInputBuilder
pub fn as_input(&self) -> &UpdateTriggerInputBuilder
Access the UpdateTrigger as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateTriggerOutput, SdkError<UpdateTriggerError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateTriggerOutput, SdkError<UpdateTriggerError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateTriggerOutput, UpdateTriggerError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateTriggerOutput, UpdateTriggerError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space containing the Trigger
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space containing the Trigger
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space containing the Trigger
Sourcepub fn trigger_id(self, input: impl Into<String>) -> Self
pub fn trigger_id(self, input: impl Into<String>) -> Self
The unique identifier of the Trigger to update
Sourcepub fn set_trigger_id(self, input: Option<String>) -> Self
pub fn set_trigger_id(self, input: Option<String>) -> Self
The unique identifier of the Trigger to update
Sourcepub fn get_trigger_id(&self) -> &Option<String>
pub fn get_trigger_id(&self) -> &Option<String>
The unique identifier of the Trigger to update
Sourcepub fn set_status(self, input: Option<String>) -> Self
pub fn set_status(self, input: Option<String>) -> Self
The new status for the Trigger
Sourcepub fn get_status(&self) -> &Option<String>
pub fn get_status(&self) -> &Option<String>
The new status for the Trigger
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier used for idempotent Trigger update
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier used for idempotent Trigger update
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier used for idempotent Trigger update