pub struct Client { /* private fields */ }Expand description
Client for AWS DevOps Agent Service
Client for invoking operations on AWS DevOps Agent Service. Each operation on AWS DevOps Agent Service is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Constructing a Client
A Config is required to construct a client. For most use cases, the aws-config
crate should be used to automatically resolve this config using
aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared
across multiple different AWS SDK clients. This config resolution process can be customized
by calling aws_config::from_env() instead, which returns a ConfigLoader that uses
the builder pattern to customize the default config.
In the simplest case, creating a client looks as follows:
let config = aws_config::load_from_env().await;
let client = aws_sdk_devopsagent::Client::new(&config);Occasionally, SDKs may have additional service-specific values that can be set on the Config that
is absent from SdkConfig, or slightly different settings for a specific client may be desired.
The Builder struct implements From<&SdkConfig>, so setting these specific settings can be
done as follows:
let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_devopsagent::config::Builder::from(&sdk_config)
.some_service_specific_setting("value")
.build();See the aws-config docs and Config for more information on customizing configuration.
Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.
Using the Client
A client has a function for every operation that can be performed by the service.
For example, the AllowVendedLogDeliveryForResource operation has
a Client::allow_vended_log_delivery_for_resource, function which returns a builder for that operation.
The fluent builder ultimately has a send() function that returns an async future that
returns a result, as illustrated below:
let result = client.allow_vended_log_delivery_for_resource()
.resource_arn_being_authorized("example")
.send()
.await;The underlying HTTP requests that get made by this can be modified with the customize_operation
function on the fluent builder. See the customize module for more
information.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn allow_vended_log_delivery_for_resource(
&self,
) -> AllowVendedLogDeliveryForResourceFluentBuilder
pub fn allow_vended_log_delivery_for_resource( &self, ) -> AllowVendedLogDeliveryForResourceFluentBuilder
Constructs a fluent builder for the AllowVendedLogDeliveryForResource operation.
- The fluent builder is configurable:
resource_arn_being_authorized(impl Into<String>)/set_resource_arn_being_authorized(Option<String>):
required: true
The ARN of the resource being authorized for vended log delivery.delivery_source_arn(impl Into<String>)/set_delivery_source_arn(Option<String>):
required: true
The ARN of the delivery source for vended log delivery.log_type(impl Into<String>)/set_log_type(Option<String>):
required: false
The type of log to be delivered.
- On success, responds with
AllowVendedLogDeliveryForResourceOutputwith field(s):message(Option<String>): A message describing the result of the authorization operation.
- On failure, responds with
SdkError<AllowVendedLogDeliveryForResourceError>
Sourceimpl Client
impl Client
Sourcepub fn associate_service(&self) -> AssociateServiceFluentBuilder
pub fn associate_service(&self) -> AssociateServiceFluentBuilder
Constructs a fluent builder for the AssociateService operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier of the AgentSpaceservice_id(impl Into<String>)/set_service_id(Option<String>):
required: true
The unique identifier of the service.configuration(ServiceConfiguration)/set_configuration(Option<ServiceConfiguration>):
required: true
The configuration that directs how AgentSpace interacts with the given service.
- On success, responds with
AssociateServiceOutputwith field(s):association(Option<Association>): Represents a service association within an AgentSpace, defining how the agent interacts with external services.webhook(Option<GenericWebhook>): Generic webhook configuration
- On failure, responds with
SdkError<AssociateServiceError>
Sourceimpl Client
impl Client
Sourcepub fn create_agent_space(&self) -> CreateAgentSpaceFluentBuilder
pub fn create_agent_space(&self) -> CreateAgentSpaceFluentBuilder
Constructs a fluent builder for the CreateAgentSpace operation.
- The fluent builder is configurable:
name(impl Into<String>)/set_name(Option<String>):
required: true
The name of the AgentSpace.description(impl Into<String>)/set_description(Option<String>):
required: false
The description of the AgentSpace.locale(impl Into<String>)/set_locale(Option<String>):
required: false
The locale for the AgentSpace, which determines the language used in agent responses.kms_key_arn(impl Into<String>)/set_kms_key_arn(Option<String>):
required: false
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.client_token(impl Into<String>)/set_client_token(Option<String>):
required: false
Client-provided token to ensure request idempotency. When the same token is provided in subsequent calls, the same response is returned within a 8-hour window.tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: false
Tags to add to the AgentSpace at creation time.
- On success, responds with
CreateAgentSpaceOutputwith field(s):agent_space(Option<AgentSpace>): Represents a complete AgentSpace with all its properties, timestamps, encryption settings, and unique identifier.tags(Option<HashMap::<String, String>>): Tags associated with the created AgentSpace.
- On failure, responds with
SdkError<CreateAgentSpaceError>
Sourceimpl Client
impl Client
Sourcepub fn create_backlog_task(&self) -> CreateBacklogTaskFluentBuilder
pub fn create_backlog_task(&self) -> CreateBacklogTaskFluentBuilder
Constructs a fluent builder for the CreateBacklogTask operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier for the agent space where the task will be createdreference(ReferenceInput)/set_reference(Option<ReferenceInput>):
required: false
Optional reference information for the tasktask_type(TaskType)/set_task_type(Option<TaskType>):
required: true
The type of task being createdtitle(impl Into<String>)/set_title(Option<String>):
required: true
The title of the backlog taskdescription(impl Into<String>)/set_description(Option<String>):
required: false
Optional detailed description of the taskpriority(Priority)/set_priority(Option<Priority>):
required: true
The priority level of the taskclient_token(impl Into<String>)/set_client_token(Option<String>):
required: false
Client-provided token for idempotent operations
- On success, responds with
CreateBacklogTaskOutputwith field(s):task(Option<Task>): The newly created task object
- On failure, responds with
SdkError<CreateBacklogTaskError>
Sourceimpl Client
impl Client
Sourcepub fn create_chat(&self) -> CreateChatFluentBuilder
pub fn create_chat(&self) -> CreateChatFluentBuilder
Constructs a fluent builder for the CreateChat operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)user_id(impl Into<String>)/set_user_id(Option<String>):
required: true
The user identifier for the chatuser_type(UserType)/set_user_type(Option<UserType>):
required: false
The authentication type of the user
- On success, responds with
CreateChatOutputwith field(s):execution_id(String): The unique identifier for the created executioncreated_at(DateTime): Timestamp when the chat was created
- On failure, responds with
SdkError<CreateChatError>
Sourceimpl Client
impl Client
Sourcepub fn create_private_connection(&self) -> CreatePrivateConnectionFluentBuilder
pub fn create_private_connection(&self) -> CreatePrivateConnectionFluentBuilder
Constructs a fluent builder for the CreatePrivateConnection operation.
- The fluent builder is configurable:
name(impl Into<String>)/set_name(Option<String>):
required: true
Unique name for this Private Connection within the account.mode(PrivateConnectionMode)/set_mode(Option<PrivateConnectionMode>):
required: true
Private Connection mode configuration.tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: false
Tags to add to the Private Connection at creation time.
- On success, responds with
CreatePrivateConnectionOutputwith field(s):name(String): The name of the Private Connection.r#type(PrivateConnectionType): The type of the Private Connection.resource_gateway_id(Option<String>): The service-managed Resource Gateway ARN. Only present for service-managed Private Connections.host_address(Option<String>): IP address or DNS name of the target resource. Only present for service-managed Private Connections.vpc_id(Option<String>): VPC identifier of the service-managed Resource Gateway. Only present for service-managed Private Connections.resource_configuration_id(Option<String>): The Resource Configuration ARN. Only present for self-managed Private Connections.status(PrivateConnectionStatus): The status of the Private Connection.certificate_expiry_time(Option<DateTime>): The expiry time of the certificate associated with the Private Connection. Only present when a certificate is associated.tags(Option<HashMap::<String, String>>): Tags associated with the created Private Connection.
- On failure, responds with
SdkError<CreatePrivateConnectionError>
Sourceimpl Client
impl Client
Sourcepub fn delete_agent_space(&self) -> DeleteAgentSpaceFluentBuilder
pub fn delete_agent_space(&self) -> DeleteAgentSpaceFluentBuilder
Constructs a fluent builder for the DeleteAgentSpace operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier of the AgentSpace
- On success, responds with
DeleteAgentSpaceOutput - On failure, responds with
SdkError<DeleteAgentSpaceError>
Sourceimpl Client
impl Client
Sourcepub fn delete_private_connection(&self) -> DeletePrivateConnectionFluentBuilder
pub fn delete_private_connection(&self) -> DeletePrivateConnectionFluentBuilder
Constructs a fluent builder for the DeletePrivateConnection operation.
- The fluent builder is configurable:
name(impl Into<String>)/set_name(Option<String>):
required: true
The name of the Private Connection.
- On success, responds with
DeletePrivateConnectionOutputwith field(s):name(String): The name of the Private Connection.status(PrivateConnectionStatus): The status of the Private Connection.
- On failure, responds with
SdkError<DeletePrivateConnectionError>
Sourceimpl Client
impl Client
Sourcepub fn deregister_service(&self) -> DeregisterServiceFluentBuilder
pub fn deregister_service(&self) -> DeregisterServiceFluentBuilder
Constructs a fluent builder for the DeregisterService operation.
- The fluent builder is configurable:
service_id(impl Into<String>)/set_service_id(Option<String>):
required: true
The service id to deregister. A service can only be deregistered if it is not associated with any AgentSpace.
- On success, responds with
DeregisterServiceOutput - On failure, responds with
SdkError<DeregisterServiceError>
Sourceimpl Client
impl Client
Sourcepub fn describe_private_connection(
&self,
) -> DescribePrivateConnectionFluentBuilder
pub fn describe_private_connection( &self, ) -> DescribePrivateConnectionFluentBuilder
Constructs a fluent builder for the DescribePrivateConnection operation.
- The fluent builder is configurable:
name(impl Into<String>)/set_name(Option<String>):
required: true
The name of the Private Connection.
- On success, responds with
DescribePrivateConnectionOutputwith field(s):name(String): The name of the Private Connection.r#type(PrivateConnectionType): The type of the Private Connection.resource_gateway_id(Option<String>): The service-managed Resource Gateway ARN. Only present for service-managed Private Connections.host_address(Option<String>): IP address or DNS name of the target resource. Only present for service-managed Private Connections.vpc_id(Option<String>): VPC identifier of the service-managed Resource Gateway. Only present for service-managed Private Connections.resource_configuration_id(Option<String>): The Resource Configuration ARN. Only present for self-managed Private Connections.status(PrivateConnectionStatus): The status of the Private Connection.certificate_expiry_time(Option<DateTime>): The expiry time of the certificate associated with the Private Connection. Only present when a certificate is associated.tags(Option<HashMap::<String, String>>): Tags associated with the Private Connection.
- On failure, responds with
SdkError<DescribePrivateConnectionError>
Sourceimpl Client
impl Client
Sourcepub fn disable_operator_app(&self) -> DisableOperatorAppFluentBuilder
pub fn disable_operator_app(&self) -> DisableOperatorAppFluentBuilder
Constructs a fluent builder for the DisableOperatorApp operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier of the AgentSpaceauth_flow(AuthFlow)/set_auth_flow(Option<AuthFlow>):
required: false
The authentication flow configured for the operator App. e.g. idc
- On success, responds with
DisableOperatorAppOutput - On failure, responds with
SdkError<DisableOperatorAppError>
Sourceimpl Client
impl Client
Sourcepub fn disassociate_service(&self) -> DisassociateServiceFluentBuilder
pub fn disassociate_service(&self) -> DisassociateServiceFluentBuilder
Constructs a fluent builder for the DisassociateService operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier of the AgentSpaceassociation_id(impl Into<String>)/set_association_id(Option<String>):
required: true
The unique identifier of the given association.
- On success, responds with
DisassociateServiceOutput - On failure, responds with
SdkError<DisassociateServiceError>
Sourceimpl Client
impl Client
Sourcepub fn enable_operator_app(&self) -> EnableOperatorAppFluentBuilder
pub fn enable_operator_app(&self) -> EnableOperatorAppFluentBuilder
Constructs a fluent builder for the EnableOperatorApp operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier of the AgentSpaceauth_flow(AuthFlow)/set_auth_flow(Option<AuthFlow>):
required: true
The authentication flow configured for the operator App. e.g. iam or idcoperator_app_role_arn(impl Into<String>)/set_operator_app_role_arn(Option<String>):
required: true
The IAM role end users assume to access AIDevOps APIsidc_instance_arn(impl Into<String>)/set_idc_instance_arn(Option<String>):
required: false
The IdC instance Arn used to create an IdC auth applicationissuer_url(impl Into<String>)/set_issuer_url(Option<String>):
required: false
The OIDC issuer URL of the external Identity Provideridp_client_id(impl Into<String>)/set_idp_client_id(Option<String>):
required: false
The OIDC client ID for the IdP applicationidp_client_secret(impl Into<String>)/set_idp_client_secret(Option<String>):
required: false
The OIDC client secret for the IdP applicationprovider(impl Into<String>)/set_provider(Option<String>):
required: false
The Identity Provider name (e.g., Entra, Okta, Google)
- On success, responds with
EnableOperatorAppOutputwith field(s):agent_space_id(String): The unique identifier of the AgentSpaceiam(Option<IamAuthConfiguration>): Configuration for IAM-based authentication flow for the Operator App.idc(Option<IdcAuthConfiguration>): Configuration for AWS Identity Center (IdC) authentication flow for the Operator App.idp(Option<IdpAuthConfiguration>): Configuration for external Identity Provider OIDC authentication flow for the Operator App.
- On failure, responds with
SdkError<EnableOperatorAppError>
Sourceimpl Client
impl Client
Sourcepub fn get_account_usage(&self) -> GetAccountUsageFluentBuilder
pub fn get_account_usage(&self) -> GetAccountUsageFluentBuilder
Constructs a fluent builder for the GetAccountUsage operation.
- The fluent builder takes no input, just
sendit. - On success, responds with
GetAccountUsageOutputwith field(s):monthly_account_investigation_hours(Option<UsageMetric>): Monthly investigation hours usage and limit for an accountmonthly_account_evaluation_hours(Option<UsageMetric>): Monthly evaluation hours usage and limit for an accountmonthly_account_system_learning_hours(Option<UsageMetric>): Monthly system learning hours usage and limit for an accountmonthly_account_on_demand_hours(Option<UsageMetric>): Monthly on-demand hours usage and limit for an accountusage_period_start_time(DateTime): The start time of the usage tracking periodusage_period_end_time(DateTime): The end time of the usage tracking period
- On failure, responds with
SdkError<GetAccountUsageError>
Sourceimpl Client
impl Client
Sourcepub fn get_agent_space(&self) -> GetAgentSpaceFluentBuilder
pub fn get_agent_space(&self) -> GetAgentSpaceFluentBuilder
Constructs a fluent builder for the GetAgentSpace operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier of the AgentSpace
- On success, responds with
GetAgentSpaceOutputwith field(s):agent_space(Option<AgentSpace>): Represents a complete AgentSpace with all its properties, timestamps, encryption settings, and unique identifier.tags(Option<HashMap::<String, String>>): Tags associated with the AgentSpace.
- On failure, responds with
SdkError<GetAgentSpaceError>
Sourceimpl Client
impl Client
Sourcepub fn get_association(&self) -> GetAssociationFluentBuilder
pub fn get_association(&self) -> GetAssociationFluentBuilder
Constructs a fluent builder for the GetAssociation operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier of the AgentSpaceassociation_id(impl Into<String>)/set_association_id(Option<String>):
required: true
The unique identifier of the given association.
- On success, responds with
GetAssociationOutputwith field(s):association(Option<Association>): Represents a service association within an AgentSpace, defining how the agent interacts with external services.
- On failure, responds with
SdkError<GetAssociationError>
Sourceimpl Client
impl Client
Sourcepub fn get_backlog_task(&self) -> GetBacklogTaskFluentBuilder
pub fn get_backlog_task(&self) -> GetBacklogTaskFluentBuilder
Constructs a fluent builder for the GetBacklogTask operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier for the agent space containing the tasktask_id(impl Into<String>)/set_task_id(Option<String>):
required: true
The unique identifier of the task to retrieve
- On success, responds with
GetBacklogTaskOutputwith field(s):task(Option<Task>): The requested task object
- On failure, responds with
SdkError<GetBacklogTaskError>
Sourceimpl Client
impl Client
Sourcepub fn get_operator_app(&self) -> GetOperatorAppFluentBuilder
pub fn get_operator_app(&self) -> GetOperatorAppFluentBuilder
Constructs a fluent builder for the GetOperatorApp operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier of the AgentSpace
- On success, responds with
GetOperatorAppOutputwith field(s):iam(Option<IamAuthConfiguration>): Configuration for IAM-based authentication flow for the Operator App.idc(Option<IdcAuthConfiguration>): Configuration for AWS Identity Center (IdC) authentication flow for the Operator App.idp(Option<IdpAuthConfiguration>): Configuration for external Identity Provider OIDC authentication flow for the Operator App.
- On failure, responds with
SdkError<GetOperatorAppError>
Sourceimpl Client
impl Client
Sourcepub fn get_recommendation(&self) -> GetRecommendationFluentBuilder
pub fn get_recommendation(&self) -> GetRecommendationFluentBuilder
Constructs a fluent builder for the GetRecommendation operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier for the agent space containing the recommendationrecommendation_id(impl Into<String>)/set_recommendation_id(Option<String>):
required: true
The unique identifier for the recommendation to retrieverecommendation_version(i64)/set_recommendation_version(Option<i64>):
required: false
Specific version of the recommendation to retrieve. If not specified, returns the latest version.
- On success, responds with
GetRecommendationOutputwith field(s):recommendation(Option<Recommendation>): The requested recommendation
- On failure, responds with
SdkError<GetRecommendationError>
Sourceimpl Client
impl Client
Sourcepub fn get_service(&self) -> GetServiceFluentBuilder
pub fn get_service(&self) -> GetServiceFluentBuilder
Constructs a fluent builder for the GetService operation.
- The fluent builder is configurable:
service_id(impl Into<String>)/set_service_id(Option<String>):
required: true
The unique identifier of the given service.
- On success, responds with
GetServiceOutputwith field(s):service(Option<RegisteredService>): Represents a registered service with its configuration and accessible resources.tags(Option<HashMap::<String, String>>): Tags associated with the Service.
- On failure, responds with
SdkError<GetServiceError>
Sourceimpl Client
impl Client
Sourcepub fn list_agent_spaces(&self) -> ListAgentSpacesFluentBuilder
pub fn list_agent_spaces(&self) -> ListAgentSpacesFluentBuilder
Constructs a fluent builder for the ListAgentSpaces operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
max_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of results to return in a single call.next_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for the next page of results.
- On success, responds with
ListAgentSpacesOutputwith field(s):next_token(Option<String>): Token to retrieve the next page of results, if there are more results.agent_spaces(Vec::<AgentSpace>): The list of AgentSpaces.
- On failure, responds with
SdkError<ListAgentSpacesError>
Sourceimpl Client
impl Client
Sourcepub fn list_associations(&self) -> ListAssociationsFluentBuilder
pub fn list_associations(&self) -> ListAssociationsFluentBuilder
Constructs a fluent builder for the ListAssociations operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier of the AgentSpacemax_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of results to return in a single call.next_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for the next page of results.filter_service_types(impl Into<String>)/set_filter_service_types(Option<String>):
required: false
A comma-separated list of service types to filter list associations output
- On success, responds with
ListAssociationsOutputwith field(s):next_token(Option<String>): Token to retrieve the next page of results, if there are more results.associations(Vec::<Association>): The list of associations.
- On failure, responds with
SdkError<ListAssociationsError>
Sourceimpl Client
impl Client
Sourcepub fn list_backlog_tasks(&self) -> ListBacklogTasksFluentBuilder
pub fn list_backlog_tasks(&self) -> ListBacklogTasksFluentBuilder
Constructs a fluent builder for the ListBacklogTasks operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier for the agent space containing the tasksfilter(TaskFilter)/set_filter(Option<TaskFilter>):
required: false
Filter criteria to apply when listing tasks Filtering restrictions: - Each filter field list is limited to a single value - Filtering by Priority and Status at the same time when not filtering by Type is not permitted - Timestamp filters (createdAfter, createdBefore) can be combined with other filters when not sorting by prioritylimit(i32)/set_limit(Option<i32>):
required: false
Maximum number of tasks to return in a single response (1-1000, default: 100)next_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for retrieving the next page of resultssort_field(TaskSortField)/set_sort_field(Option<TaskSortField>):
required: false
Field to sort by Sorting restrictions: - Only sorting on createdAt is supported when using priority or status filters alone. - Sorting by priority is not supported when using Timestamp filters (createdAfter, createdBefore)order(TaskSortOrder)/set_order(Option<TaskSortOrder>):
required: false
Sort order for the tasks based on sortField (default: DESC)
- On success, responds with
ListBacklogTasksOutputwith field(s):tasks(Vec::<Task>): List of backlog tasksnext_token(Option<String>): Token for retrieving the next page of results, if more results are available
- On failure, responds with
SdkError<ListBacklogTasksError>
Sourceimpl Client
impl Client
Sourcepub fn list_chats(&self) -> ListChatsFluentBuilder
pub fn list_chats(&self) -> ListChatsFluentBuilder
Constructs a fluent builder for the ListChats operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)user_id(impl Into<String>)/set_user_id(Option<String>):
required: true
The user identifier to list chats formax_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of results to returnnext_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for pagination
- On success, responds with
ListChatsOutputwith field(s):executions(Vec::<ChatExecution>): List of recent chat executionsnext_token(Option<String>): Token for retrieving the next page of results
- On failure, responds with
SdkError<ListChatsError>
Sourceimpl Client
impl Client
Sourcepub fn list_executions(&self) -> ListExecutionsFluentBuilder
pub fn list_executions(&self) -> ListExecutionsFluentBuilder
Constructs a fluent builder for the ListExecutions operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier for the agent spacetask_id(impl Into<String>)/set_task_id(Option<String>):
required: true
The unique identifier of the task whose executions to retrievelimit(i32)/set_limit(Option<i32>):
required: false
Maximum number of executions to returnnext_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for pagination to retrieve the next set of results
- On success, responds with
ListExecutionsOutputwith field(s):executions(Vec::<Execution>): List of executionsnext_token(Option<String>): Token for retrieving the next page of results, if available
- On failure, responds with
SdkError<ListExecutionsError>
Sourceimpl Client
impl Client
Sourcepub fn list_goals(&self) -> ListGoalsFluentBuilder
pub fn list_goals(&self) -> ListGoalsFluentBuilder
Constructs a fluent builder for the ListGoals operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier for the agent spacestatus(GoalStatus)/set_status(Option<GoalStatus>):
required: false
Filter goals by goal statusgoal_type(GoalType)/set_goal_type(Option<GoalType>):
required: false
Filter goals by goal typelimit(i32)/set_limit(Option<i32>):
required: false
Maximum number of goals to returnnext_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Pagination token for the next set of results
- On success, responds with
ListGoalsOutputwith field(s):goals(Vec::<Goal>): List of goals matching the criterianext_token(Option<String>): Pagination token for the next set of results
- On failure, responds with
SdkError<ListGoalsError>
Sourceimpl Client
impl Client
Sourcepub fn list_journal_records(&self) -> ListJournalRecordsFluentBuilder
pub fn list_journal_records(&self) -> ListJournalRecordsFluentBuilder
Constructs a fluent builder for the ListJournalRecords operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier for the agent space containing the executionexecution_id(impl Into<String>)/set_execution_id(Option<String>):
required: true
The unique identifier of the execution whose journal records to retrievelimit(i32)/set_limit(Option<i32>):
required: false
Maximum number of records to return in a single response (1-100, default: 100)next_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for retrieving the next page of resultsrecord_type(impl Into<String>)/set_record_type(Option<String>):
required: false
Filter records by type (empty string returns all types)order(OrderType)/set_order(Option<OrderType>):
required: false
Sort order for the records based on timestamp (default: DESC)
- On success, responds with
ListJournalRecordsOutputwith field(s):records(Vec::<JournalRecord>): List of journal records matching the request criterianext_token(Option<String>): Token for retrieving the next page of results, if more results are available
- On failure, responds with
SdkError<ListJournalRecordsError>
Sourceimpl Client
impl Client
Sourcepub fn list_pending_messages(&self) -> ListPendingMessagesFluentBuilder
pub fn list_pending_messages(&self) -> ListPendingMessagesFluentBuilder
Constructs a fluent builder for the ListPendingMessages operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)execution_id(impl Into<String>)/set_execution_id(Option<String>):
required: true
The unique identifier of the execution whose journal records to retrieve
- On success, responds with
ListPendingMessagesOutputwith field(s):agent_space_id(String): Unique identifier for an agent space (allows alphanumeric characters and hyphens; 1-64 characters)execution_id(String): The unique identifier for the execution.messages(Vec::<PendingMessage>): The list of pending messages for the execution.created_at(DateTime): Timestamp when the pending messages were created.
- On failure, responds with
SdkError<ListPendingMessagesError>
Sourceimpl Client
impl Client
Sourcepub fn list_private_connections(&self) -> ListPrivateConnectionsFluentBuilder
pub fn list_private_connections(&self) -> ListPrivateConnectionsFluentBuilder
Constructs a fluent builder for the ListPrivateConnections operation.
- The fluent builder takes no input, just
sendit. - On success, responds with
ListPrivateConnectionsOutputwith field(s):private_connections(Vec::<PrivateConnectionSummary>): The list of Private Connections.
- On failure, responds with
SdkError<ListPrivateConnectionsError>
Sourceimpl Client
impl Client
Sourcepub fn list_recommendations(&self) -> ListRecommendationsFluentBuilder
pub fn list_recommendations(&self) -> ListRecommendationsFluentBuilder
Constructs a fluent builder for the ListRecommendations operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier for the agent space containing the recommendationstask_id(impl Into<String>)/set_task_id(Option<String>):
required: false
Optional task ID to filter recommendations by specific taskgoal_id(impl Into<String>)/set_goal_id(Option<String>):
required: false
Optional goal ID to filter recommendations by specific goalstatus(RecommendationStatus)/set_status(Option<RecommendationStatus>):
required: false
Optional status to filter recommendations by their current statuspriority(RecommendationPriority)/set_priority(Option<RecommendationPriority>):
required: false
Optional priority to filter recommendations by priority levellimit(i32)/set_limit(Option<i32>):
required: false
Maximum number of recommendations to return in a single responsenext_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for retrieving the next page of results
- On success, responds with
ListRecommendationsOutputwith field(s):recommendations(Vec::<Recommendation>): List of recommendations matching the request criterianext_token(Option<String>): Token for retrieving the next page of results, if more results are available
- On failure, responds with
SdkError<ListRecommendationsError>
Sourceimpl Client
impl Client
Sourcepub fn list_services(&self) -> ListServicesFluentBuilder
pub fn list_services(&self) -> ListServicesFluentBuilder
Constructs a fluent builder for the ListServices operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
max_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of results to return in a single call.next_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for the next page of results.filter_service_type(Service)/set_filter_service_type(Option<Service>):
required: false
Optional filter to list only services of a specific type.
- On success, responds with
ListServicesOutputwith field(s):next_token(Option<String>): Token to retrieve the next page of results, if there are more results.services(Vec::<RegisteredService>): List of registered services.
- On failure, responds with
SdkError<ListServicesError>
Sourceimpl Client
impl Client
Constructs a fluent builder for the ListTagsForResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: true
The ARN of the resource.
- On success, responds with
ListTagsForResourceOutputwith field(s):tags(HashMap::<String, String>): Tags associated with the resource.
- On failure, responds with
SdkError<ListTagsForResourceError>
Sourceimpl Client
impl Client
Sourcepub fn list_webhooks(&self) -> ListWebhooksFluentBuilder
pub fn list_webhooks(&self) -> ListWebhooksFluentBuilder
Constructs a fluent builder for the ListWebhooks operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier of the AgentSpaceassociation_id(impl Into<String>)/set_association_id(Option<String>):
required: true
The unique identifier of the given association.
- On success, responds with
ListWebhooksOutputwith field(s):webhooks(Vec::<Webhook>): The list of association webhooks.
- On failure, responds with
SdkError<ListWebhooksError>
Sourceimpl Client
impl Client
Sourcepub fn register_service(&self) -> RegisterServiceFluentBuilder
pub fn register_service(&self) -> RegisterServiceFluentBuilder
Constructs a fluent builder for the RegisterService operation.
- The fluent builder is configurable:
service(PostRegisterServiceSupportedService)/set_service(Option<PostRegisterServiceSupportedService>):
required: true
Services that can be registered via the post-registration API (excludes OAuth 3LO services).service_details(ServiceDetails)/set_service_details(Option<ServiceDetails>):
required: true
Service-specific authorization configuration parameterskms_key_arn(impl Into<String>)/set_kms_key_arn(Option<String>):
required: false
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.private_connection_name(impl Into<String>)/set_private_connection_name(Option<String>):
required: false
The name of the private connection to use for VPC connectivity.name(impl Into<String>)/set_name(Option<String>):
required: false
The display name for the service registration.tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: false
Tags to add to the Service at registration time.
- On success, responds with
RegisterServiceOutputwith field(s):service_id(Option<String>): Service ID - present when registration is complete, absent when additional steps are requiredadditional_step(Option<AdditionalServiceRegistrationStep>): Indicates if additional steps are required to complete service registration (e.g., 3-legged OAuth)kms_key_arn(Option<String>): The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.tags(Option<HashMap::<String, String>>): Tags associated with the registered Service.
- On failure, responds with
SdkError<RegisterServiceError>
Sourceimpl Client
impl Client
Sourcepub fn send_message(&self) -> SendMessageFluentBuilder
pub fn send_message(&self) -> SendMessageFluentBuilder
Constructs a fluent builder for the SendMessage operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The agent space identifierexecution_id(impl Into<String>)/set_execution_id(Option<String>):
required: true
The execution identifier for the chat sessioncontent(impl Into<String>)/set_content(Option<String>):
required: true
The user message contentcontext(SendMessageContext)/set_context(Option<SendMessageContext>):
required: false
Optional context for the messageuser_id(impl Into<String>)/set_user_id(Option<String>):
required: true
Required user identifier
- On success, responds with
SendMessageOutputwith field(s):events(EventReceiver<SendMessageEvents, SendMessageEventsError>): The stream of chat message events
- On failure, responds with
SdkError<SendMessageError>
Sourceimpl Client
impl Client
Sourcepub fn tag_resource(&self) -> TagResourceFluentBuilder
pub fn tag_resource(&self) -> TagResourceFluentBuilder
Constructs a fluent builder for the TagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: true
The ARN of the resource to tag.tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: true
Tags to add to the resource.
- On success, responds with
TagResourceOutput - On failure, responds with
SdkError<TagResourceError>
Sourceimpl Client
impl Client
Sourcepub fn untag_resource(&self) -> UntagResourceFluentBuilder
pub fn untag_resource(&self) -> UntagResourceFluentBuilder
Constructs a fluent builder for the UntagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: true
The ARN of the resource to untag.tag_keys(impl Into<String>)/set_tag_keys(Option<Vec::<String>>):
required: true
Tag keys to remove.
- On success, responds with
UntagResourceOutput - On failure, responds with
SdkError<UntagResourceError>
Sourceimpl Client
impl Client
Sourcepub fn update_agent_space(&self) -> UpdateAgentSpaceFluentBuilder
pub fn update_agent_space(&self) -> UpdateAgentSpaceFluentBuilder
Constructs a fluent builder for the UpdateAgentSpace operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier of the AgentSpacename(impl Into<String>)/set_name(Option<String>):
required: false
The updated name of the AgentSpace.description(impl Into<String>)/set_description(Option<String>):
required: false
The updated description of the AgentSpace.locale(impl Into<String>)/set_locale(Option<String>):
required: false
The updated locale for the AgentSpace, which determines the language used in agent responses.
- On success, responds with
UpdateAgentSpaceOutputwith field(s):agent_space(Option<AgentSpace>): Represents a complete AgentSpace with all its properties, timestamps, encryption settings, and unique identifier.
- On failure, responds with
SdkError<UpdateAgentSpaceError>
Sourceimpl Client
impl Client
Sourcepub fn update_association(&self) -> UpdateAssociationFluentBuilder
pub fn update_association(&self) -> UpdateAssociationFluentBuilder
Constructs a fluent builder for the UpdateAssociation operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier of the AgentSpaceassociation_id(impl Into<String>)/set_association_id(Option<String>):
required: true
The unique identifier of the given association.configuration(ServiceConfiguration)/set_configuration(Option<ServiceConfiguration>):
required: true
The configuration that directs how AgentSpace interacts with the given service. The entire configuration is replaced on update.
- On success, responds with
UpdateAssociationOutputwith field(s):association(Option<Association>): Represents a service association within an AgentSpace, defining how the agent interacts with external services.webhook(Option<GenericWebhook>): Generic webhook configuration
- On failure, responds with
SdkError<UpdateAssociationError>
Sourceimpl Client
impl Client
Sourcepub fn update_backlog_task(&self) -> UpdateBacklogTaskFluentBuilder
pub fn update_backlog_task(&self) -> UpdateBacklogTaskFluentBuilder
Constructs a fluent builder for the UpdateBacklogTask operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier for the agent space containing the tasktask_id(impl Into<String>)/set_task_id(Option<String>):
required: true
The unique identifier of the task to updatetask_status(TaskStatus)/set_task_status(Option<TaskStatus>):
required: false
Updated task statusclient_token(impl Into<String>)/set_client_token(Option<String>):
required: false
Client-provided token for idempotent operations
- On success, responds with
UpdateBacklogTaskOutputwith field(s):task(Option<Task>): The updated task object
- On failure, responds with
SdkError<UpdateBacklogTaskError>
Sourceimpl Client
impl Client
Sourcepub fn update_goal(&self) -> UpdateGoalFluentBuilder
pub fn update_goal(&self) -> UpdateGoalFluentBuilder
Constructs a fluent builder for the UpdateGoal operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier for the agent space containing the goalgoal_id(impl Into<String>)/set_goal_id(Option<String>):
required: true
The unique identifier of the goal to updateevaluation_schedule(GoalScheduleInput)/set_evaluation_schedule(Option<GoalScheduleInput>):
required: false
Update goal schedule stateclient_token(impl Into<String>)/set_client_token(Option<String>):
required: false
Client-provided token for idempotent operations
- On success, responds with
UpdateGoalOutputwith field(s):goal(Option<Goal>): The updated goal object
- On failure, responds with
SdkError<UpdateGoalError>
Sourceimpl Client
impl Client
Sourcepub fn update_operator_app_idp_config(
&self,
) -> UpdateOperatorAppIdpConfigFluentBuilder
pub fn update_operator_app_idp_config( &self, ) -> UpdateOperatorAppIdpConfigFluentBuilder
Constructs a fluent builder for the UpdateOperatorAppIdpConfig operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier of the AgentSpaceidp_client_secret(impl Into<String>)/set_idp_client_secret(Option<String>):
required: false
The OIDC client secret for the IdP application
- On success, responds with
UpdateOperatorAppIdpConfigOutputwith field(s):agent_space_id(String): The unique identifier of the AgentSpaceidp(Option<IdpAuthConfiguration>): Configuration for external Identity Provider OIDC authentication flow for the Operator App.
- On failure, responds with
SdkError<UpdateOperatorAppIdpConfigError>
Sourceimpl Client
impl Client
Sourcepub fn update_private_connection_certificate(
&self,
) -> UpdatePrivateConnectionCertificateFluentBuilder
pub fn update_private_connection_certificate( &self, ) -> UpdatePrivateConnectionCertificateFluentBuilder
Constructs a fluent builder for the UpdatePrivateConnectionCertificate operation.
- The fluent builder is configurable:
name(impl Into<String>)/set_name(Option<String>):
required: true
The name of the Private Connection.certificate(impl Into<String>)/set_certificate(Option<String>):
required: true
The new certificate for the Private Connection.
- On success, responds with
UpdatePrivateConnectionCertificateOutputwith field(s):name(String): The name of the Private Connection.r#type(PrivateConnectionType): The type of the Private Connection.resource_gateway_id(Option<String>): The service-managed Resource Gateway ARN. Only present for service-managed Private Connections.host_address(Option<String>): IP address or DNS name of the target resource. Only present for service-managed Private Connections.vpc_id(Option<String>): VPC identifier of the service-managed Resource Gateway. Only present for service-managed Private Connections.resource_configuration_id(Option<String>): The Resource Configuration ARN. Only present for self-managed Private Connections.status(PrivateConnectionStatus): The status of the Private Connection.certificate_expiry_time(Option<DateTime>): The expiry time of the certificate associated with the Private Connection. Only present when a certificate is associated.
- On failure, responds with
SdkError<UpdatePrivateConnectionCertificateError>
Sourceimpl Client
impl Client
Sourcepub fn update_recommendation(&self) -> UpdateRecommendationFluentBuilder
pub fn update_recommendation(&self) -> UpdateRecommendationFluentBuilder
Constructs a fluent builder for the UpdateRecommendation operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier for the agent space containing the recommendationrecommendation_id(impl Into<String>)/set_recommendation_id(Option<String>):
required: true
The unique identifier for the recommendation to updatestatus(RecommendationStatus)/set_status(Option<RecommendationStatus>):
required: false
Current status of the recommendationadditional_context(impl Into<String>)/set_additional_context(Option<String>):
required: false
Additional context for recommendationclient_token(impl Into<String>)/set_client_token(Option<String>):
required: false
A unique token that ensures idempotency of the request
- On success, responds with
UpdateRecommendationOutputwith field(s):recommendation(Option<Recommendation>): The updated recommendation
- On failure, responds with
SdkError<UpdateRecommendationError>
Sourceimpl Client
impl Client
Sourcepub fn validate_aws_associations(&self) -> ValidateAwsAssociationsFluentBuilder
pub fn validate_aws_associations(&self) -> ValidateAwsAssociationsFluentBuilder
Constructs a fluent builder for the ValidateAwsAssociations operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
The unique identifier of the AgentSpace
- On success, responds with
ValidateAwsAssociationsOutput - On failure, responds with
SdkError<ValidateAwsAssociationsError>
Sourceimpl Client
impl Client
Sourcepub fn from_conf(conf: Config) -> Self
pub fn from_conf(conf: Config) -> Self
Creates a new client from the service Config.
Panics
This method will panic in the following cases:
- Retries or timeouts are enabled without a
sleep_implconfigured. - Identity caching is enabled without a
sleep_implandtime_sourceconfigured. - No
behavior_versionis provided.
The panic message for each of these will have instructions on how to resolve them.
Sourceimpl Client
impl Client
Sourcepub fn new(sdk_config: &SdkConfig) -> Self
pub fn new(sdk_config: &SdkConfig) -> Self
Creates a new client from an SDK Config.
Panics
- This method will panic if the
sdk_configis missing an async sleep implementation. If you experience this panic, set thesleep_implon the Config passed into this function to fix it. - This method will panic if the
sdk_configis missing an HTTP connector. If you experience this panic, set thehttp_connectoron the Config passed into this function to fix it. - This method will panic if no
BehaviorVersionis provided. If you experience this panic, setbehavior_versionon the Config or enable thebehavior-version-latestCargo feature.