#[non_exhaustive]pub struct AgentSpaceBuilder { /* private fields */ }Expand description
A builder for AgentSpace.
Implementations
Sourceimpl AgentSpaceBuilder
impl AgentSpaceBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the AgentSpace. This field is required.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the AgentSpace.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the AgentSpace.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the AgentSpace.
Sourcepub fn locale(self, input: impl Into<String>) -> Self
pub fn locale(self, input: impl Into<String>) -> Self
The locale for the AgentSpace, which determines the language used in agent responses.
Sourcepub fn set_locale(self, input: Option<String>) -> Self
pub fn set_locale(self, input: Option<String>) -> Self
The locale for the AgentSpace, which determines the language used in agent responses.
Sourcepub fn get_locale(&self) -> &Option<String>
pub fn get_locale(&self) -> &Option<String>
The locale for the AgentSpace, which determines the language used in agent responses.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The timestamp when the resource was created. This field is required.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The timestamp when the resource was created.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The timestamp when the resource was created.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The timestamp when the resource was last updated. This field is required.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The timestamp when the resource was last updated.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The timestamp when the resource was last updated.
Sourcepub fn kms_key_arn(self, input: impl Into<String>) -> Self
pub fn kms_key_arn(self, input: impl Into<String>) -> Self
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn set_kms_key_arn(self, input: Option<String>) -> Self
pub fn set_kms_key_arn(self, input: Option<String>) -> Self
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn get_kms_key_arn(&self) -> &Option<String>
pub fn get_kms_key_arn(&self) -> &Option<String>
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the AgentSpace This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the AgentSpace
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the AgentSpace
Sourcepub fn build(self) -> Result<AgentSpace, BuildError>
pub fn build(self) -> Result<AgentSpace, BuildError>
Consumes the builder and constructs a AgentSpace.
This method will fail if any of the following fields are not set: