#[non_exhaustive]pub struct ApprovalActionBuilder { /* private fields */ }Expand description
A builder for ApprovalAction.
Implementations
Sourceimpl ApprovalActionBuilder
impl ApprovalActionBuilder
Sourcepub fn tool_use_id(self, input: impl Into<String>) -> Self
pub fn tool_use_id(self, input: impl Into<String>) -> Self
Identifier of the specific paused tool invocation that requested approval. Correlates the approval decision back to the paused invocation.
Sourcepub fn set_tool_use_id(self, input: Option<String>) -> Self
pub fn set_tool_use_id(self, input: Option<String>) -> Self
Identifier of the specific paused tool invocation that requested approval. Correlates the approval decision back to the paused invocation.
Sourcepub fn get_tool_use_id(&self) -> &Option<String>
pub fn get_tool_use_id(&self) -> &Option<String>
Identifier of the specific paused tool invocation that requested approval. Correlates the approval decision back to the paused invocation.
Sourcepub fn interrupt_id(self, input: impl Into<String>) -> Self
pub fn interrupt_id(self, input: impl Into<String>) -> Self
An opaque resume identifier issued by the service when an agent execution pauses for approval. Provide it when resuming so the service can resume the correct paused execution.
Sourcepub fn set_interrupt_id(self, input: Option<String>) -> Self
pub fn set_interrupt_id(self, input: Option<String>) -> Self
An opaque resume identifier issued by the service when an agent execution pauses for approval. Provide it when resuming so the service can resume the correct paused execution.
Sourcepub fn get_interrupt_id(&self) -> &Option<String>
pub fn get_interrupt_id(&self) -> &Option<String>
An opaque resume identifier issued by the service when an agent execution pauses for approval. Provide it when resuming so the service can resume the correct paused execution.
Sourcepub fn approval_id(self, input: impl Into<String>) -> Self
pub fn approval_id(self, input: impl Into<String>) -> Self
Identifier of the approval request being resolved.
Sourcepub fn set_approval_id(self, input: Option<String>) -> Self
pub fn set_approval_id(self, input: Option<String>) -> Self
Identifier of the approval request being resolved.
Sourcepub fn get_approval_id(&self) -> &Option<String>
pub fn get_approval_id(&self) -> &Option<String>
Identifier of the approval request being resolved.
Optional display text of the UI control the user chose (for example, "Approve Exact", "Approve Broader", or "Reject"), provided as auxiliary decision context.
Optional display text of the UI control the user chose (for example, "Approve Exact", "Approve Broader", or "Reject"), provided as auxiliary decision context.
Optional display text of the UI control the user chose (for example, "Approve Exact", "Approve Broader", or "Reject"), provided as auxiliary decision context.
Sourcepub fn action(self, input: ApprovalActionType) -> Self
pub fn action(self, input: ApprovalActionType) -> Self
The action taken on the approval request — APPROVED or REJECTED.
Sourcepub fn set_action(self, input: Option<ApprovalActionType>) -> Self
pub fn set_action(self, input: Option<ApprovalActionType>) -> Self
The action taken on the approval request — APPROVED or REJECTED.
Sourcepub fn get_action(&self) -> &Option<ApprovalActionType>
pub fn get_action(&self) -> &Option<ApprovalActionType>
The action taken on the approval request — APPROVED or REJECTED.
Sourcepub fn build(self) -> ApprovalAction
pub fn build(self) -> ApprovalAction
Consumes the builder and constructs a ApprovalAction.