#[non_exhaustive]pub struct AssociationBuilder { /* private fields */ }Expand description
A builder for Association.
Implementations
Sourceimpl AssociationBuilder
impl AssociationBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the AgentSpace This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the AgentSpace
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the AgentSpace
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The timestamp when the resource was created. This field is required.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The timestamp when the resource was created.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The timestamp when the resource was created.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The timestamp when the resource was last updated. This field is required.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The timestamp when the resource was last updated.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The timestamp when the resource was last updated.
Sourcepub fn status(self, input: ValidationStatus) -> Self
pub fn status(self, input: ValidationStatus) -> Self
Validation status
Sourcepub fn set_status(self, input: Option<ValidationStatus>) -> Self
pub fn set_status(self, input: Option<ValidationStatus>) -> Self
Validation status
Sourcepub fn get_status(&self) -> &Option<ValidationStatus>
pub fn get_status(&self) -> &Option<ValidationStatus>
Validation status
Sourcepub fn association_id(self, input: impl Into<String>) -> Self
pub fn association_id(self, input: impl Into<String>) -> Self
The unique identifier of the given association. This field is required.
Sourcepub fn set_association_id(self, input: Option<String>) -> Self
pub fn set_association_id(self, input: Option<String>) -> Self
The unique identifier of the given association.
Sourcepub fn get_association_id(&self) -> &Option<String>
pub fn get_association_id(&self) -> &Option<String>
The unique identifier of the given association.
Sourcepub fn service_id(self, input: impl Into<String>) -> Self
pub fn service_id(self, input: impl Into<String>) -> Self
The identifier for associated service This field is required.
Sourcepub fn set_service_id(self, input: Option<String>) -> Self
pub fn set_service_id(self, input: Option<String>) -> Self
The identifier for associated service
Sourcepub fn get_service_id(&self) -> &Option<String>
pub fn get_service_id(&self) -> &Option<String>
The identifier for associated service
Sourcepub fn configuration(self, input: ServiceConfiguration) -> Self
pub fn configuration(self, input: ServiceConfiguration) -> Self
The configuration that directs how AgentSpace interacts with the given service. This field is required.
Sourcepub fn set_configuration(self, input: Option<ServiceConfiguration>) -> Self
pub fn set_configuration(self, input: Option<ServiceConfiguration>) -> Self
The configuration that directs how AgentSpace interacts with the given service.
Sourcepub fn get_configuration(&self) -> &Option<ServiceConfiguration>
pub fn get_configuration(&self) -> &Option<ServiceConfiguration>
The configuration that directs how AgentSpace interacts with the given service.
Sourcepub fn build(self) -> Result<Association, BuildError>
pub fn build(self) -> Result<Association, BuildError>
Consumes the builder and constructs a Association.
This method will fail if any of the following fields are not set: