#[non_exhaustive]pub struct ChatExecutionBuilder { /* private fields */ }Expand description
A builder for ChatExecution.
Implementations
Sourceimpl ChatExecutionBuilder
impl ChatExecutionBuilder
Sourcepub fn execution_id(self, input: impl Into<String>) -> Self
pub fn execution_id(self, input: impl Into<String>) -> Self
The unique identifier for the execution This field is required.
Sourcepub fn set_execution_id(self, input: Option<String>) -> Self
pub fn set_execution_id(self, input: Option<String>) -> Self
The unique identifier for the execution
Sourcepub fn get_execution_id(&self) -> &Option<String>
pub fn get_execution_id(&self) -> &Option<String>
The unique identifier for the execution
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
Timestamp when the chat was created This field is required.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
Timestamp when the chat was created
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
Timestamp when the chat was created
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
Timestamp when the chat was last updated
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
Timestamp when the chat was last updated
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
Timestamp when the chat was last updated
Sourcepub fn set_summary(self, input: Option<String>) -> Self
pub fn set_summary(self, input: Option<String>) -> Self
Summary or title of the chat
Sourcepub fn get_summary(&self) -> &Option<String>
pub fn get_summary(&self) -> &Option<String>
Summary or title of the chat
Sourcepub fn build(self) -> Result<ChatExecution, BuildError>
pub fn build(self) -> Result<ChatExecution, BuildError>
Consumes the builder and constructs a ChatExecution.
This method will fail if any of the following fields are not set: