#[non_exhaustive]pub struct ChatParticipantConnectionBuilder { /* private fields */ }Expand description
A builder for ChatParticipantConnection.
Implementations
Sourceimpl ChatParticipantConnectionBuilder
impl ChatParticipantConnectionBuilder
Sourcepub fn initial_contact_id(self, input: impl Into<String>) -> Self
pub fn initial_contact_id(self, input: impl Into<String>) -> Self
The identifier of the contact in this instance of Amazon Connect This field is required.
Sourcepub fn set_initial_contact_id(self, input: Option<String>) -> Self
pub fn set_initial_contact_id(self, input: Option<String>) -> Self
The identifier of the contact in this instance of Amazon Connect
Sourcepub fn get_initial_contact_id(&self) -> &Option<String>
pub fn get_initial_contact_id(&self) -> &Option<String>
The identifier of the contact in this instance of Amazon Connect
Sourcepub fn participant_id(self, input: impl Into<String>) -> Self
pub fn participant_id(self, input: impl Into<String>) -> Self
The identifier for a chat participant This field is required.
Sourcepub fn set_participant_id(self, input: Option<String>) -> Self
pub fn set_participant_id(self, input: Option<String>) -> Self
The identifier for a chat participant
Sourcepub fn get_participant_id(&self) -> &Option<String>
pub fn get_participant_id(&self) -> &Option<String>
The identifier for a chat participant
Sourcepub fn participant_token(self, input: impl Into<String>) -> Self
pub fn participant_token(self, input: impl Into<String>) -> Self
The token used by the chat participant to call CreateParticipantConnection This field is required.
Sourcepub fn set_participant_token(self, input: Option<String>) -> Self
pub fn set_participant_token(self, input: Option<String>) -> Self
The token used by the chat participant to call CreateParticipantConnection
Sourcepub fn get_participant_token(&self) -> &Option<String>
pub fn get_participant_token(&self) -> &Option<String>
The token used by the chat participant to call CreateParticipantConnection
Sourcepub fn build(self) -> Result<ChatParticipantConnection, BuildError>
pub fn build(self) -> Result<ChatParticipantConnection, BuildError>
Consumes the builder and constructs a ChatParticipantConnection.
This method will fail if any of the following fields are not set: