#[non_exhaustive]pub struct ExecutionBuilder { /* private fields */ }Expand description
A builder for Execution.
Implementations
Sourceimpl ExecutionBuilder
impl ExecutionBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space containing this execution This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space containing this execution
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space containing this execution
Sourcepub fn execution_id(self, input: impl Into<String>) -> Self
pub fn execution_id(self, input: impl Into<String>) -> Self
The unique identifier for this execution This field is required.
Sourcepub fn set_execution_id(self, input: Option<String>) -> Self
pub fn set_execution_id(self, input: Option<String>) -> Self
The unique identifier for this execution
Sourcepub fn get_execution_id(&self) -> &Option<String>
pub fn get_execution_id(&self) -> &Option<String>
The unique identifier for this execution
Sourcepub fn parent_execution_id(self, input: impl Into<String>) -> Self
pub fn parent_execution_id(self, input: impl Into<String>) -> Self
The identifier of the parent execution, if this is a child execution
Sourcepub fn set_parent_execution_id(self, input: Option<String>) -> Self
pub fn set_parent_execution_id(self, input: Option<String>) -> Self
The identifier of the parent execution, if this is a child execution
Sourcepub fn get_parent_execution_id(&self) -> &Option<String>
pub fn get_parent_execution_id(&self) -> &Option<String>
The identifier of the parent execution, if this is a child execution
Sourcepub fn agent_sub_task(self, input: impl Into<String>) -> Self
pub fn agent_sub_task(self, input: impl Into<String>) -> Self
The specific subtask being executed by the agent This field is required.
Sourcepub fn set_agent_sub_task(self, input: Option<String>) -> Self
pub fn set_agent_sub_task(self, input: Option<String>) -> Self
The specific subtask being executed by the agent
Sourcepub fn get_agent_sub_task(&self) -> &Option<String>
pub fn get_agent_sub_task(&self) -> &Option<String>
The specific subtask being executed by the agent
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
Timestamp when this execution was created This field is required.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
Timestamp when this execution was created
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
Timestamp when this execution was created
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
Timestamp when this execution was last updated This field is required.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
Timestamp when this execution was last updated
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
Timestamp when this execution was last updated
Sourcepub fn execution_status(self, input: ExecutionStatus) -> Self
pub fn execution_status(self, input: ExecutionStatus) -> Self
The current status of this execution This field is required.
Sourcepub fn set_execution_status(self, input: Option<ExecutionStatus>) -> Self
pub fn set_execution_status(self, input: Option<ExecutionStatus>) -> Self
The current status of this execution
Sourcepub fn get_execution_status(&self) -> &Option<ExecutionStatus>
pub fn get_execution_status(&self) -> &Option<ExecutionStatus>
The current status of this execution
Sourcepub fn agent_type(self, input: impl Into<String>) -> Self
pub fn agent_type(self, input: impl Into<String>) -> Self
The type of agent that performed this execution.
Sourcepub fn set_agent_type(self, input: Option<String>) -> Self
pub fn set_agent_type(self, input: Option<String>) -> Self
The type of agent that performed this execution.
Sourcepub fn get_agent_type(&self) -> &Option<String>
pub fn get_agent_type(&self) -> &Option<String>
The type of agent that performed this execution.
Sourcepub fn uid(self, input: impl Into<String>) -> Self
pub fn uid(self, input: impl Into<String>) -> Self
The unique identifier for the user session associated with this execution
Sourcepub fn set_uid(self, input: Option<String>) -> Self
pub fn set_uid(self, input: Option<String>) -> Self
The unique identifier for the user session associated with this execution
Sourcepub fn get_uid(&self) -> &Option<String>
pub fn get_uid(&self) -> &Option<String>
The unique identifier for the user session associated with this execution