#[non_exhaustive]pub struct GoalBuilder { /* private fields */ }Expand description
A builder for Goal.
Implementations
Sourceimpl GoalBuilder
impl GoalBuilder
Sourcepub fn agent_space_arn(self, input: impl Into<String>) -> Self
pub fn agent_space_arn(self, input: impl Into<String>) -> Self
The unique identifier for the agent space containing this goal This field is required.
Sourcepub fn set_agent_space_arn(self, input: Option<String>) -> Self
pub fn set_agent_space_arn(self, input: Option<String>) -> Self
The unique identifier for the agent space containing this goal
Sourcepub fn get_agent_space_arn(&self) -> &Option<String>
pub fn get_agent_space_arn(&self) -> &Option<String>
The unique identifier for the agent space containing this goal
Sourcepub fn goal_id(self, input: impl Into<String>) -> Self
pub fn goal_id(self, input: impl Into<String>) -> Self
The unique identifier for this goal This field is required.
Sourcepub fn set_goal_id(self, input: Option<String>) -> Self
pub fn set_goal_id(self, input: Option<String>) -> Self
The unique identifier for this goal
Sourcepub fn get_goal_id(&self) -> &Option<String>
pub fn get_goal_id(&self) -> &Option<String>
The unique identifier for this goal
Sourcepub fn title(self, input: impl Into<String>) -> Self
pub fn title(self, input: impl Into<String>) -> Self
The title of the goal This field is required.
Sourcepub fn content(self, input: GoalContent) -> Self
pub fn content(self, input: GoalContent) -> Self
Content of the goal This field is required.
Sourcepub fn set_content(self, input: Option<GoalContent>) -> Self
pub fn set_content(self, input: Option<GoalContent>) -> Self
Content of the goal
Sourcepub fn get_content(&self) -> &Option<GoalContent>
pub fn get_content(&self) -> &Option<GoalContent>
Content of the goal
Sourcepub fn status(self, input: GoalStatus) -> Self
pub fn status(self, input: GoalStatus) -> Self
Current status of the goal itself This field is required.
Sourcepub fn set_status(self, input: Option<GoalStatus>) -> Self
pub fn set_status(self, input: Option<GoalStatus>) -> Self
Current status of the goal itself
Sourcepub fn get_status(&self) -> &Option<GoalStatus>
pub fn get_status(&self) -> &Option<GoalStatus>
Current status of the goal itself
Sourcepub fn goal_type(self, input: GoalType) -> Self
pub fn goal_type(self, input: GoalType) -> Self
Type of goal based on its origin This field is required.
Sourcepub fn set_goal_type(self, input: Option<GoalType>) -> Self
pub fn set_goal_type(self, input: Option<GoalType>) -> Self
Type of goal based on its origin
Sourcepub fn get_goal_type(&self) -> &Option<GoalType>
pub fn get_goal_type(&self) -> &Option<GoalType>
Type of goal based on its origin
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
Timestamp when this goal was created This field is required.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
Timestamp when this goal was created
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
Timestamp when this goal was created
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
Timestamp when this goal was last updated This field is required.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
Timestamp when this goal was last updated
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
Timestamp when this goal was last updated
Sourcepub fn last_evaluated_at(self, input: DateTime) -> Self
pub fn last_evaluated_at(self, input: DateTime) -> Self
Timestamp when the goal was last evaluated
Sourcepub fn set_last_evaluated_at(self, input: Option<DateTime>) -> Self
pub fn set_last_evaluated_at(self, input: Option<DateTime>) -> Self
Timestamp when the goal was last evaluated
Sourcepub fn get_last_evaluated_at(&self) -> &Option<DateTime>
pub fn get_last_evaluated_at(&self) -> &Option<DateTime>
Timestamp when the goal was last evaluated
Sourcepub fn last_task_id(self, input: impl Into<String>) -> Self
pub fn last_task_id(self, input: impl Into<String>) -> Self
ID of the most recent task associated with this goal
Sourcepub fn set_last_task_id(self, input: Option<String>) -> Self
pub fn set_last_task_id(self, input: Option<String>) -> Self
ID of the most recent task associated with this goal
Sourcepub fn get_last_task_id(&self) -> &Option<String>
pub fn get_last_task_id(&self) -> &Option<String>
ID of the most recent task associated with this goal
Sourcepub fn last_successful_task_id(self, input: impl Into<String>) -> Self
pub fn last_successful_task_id(self, input: impl Into<String>) -> Self
ID of the most recent successful task associated with this goal
Sourcepub fn set_last_successful_task_id(self, input: Option<String>) -> Self
pub fn set_last_successful_task_id(self, input: Option<String>) -> Self
ID of the most recent successful task associated with this goal
Sourcepub fn get_last_successful_task_id(&self) -> &Option<String>
pub fn get_last_successful_task_id(&self) -> &Option<String>
ID of the most recent successful task associated with this goal
Sourcepub fn version(self, input: i32) -> Self
pub fn version(self, input: i32) -> Self
Version number for optimistic locking This field is required.
Sourcepub fn set_version(self, input: Option<i32>) -> Self
pub fn set_version(self, input: Option<i32>) -> Self
Version number for optimistic locking
Sourcepub fn get_version(&self) -> &Option<i32>
pub fn get_version(&self) -> &Option<i32>
Version number for optimistic locking
Sourcepub fn evaluation_schedule(self, input: GoalSchedule) -> Self
pub fn evaluation_schedule(self, input: GoalSchedule) -> Self
Goal Schedule. Allows to schedule the goal to run periodically, as well as disable a goal temporarily
Sourcepub fn set_evaluation_schedule(self, input: Option<GoalSchedule>) -> Self
pub fn set_evaluation_schedule(self, input: Option<GoalSchedule>) -> Self
Goal Schedule. Allows to schedule the goal to run periodically, as well as disable a goal temporarily
Sourcepub fn get_evaluation_schedule(&self) -> &Option<GoalSchedule>
pub fn get_evaluation_schedule(&self) -> &Option<GoalSchedule>
Goal Schedule. Allows to schedule the goal to run periodically, as well as disable a goal temporarily