#[non_exhaustive]pub struct GoalScheduleBuilder { /* private fields */ }Expand description
A builder for GoalSchedule.
Implementations
Sourceimpl GoalScheduleBuilder
impl GoalScheduleBuilder
Sourcepub fn state(self, input: SchedulerState) -> Self
pub fn state(self, input: SchedulerState) -> Self
Whether the schedule is enabled or disabled This field is required.
Sourcepub fn set_state(self, input: Option<SchedulerState>) -> Self
pub fn set_state(self, input: Option<SchedulerState>) -> Self
Whether the schedule is enabled or disabled
Sourcepub fn get_state(&self) -> &Option<SchedulerState>
pub fn get_state(&self) -> &Option<SchedulerState>
Whether the schedule is enabled or disabled
Sourcepub fn expression(self, input: impl Into<String>) -> Self
pub fn expression(self, input: impl Into<String>) -> Self
Schedule expression (e.g., ‘rate(7 days)’)
Sourcepub fn set_expression(self, input: Option<String>) -> Self
pub fn set_expression(self, input: Option<String>) -> Self
Schedule expression (e.g., ‘rate(7 days)’)
Sourcepub fn get_expression(&self) -> &Option<String>
pub fn get_expression(&self) -> &Option<String>
Schedule expression (e.g., ‘rate(7 days)’)
Sourcepub fn build(self) -> Result<GoalSchedule, BuildError>
pub fn build(self) -> Result<GoalSchedule, BuildError>
Consumes the builder and constructs a GoalSchedule.
This method will fail if any of the following fields are not set: