#[non_exhaustive]pub struct GoalScheduleInputBuilder { /* private fields */ }Expand description
A builder for GoalScheduleInput.
Implementations
Sourceimpl GoalScheduleInputBuilder
impl GoalScheduleInputBuilder
Sourcepub fn state(self, input: SchedulerState) -> Self
pub fn state(self, input: SchedulerState) -> Self
Whether the schedule is enabled or disabled This field is required.
Sourcepub fn set_state(self, input: Option<SchedulerState>) -> Self
pub fn set_state(self, input: Option<SchedulerState>) -> Self
Whether the schedule is enabled or disabled
Sourcepub fn get_state(&self) -> &Option<SchedulerState>
pub fn get_state(&self) -> &Option<SchedulerState>
Whether the schedule is enabled or disabled
Sourcepub fn build(self) -> Result<GoalScheduleInput, BuildError>
pub fn build(self) -> Result<GoalScheduleInput, BuildError>
Consumes the builder and constructs a GoalScheduleInput.
This method will fail if any of the following fields are not set: