#[non_exhaustive]pub struct IdpAuthConfigurationBuilder { /* private fields */ }Expand description
A builder for IdpAuthConfiguration.
Implementations
Sourceimpl IdpAuthConfigurationBuilder
impl IdpAuthConfigurationBuilder
Sourcepub fn issuer_url(self, input: impl Into<String>) -> Self
pub fn issuer_url(self, input: impl Into<String>) -> Self
The OIDC issuer URL of the external Identity Provider This field is required.
Sourcepub fn set_issuer_url(self, input: Option<String>) -> Self
pub fn set_issuer_url(self, input: Option<String>) -> Self
The OIDC issuer URL of the external Identity Provider
Sourcepub fn get_issuer_url(&self) -> &Option<String>
pub fn get_issuer_url(&self) -> &Option<String>
The OIDC issuer URL of the external Identity Provider
Sourcepub fn client_id(self, input: impl Into<String>) -> Self
pub fn client_id(self, input: impl Into<String>) -> Self
The OIDC client ID for the IdP application This field is required.
Sourcepub fn set_client_id(self, input: Option<String>) -> Self
pub fn set_client_id(self, input: Option<String>) -> Self
The OIDC client ID for the IdP application
Sourcepub fn get_client_id(&self) -> &Option<String>
pub fn get_client_id(&self) -> &Option<String>
The OIDC client ID for the IdP application
Sourcepub fn operator_app_role_arn(self, input: impl Into<String>) -> Self
pub fn operator_app_role_arn(self, input: impl Into<String>) -> Self
The IAM role end users assume to access AIDevOps APIs This field is required.
Sourcepub fn set_operator_app_role_arn(self, input: Option<String>) -> Self
pub fn set_operator_app_role_arn(self, input: Option<String>) -> Self
The IAM role end users assume to access AIDevOps APIs
Sourcepub fn get_operator_app_role_arn(&self) -> &Option<String>
pub fn get_operator_app_role_arn(&self) -> &Option<String>
The IAM role end users assume to access AIDevOps APIs
Sourcepub fn provider(self, input: impl Into<String>) -> Self
pub fn provider(self, input: impl Into<String>) -> Self
The Identity Provider name (e.g., Entra, Okta, Google) This field is required.
Sourcepub fn set_provider(self, input: Option<String>) -> Self
pub fn set_provider(self, input: Option<String>) -> Self
The Identity Provider name (e.g., Entra, Okta, Google)
Sourcepub fn get_provider(&self) -> &Option<String>
pub fn get_provider(&self) -> &Option<String>
The Identity Provider name (e.g., Entra, Okta, Google)
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The timestamp when the Operator App IdP auth flow was enabled. This field is required.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The timestamp when the Operator App IdP auth flow was enabled.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The timestamp when the Operator App IdP auth flow was enabled.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The timestamp when the Operator App IdP auth flow was updated.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The timestamp when the Operator App IdP auth flow was updated.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The timestamp when the Operator App IdP auth flow was updated.
Sourcepub fn build(self) -> Result<IdpAuthConfiguration, BuildError>
pub fn build(self) -> Result<IdpAuthConfiguration, BuildError>
Consumes the builder and constructs a IdpAuthConfiguration.
This method will fail if any of the following fields are not set: