#[non_exhaustive]pub struct McpServerBearerTokenConfigBuilder { /* private fields */ }Expand description
A builder for McpServerBearerTokenConfig.
Implementations
Sourceimpl McpServerBearerTokenConfigBuilder
impl McpServerBearerTokenConfigBuilder
Sourcepub fn token_name(self, input: impl Into<String>) -> Self
pub fn token_name(self, input: impl Into<String>) -> Self
User friendly bearer token name specified by end user. This field is required.
Sourcepub fn set_token_name(self, input: Option<String>) -> Self
pub fn set_token_name(self, input: Option<String>) -> Self
User friendly bearer token name specified by end user.
Sourcepub fn get_token_name(&self) -> &Option<String>
pub fn get_token_name(&self) -> &Option<String>
User friendly bearer token name specified by end user.
Sourcepub fn token_value(self, input: impl Into<String>) -> Self
pub fn token_value(self, input: impl Into<String>) -> Self
Bearer token value in alphanumeric for authenticating with the service. This field is required.
Sourcepub fn set_token_value(self, input: Option<String>) -> Self
pub fn set_token_value(self, input: Option<String>) -> Self
Bearer token value in alphanumeric for authenticating with the service.
Sourcepub fn get_token_value(&self) -> &Option<String>
pub fn get_token_value(&self) -> &Option<String>
Bearer token value in alphanumeric for authenticating with the service.
HTTP header name to send the bearer token in requests to the service. Defaults to ‘Authorization’ per RFC 6750.
HTTP header name to send the bearer token in requests to the service. Defaults to ‘Authorization’ per RFC 6750.
HTTP header name to send the bearer token in requests to the service. Defaults to ‘Authorization’ per RFC 6750.
Sourcepub fn build(self) -> Result<McpServerBearerTokenConfig, BuildError>
pub fn build(self) -> Result<McpServerBearerTokenConfig, BuildError>
Consumes the builder and constructs a McpServerBearerTokenConfig.
This method will fail if any of the following fields are not set: