#[non_exhaustive]pub struct McpServerGrafanaConfigurationBuilder { /* private fields */ }Expand description
A builder for McpServerGrafanaConfiguration.
Implementations
Sourceimpl McpServerGrafanaConfigurationBuilder
impl McpServerGrafanaConfigurationBuilder
Sourcepub fn endpoint(self, input: impl Into<String>) -> Self
pub fn endpoint(self, input: impl Into<String>) -> Self
Grafana instance URL (e.g., https://your-instance.grafana.net) This field is required.
Sourcepub fn set_endpoint(self, input: Option<String>) -> Self
pub fn set_endpoint(self, input: Option<String>) -> Self
Grafana instance URL (e.g., https://your-instance.grafana.net)
Sourcepub fn get_endpoint(&self) -> &Option<String>
pub fn get_endpoint(&self) -> &Option<String>
Grafana instance URL (e.g., https://your-instance.grafana.net)
Sourcepub fn organization_id(self, input: impl Into<String>) -> Self
pub fn organization_id(self, input: impl Into<String>) -> Self
The Grafana organization ID that can be used.
Sourcepub fn set_organization_id(self, input: Option<String>) -> Self
pub fn set_organization_id(self, input: Option<String>) -> Self
The Grafana organization ID that can be used.
Sourcepub fn get_organization_id(&self) -> &Option<String>
pub fn get_organization_id(&self) -> &Option<String>
The Grafana organization ID that can be used.
Sourcepub fn tools(self, input: impl Into<String>) -> Self
pub fn tools(self, input: impl Into<String>) -> Self
Appends an item to tools.
To override the contents of this collection use set_tools.
List of MCP tools that can be used.
Sourcepub fn build(self) -> Result<McpServerGrafanaConfiguration, BuildError>
pub fn build(self) -> Result<McpServerGrafanaConfiguration, BuildError>
Consumes the builder and constructs a McpServerGrafanaConfiguration.
This method will fail if any of the following fields are not set: