#[non_exhaustive]pub struct McpServerOAuth3LoConfigBuilder { /* private fields */ }Expand description
A builder for McpServerOAuth3LoConfig.
Implementations
Sourceimpl McpServerOAuth3LoConfigBuilder
impl McpServerOAuth3LoConfigBuilder
Sourcepub fn client_name(self, input: impl Into<String>) -> Self
pub fn client_name(self, input: impl Into<String>) -> Self
User friendly OAuth client name specified by end user.
Sourcepub fn set_client_name(self, input: Option<String>) -> Self
pub fn set_client_name(self, input: Option<String>) -> Self
User friendly OAuth client name specified by end user.
Sourcepub fn get_client_name(&self) -> &Option<String>
pub fn get_client_name(&self) -> &Option<String>
User friendly OAuth client name specified by end user.
Sourcepub fn client_id(self, input: impl Into<String>) -> Self
pub fn client_id(self, input: impl Into<String>) -> Self
OAuth client ID for authenticating with the service. This field is required.
Sourcepub fn set_client_id(self, input: Option<String>) -> Self
pub fn set_client_id(self, input: Option<String>) -> Self
OAuth client ID for authenticating with the service.
Sourcepub fn get_client_id(&self) -> &Option<String>
pub fn get_client_id(&self) -> &Option<String>
OAuth client ID for authenticating with the service.
Sourcepub fn exchange_parameters(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn exchange_parameters( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to exchange_parameters.
To override the contents of this collection use set_exchange_parameters.
OAuth token exchange parameters for authenticating with the service.
Sourcepub fn set_exchange_parameters(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_exchange_parameters( self, input: Option<HashMap<String, String>>, ) -> Self
OAuth token exchange parameters for authenticating with the service.
Sourcepub fn get_exchange_parameters(&self) -> &Option<HashMap<String, String>>
pub fn get_exchange_parameters(&self) -> &Option<HashMap<String, String>>
OAuth token exchange parameters for authenticating with the service.
Sourcepub fn return_to_endpoint(self, input: impl Into<String>) -> Self
pub fn return_to_endpoint(self, input: impl Into<String>) -> Self
The endpoint to return to after OAuth flow completes (must be AWS console domain) This field is required.
Sourcepub fn set_return_to_endpoint(self, input: Option<String>) -> Self
pub fn set_return_to_endpoint(self, input: Option<String>) -> Self
The endpoint to return to after OAuth flow completes (must be AWS console domain)
Sourcepub fn get_return_to_endpoint(&self) -> &Option<String>
pub fn get_return_to_endpoint(&self) -> &Option<String>
The endpoint to return to after OAuth flow completes (must be AWS console domain)
OAuth authorization URL for 3LO authentication. This field is required.
OAuth authorization URL for 3LO authentication.
OAuth authorization URL for 3LO authentication.
Sourcepub fn exchange_url(self, input: impl Into<String>) -> Self
pub fn exchange_url(self, input: impl Into<String>) -> Self
OAuth token exchange URL. This field is required.
Sourcepub fn set_exchange_url(self, input: Option<String>) -> Self
pub fn set_exchange_url(self, input: Option<String>) -> Self
OAuth token exchange URL.
Sourcepub fn get_exchange_url(&self) -> &Option<String>
pub fn get_exchange_url(&self) -> &Option<String>
OAuth token exchange URL.
Sourcepub fn client_secret(self, input: impl Into<String>) -> Self
pub fn client_secret(self, input: impl Into<String>) -> Self
OAuth client secret for authenticating with the service. Required for confidential clients or when PKCE is not supported. Optional for public clients using PKCE.
Sourcepub fn set_client_secret(self, input: Option<String>) -> Self
pub fn set_client_secret(self, input: Option<String>) -> Self
OAuth client secret for authenticating with the service. Required for confidential clients or when PKCE is not supported. Optional for public clients using PKCE.
Sourcepub fn get_client_secret(&self) -> &Option<String>
pub fn get_client_secret(&self) -> &Option<String>
OAuth client secret for authenticating with the service. Required for confidential clients or when PKCE is not supported. Optional for public clients using PKCE.
Sourcepub fn support_code_challenge(self, input: bool) -> Self
pub fn support_code_challenge(self, input: bool) -> Self
Whether the service supports PKCE (Proof Key for Code Exchange) for enhanced security during the OAuth flow.
Sourcepub fn set_support_code_challenge(self, input: Option<bool>) -> Self
pub fn set_support_code_challenge(self, input: Option<bool>) -> Self
Whether the service supports PKCE (Proof Key for Code Exchange) for enhanced security during the OAuth flow.
Sourcepub fn get_support_code_challenge(&self) -> &Option<bool>
pub fn get_support_code_challenge(&self) -> &Option<bool>
Whether the service supports PKCE (Proof Key for Code Exchange) for enhanced security during the OAuth flow.
Sourcepub fn scopes(self, input: impl Into<String>) -> Self
pub fn scopes(self, input: impl Into<String>) -> Self
Appends an item to scopes.
To override the contents of this collection use set_scopes.
OAuth scopes for 3LO authentication. The service will always request scope offline_access.
Sourcepub fn set_scopes(self, input: Option<Vec<String>>) -> Self
pub fn set_scopes(self, input: Option<Vec<String>>) -> Self
OAuth scopes for 3LO authentication. The service will always request scope offline_access.
Sourcepub fn get_scopes(&self) -> &Option<Vec<String>>
pub fn get_scopes(&self) -> &Option<Vec<String>>
OAuth scopes for 3LO authentication. The service will always request scope offline_access.
Sourcepub fn build(self) -> Result<McpServerOAuth3LoConfig, BuildError>
pub fn build(self) -> Result<McpServerOAuth3LoConfig, BuildError>
Consumes the builder and constructs a McpServerOAuth3LoConfig.
This method will fail if any of the following fields are not set: