#[non_exhaustive]pub struct MsTeamsConfigurationBuilder { /* private fields */ }Expand description
A builder for MsTeamsConfiguration.
Implementations
Sourceimpl MsTeamsConfigurationBuilder
impl MsTeamsConfigurationBuilder
Sourcepub fn team_id(self, input: impl Into<String>) -> Self
pub fn team_id(self, input: impl Into<String>) -> Self
Associated MS Teams teams ID This field is required.
Sourcepub fn set_team_id(self, input: Option<String>) -> Self
pub fn set_team_id(self, input: Option<String>) -> Self
Associated MS Teams teams ID
Sourcepub fn get_team_id(&self) -> &Option<String>
pub fn get_team_id(&self) -> &Option<String>
Associated MS Teams teams ID
Sourcepub fn team_name(self, input: impl Into<String>) -> Self
pub fn team_name(self, input: impl Into<String>) -> Self
Associated MS Teams team name This field is required.
Sourcepub fn set_team_name(self, input: Option<String>) -> Self
pub fn set_team_name(self, input: Option<String>) -> Self
Associated MS Teams team name
Sourcepub fn get_team_name(&self) -> &Option<String>
pub fn get_team_name(&self) -> &Option<String>
Associated MS Teams team name
Sourcepub fn transmission_target(self, input: MsTeamsTransmissionTarget) -> Self
pub fn transmission_target(self, input: MsTeamsTransmissionTarget) -> Self
Transmission targets for agent notification This field is required.
Sourcepub fn set_transmission_target(
self,
input: Option<MsTeamsTransmissionTarget>,
) -> Self
pub fn set_transmission_target( self, input: Option<MsTeamsTransmissionTarget>, ) -> Self
Transmission targets for agent notification
Sourcepub fn get_transmission_target(&self) -> &Option<MsTeamsTransmissionTarget>
pub fn get_transmission_target(&self) -> &Option<MsTeamsTransmissionTarget>
Transmission targets for agent notification
Sourcepub fn build(self) -> Result<MsTeamsConfiguration, BuildError>
pub fn build(self) -> Result<MsTeamsConfiguration, BuildError>
Consumes the builder and constructs a MsTeamsConfiguration.
This method will fail if any of the following fields are not set: