#[non_exhaustive]pub struct NewRelicApiKeyConfigBuilder { /* private fields */ }Expand description
A builder for NewRelicApiKeyConfig.
Implementations
Sourceimpl NewRelicApiKeyConfigBuilder
impl NewRelicApiKeyConfigBuilder
Sourcepub fn api_key(self, input: impl Into<String>) -> Self
pub fn api_key(self, input: impl Into<String>) -> Self
New Relic User API Key This field is required.
Sourcepub fn set_api_key(self, input: Option<String>) -> Self
pub fn set_api_key(self, input: Option<String>) -> Self
New Relic User API Key
Sourcepub fn get_api_key(&self) -> &Option<String>
pub fn get_api_key(&self) -> &Option<String>
New Relic User API Key
Sourcepub fn account_id(self, input: impl Into<String>) -> Self
pub fn account_id(self, input: impl Into<String>) -> Self
New Relic Account ID This field is required.
Sourcepub fn set_account_id(self, input: Option<String>) -> Self
pub fn set_account_id(self, input: Option<String>) -> Self
New Relic Account ID
Sourcepub fn get_account_id(&self) -> &Option<String>
pub fn get_account_id(&self) -> &Option<String>
New Relic Account ID
Sourcepub fn region(self, input: NewRelicRegion) -> Self
pub fn region(self, input: NewRelicRegion) -> Self
New Relic region (US or EU) This field is required.
Sourcepub fn set_region(self, input: Option<NewRelicRegion>) -> Self
pub fn set_region(self, input: Option<NewRelicRegion>) -> Self
New Relic region (US or EU)
Sourcepub fn get_region(&self) -> &Option<NewRelicRegion>
pub fn get_region(&self) -> &Option<NewRelicRegion>
New Relic region (US or EU)
Sourcepub fn application_ids(self, input: impl Into<String>) -> Self
pub fn application_ids(self, input: impl Into<String>) -> Self
Appends an item to application_ids.
To override the contents of this collection use set_application_ids.
List of monitored APM application IDs in New Relic
Sourcepub fn set_application_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_application_ids(self, input: Option<Vec<String>>) -> Self
List of monitored APM application IDs in New Relic
Sourcepub fn get_application_ids(&self) -> &Option<Vec<String>>
pub fn get_application_ids(&self) -> &Option<Vec<String>>
List of monitored APM application IDs in New Relic
Sourcepub fn entity_guids(self, input: impl Into<String>) -> Self
pub fn entity_guids(self, input: impl Into<String>) -> Self
Appends an item to entity_guids.
To override the contents of this collection use set_entity_guids.
List of globally unique IDs for New Relic resources (apps, hosts, services)
Sourcepub fn set_entity_guids(self, input: Option<Vec<String>>) -> Self
pub fn set_entity_guids(self, input: Option<Vec<String>>) -> Self
List of globally unique IDs for New Relic resources (apps, hosts, services)
Sourcepub fn get_entity_guids(&self) -> &Option<Vec<String>>
pub fn get_entity_guids(&self) -> &Option<Vec<String>>
List of globally unique IDs for New Relic resources (apps, hosts, services)
Sourcepub fn alert_policy_ids(self, input: impl Into<String>) -> Self
pub fn alert_policy_ids(self, input: impl Into<String>) -> Self
Appends an item to alert_policy_ids.
To override the contents of this collection use set_alert_policy_ids.
List of alert policy IDs grouping related conditions
Sourcepub fn set_alert_policy_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_alert_policy_ids(self, input: Option<Vec<String>>) -> Self
List of alert policy IDs grouping related conditions
Sourcepub fn get_alert_policy_ids(&self) -> &Option<Vec<String>>
pub fn get_alert_policy_ids(&self) -> &Option<Vec<String>>
List of alert policy IDs grouping related conditions
Sourcepub fn build(self) -> Result<NewRelicApiKeyConfig, BuildError>
pub fn build(self) -> Result<NewRelicApiKeyConfig, BuildError>
Consumes the builder and constructs a NewRelicApiKeyConfig.
This method will fail if any of the following fields are not set: