#[non_exhaustive]pub struct PagerDutyConfigurationBuilder { /* private fields */ }Expand description
A builder for PagerDutyConfiguration.
Implementations
Sourceimpl PagerDutyConfigurationBuilder
impl PagerDutyConfigurationBuilder
Sourcepub fn services(self, input: impl Into<String>) -> Self
pub fn services(self, input: impl Into<String>) -> Self
Appends an item to services.
To override the contents of this collection use set_services.
List of Pagerduty service available for the association.
Sourcepub fn set_services(self, input: Option<Vec<String>>) -> Self
pub fn set_services(self, input: Option<Vec<String>>) -> Self
List of Pagerduty service available for the association.
Sourcepub fn get_services(&self) -> &Option<Vec<String>>
pub fn get_services(&self) -> &Option<Vec<String>>
List of Pagerduty service available for the association.
Sourcepub fn customer_email(self, input: impl Into<String>) -> Self
pub fn customer_email(self, input: impl Into<String>) -> Self
Email to be used in Pagerduty API header This field is required.
Sourcepub fn set_customer_email(self, input: Option<String>) -> Self
pub fn set_customer_email(self, input: Option<String>) -> Self
Email to be used in Pagerduty API header
Sourcepub fn get_customer_email(&self) -> &Option<String>
pub fn get_customer_email(&self) -> &Option<String>
Email to be used in Pagerduty API header
Sourcepub fn build(self) -> Result<PagerDutyConfiguration, BuildError>
pub fn build(self) -> Result<PagerDutyConfiguration, BuildError>
Consumes the builder and constructs a PagerDutyConfiguration.
This method will fail if any of the following fields are not set: