#[non_exhaustive]pub struct PrivateConnectionSummaryBuilder { /* private fields */ }Expand description
A builder for PrivateConnectionSummary.
Implementations
Sourceimpl PrivateConnectionSummaryBuilder
impl PrivateConnectionSummaryBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the Private Connection. This field is required.
Sourcepub fn type(self, input: PrivateConnectionType) -> Self
pub fn type(self, input: PrivateConnectionType) -> Self
The type of the Private Connection. This field is required.
Sourcepub fn set_type(self, input: Option<PrivateConnectionType>) -> Self
pub fn set_type(self, input: Option<PrivateConnectionType>) -> Self
The type of the Private Connection.
Sourcepub fn get_type(&self) -> &Option<PrivateConnectionType>
pub fn get_type(&self) -> &Option<PrivateConnectionType>
The type of the Private Connection.
Sourcepub fn resource_gateway_id(self, input: impl Into<String>) -> Self
pub fn resource_gateway_id(self, input: impl Into<String>) -> Self
The service-managed Resource Gateway ARN. Only present for service-managed Private Connections.
Sourcepub fn set_resource_gateway_id(self, input: Option<String>) -> Self
pub fn set_resource_gateway_id(self, input: Option<String>) -> Self
The service-managed Resource Gateway ARN. Only present for service-managed Private Connections.
Sourcepub fn get_resource_gateway_id(&self) -> &Option<String>
pub fn get_resource_gateway_id(&self) -> &Option<String>
The service-managed Resource Gateway ARN. Only present for service-managed Private Connections.
Sourcepub fn host_address(self, input: impl Into<String>) -> Self
pub fn host_address(self, input: impl Into<String>) -> Self
IP address or DNS name of the target resource. Only present for service-managed Private Connections.
Sourcepub fn set_host_address(self, input: Option<String>) -> Self
pub fn set_host_address(self, input: Option<String>) -> Self
IP address or DNS name of the target resource. Only present for service-managed Private Connections.
Sourcepub fn get_host_address(&self) -> &Option<String>
pub fn get_host_address(&self) -> &Option<String>
IP address or DNS name of the target resource. Only present for service-managed Private Connections.
Sourcepub fn vpc_id(self, input: impl Into<String>) -> Self
pub fn vpc_id(self, input: impl Into<String>) -> Self
VPC identifier of the service-managed Resource Gateway. Only present for service-managed Private Connections.
Sourcepub fn set_vpc_id(self, input: Option<String>) -> Self
pub fn set_vpc_id(self, input: Option<String>) -> Self
VPC identifier of the service-managed Resource Gateway. Only present for service-managed Private Connections.
Sourcepub fn get_vpc_id(&self) -> &Option<String>
pub fn get_vpc_id(&self) -> &Option<String>
VPC identifier of the service-managed Resource Gateway. Only present for service-managed Private Connections.
Sourcepub fn resource_configuration_id(self, input: impl Into<String>) -> Self
pub fn resource_configuration_id(self, input: impl Into<String>) -> Self
The Resource Configuration ARN. Only present for self-managed Private Connections.
Sourcepub fn set_resource_configuration_id(self, input: Option<String>) -> Self
pub fn set_resource_configuration_id(self, input: Option<String>) -> Self
The Resource Configuration ARN. Only present for self-managed Private Connections.
Sourcepub fn get_resource_configuration_id(&self) -> &Option<String>
pub fn get_resource_configuration_id(&self) -> &Option<String>
The Resource Configuration ARN. Only present for self-managed Private Connections.
Sourcepub fn status(self, input: PrivateConnectionStatus) -> Self
pub fn status(self, input: PrivateConnectionStatus) -> Self
The status of the Private Connection. This field is required.
Sourcepub fn set_status(self, input: Option<PrivateConnectionStatus>) -> Self
pub fn set_status(self, input: Option<PrivateConnectionStatus>) -> Self
The status of the Private Connection.
Sourcepub fn get_status(&self) -> &Option<PrivateConnectionStatus>
pub fn get_status(&self) -> &Option<PrivateConnectionStatus>
The status of the Private Connection.
Sourcepub fn certificate_expiry_time(self, input: DateTime) -> Self
pub fn certificate_expiry_time(self, input: DateTime) -> Self
The expiry time of the certificate associated with the Private Connection. Only present when a certificate is associated.
Sourcepub fn set_certificate_expiry_time(self, input: Option<DateTime>) -> Self
pub fn set_certificate_expiry_time(self, input: Option<DateTime>) -> Self
The expiry time of the certificate associated with the Private Connection. Only present when a certificate is associated.
Sourcepub fn get_certificate_expiry_time(&self) -> &Option<DateTime>
pub fn get_certificate_expiry_time(&self) -> &Option<DateTime>
The expiry time of the certificate associated with the Private Connection. Only present when a certificate is associated.
Sourcepub fn build(self) -> Result<PrivateConnectionSummary, BuildError>
pub fn build(self) -> Result<PrivateConnectionSummary, BuildError>
Consumes the builder and constructs a PrivateConnectionSummary.
This method will fail if any of the following fields are not set: