RecommendationBuilder

Struct RecommendationBuilder 

#[non_exhaustive]
pub struct RecommendationBuilder { /* private fields */ }
A builder for Recommendation.

Implementations

Source

impl RecommendationBuilder

pub fn agent_space_arn(self, input: impl Into<String>) -> Self

ARN of the agent space this recommendation belongs to This field is required.

pub fn set_agent_space_arn(self, input: Option<String>) -> Self

ARN of the agent space this recommendation belongs to

pub fn get_agent_space_arn(&self) -> &Option<String>

ARN of the agent space this recommendation belongs to

pub fn recommendation_id(self, input: impl Into<String>) -> Self

The unique identifier for this recommendation This field is required.

pub fn set_recommendation_id(self, input: Option<String>) -> Self

The unique identifier for this recommendation

pub fn get_recommendation_id(&self) -> &Option<String>

The unique identifier for this recommendation

pub fn task_id(self, input: impl Into<String>) -> Self

ID of the task that generated the recommendation This field is required.

pub fn set_task_id(self, input: Option<String>) -> Self

ID of the task that generated the recommendation

pub fn get_task_id(&self) -> &Option<String>

ID of the task that generated the recommendation

pub fn goal_id(self, input: impl Into<String>) -> Self

ID of the goal this recommendation is associated with

pub fn set_goal_id(self, input: Option<String>) -> Self

ID of the goal this recommendation is associated with

pub fn get_goal_id(&self) -> &Option<String>

ID of the goal this recommendation is associated with

pub fn title(self, input: impl Into<String>) -> Self

The title of the recommendation This field is required.

pub fn set_title(self, input: Option<String>) -> Self

The title of the recommendation

pub fn get_title(&self) -> &Option<String>

The title of the recommendation

pub fn content(self, input: RecommendationContent) -> Self

Content of the recommendation This field is required.

pub fn set_content(self, input: Option<RecommendationContent>) -> Self

Content of the recommendation

pub fn get_content(&self) -> &Option<RecommendationContent>

Content of the recommendation

pub fn status(self, input: RecommendationStatus) -> Self

Current status of the recommendation This field is required.

pub fn set_status(self, input: Option<RecommendationStatus>) -> Self

Current status of the recommendation

pub fn get_status(&self) -> &Option<RecommendationStatus>

Current status of the recommendation

pub fn priority(self, input: RecommendationPriority) -> Self

Priority level of the recommendation This field is required.

pub fn set_priority(self, input: Option<RecommendationPriority>) -> Self

Priority level of the recommendation

pub fn get_priority(&self) -> &Option<RecommendationPriority>

Priority level of the recommendation

pub fn goal_version(self, input: i64) -> Self

Version of the goal at the time this recommendation was generated

pub fn set_goal_version(self, input: Option<i64>) -> Self

Version of the goal at the time this recommendation was generated

pub fn get_goal_version(&self) -> &Option<i64>

Version of the goal at the time this recommendation was generated

pub fn additional_context(self, input: impl Into<String>) -> Self

Additional context for recommendation

pub fn set_additional_context(self, input: Option<String>) -> Self

Additional context for recommendation

pub fn get_additional_context(&self) -> &Option<String>

Additional context for recommendation

pub fn created_at(self, input: DateTime) -> Self

Timestamp when this recommendation was created This field is required.

pub fn set_created_at(self, input: Option<DateTime>) -> Self

Timestamp when this recommendation was created

pub fn get_created_at(&self) -> &Option<DateTime>

Timestamp when this recommendation was created

pub fn updated_at(self, input: DateTime) -> Self

Timestamp when this recommendation was last updated This field is required.

pub fn set_updated_at(self, input: Option<DateTime>) -> Self

Timestamp when this recommendation was last updated

pub fn get_updated_at(&self) -> &Option<DateTime>

Timestamp when this recommendation was last updated

pub fn version(self, input: i64) -> Self

Version number for optimistic locking This field is required.

pub fn set_version(self, input: Option<i64>) -> Self

Version number for optimistic locking

pub fn get_version(&self) -> &Option<i64>

Version number for optimistic locking

pub fn build(self) -> Result<Recommendation, BuildError>

Consumes the builder and constructs a Recommendation. This method will fail if any of the following fields are not set: