#[non_exhaustive]pub struct ReferenceInputBuilder { /* private fields */ }Expand description
A builder for ReferenceInput.
Implementations
Sourceimpl ReferenceInputBuilder
impl ReferenceInputBuilder
Sourcepub fn system(self, input: impl Into<String>) -> Self
pub fn system(self, input: impl Into<String>) -> Self
The name of the external system This field is required.
Sourcepub fn set_system(self, input: Option<String>) -> Self
pub fn set_system(self, input: Option<String>) -> Self
The name of the external system
Sourcepub fn get_system(&self) -> &Option<String>
pub fn get_system(&self) -> &Option<String>
The name of the external system
Sourcepub fn reference_id(self, input: impl Into<String>) -> Self
pub fn reference_id(self, input: impl Into<String>) -> Self
The unique identifier in the external system This field is required.
Sourcepub fn set_reference_id(self, input: Option<String>) -> Self
pub fn set_reference_id(self, input: Option<String>) -> Self
The unique identifier in the external system
Sourcepub fn get_reference_id(&self) -> &Option<String>
pub fn get_reference_id(&self) -> &Option<String>
The unique identifier in the external system
Sourcepub fn reference_url(self, input: impl Into<String>) -> Self
pub fn reference_url(self, input: impl Into<String>) -> Self
URL to access the reference in the external system This field is required.
Sourcepub fn set_reference_url(self, input: Option<String>) -> Self
pub fn set_reference_url(self, input: Option<String>) -> Self
URL to access the reference in the external system
Sourcepub fn get_reference_url(&self) -> &Option<String>
pub fn get_reference_url(&self) -> &Option<String>
URL to access the reference in the external system
Sourcepub fn association_id(self, input: impl Into<String>) -> Self
pub fn association_id(self, input: impl Into<String>) -> Self
Association identifier of the external system This field is required.
Sourcepub fn set_association_id(self, input: Option<String>) -> Self
pub fn set_association_id(self, input: Option<String>) -> Self
Association identifier of the external system
Sourcepub fn get_association_id(&self) -> &Option<String>
pub fn get_association_id(&self) -> &Option<String>
Association identifier of the external system
Sourcepub fn build(self) -> Result<ReferenceInput, BuildError>
pub fn build(self) -> Result<ReferenceInput, BuildError>
Consumes the builder and constructs a ReferenceInput.
This method will fail if any of the following fields are not set: