#[non_exhaustive]pub struct RegisteredAzureIdentityDetailsBuilder { /* private fields */ }Expand description
A builder for RegisteredAzureIdentityDetails.
Implementations
Sourceimpl RegisteredAzureIdentityDetailsBuilder
impl RegisteredAzureIdentityDetailsBuilder
Sourcepub fn tenant_id(self, input: impl Into<String>) -> Self
pub fn tenant_id(self, input: impl Into<String>) -> Self
The Azure Active Directory tenant ID for the identity. This field is required.
Sourcepub fn set_tenant_id(self, input: Option<String>) -> Self
pub fn set_tenant_id(self, input: Option<String>) -> Self
The Azure Active Directory tenant ID for the identity.
Sourcepub fn get_tenant_id(&self) -> &Option<String>
pub fn get_tenant_id(&self) -> &Option<String>
The Azure Active Directory tenant ID for the identity.
Sourcepub fn client_id(self, input: impl Into<String>) -> Self
pub fn client_id(self, input: impl Into<String>) -> Self
The client ID of the service principal or managed identity used for authentication. This field is required.
Sourcepub fn set_client_id(self, input: Option<String>) -> Self
pub fn set_client_id(self, input: Option<String>) -> Self
The client ID of the service principal or managed identity used for authentication.
Sourcepub fn get_client_id(&self) -> &Option<String>
pub fn get_client_id(&self) -> &Option<String>
The client ID of the service principal or managed identity used for authentication.
Sourcepub fn web_identity_role_arn(self, input: impl Into<String>) -> Self
pub fn web_identity_role_arn(self, input: impl Into<String>) -> Self
The role ARN to be assumed by DevOps Agent for requesting Web Identity Token. This field is required.
Sourcepub fn set_web_identity_role_arn(self, input: Option<String>) -> Self
pub fn set_web_identity_role_arn(self, input: Option<String>) -> Self
The role ARN to be assumed by DevOps Agent for requesting Web Identity Token.
Sourcepub fn get_web_identity_role_arn(&self) -> &Option<String>
pub fn get_web_identity_role_arn(&self) -> &Option<String>
The role ARN to be assumed by DevOps Agent for requesting Web Identity Token.
Sourcepub fn web_identity_token_audiences(self, input: impl Into<String>) -> Self
pub fn web_identity_token_audiences(self, input: impl Into<String>) -> Self
Appends an item to web_identity_token_audiences.
To override the contents of this collection use set_web_identity_token_audiences.
The audiences for the Web Identity Token.
Sourcepub fn set_web_identity_token_audiences(
self,
input: Option<Vec<String>>,
) -> Self
pub fn set_web_identity_token_audiences( self, input: Option<Vec<String>>, ) -> Self
The audiences for the Web Identity Token.
Sourcepub fn get_web_identity_token_audiences(&self) -> &Option<Vec<String>>
pub fn get_web_identity_token_audiences(&self) -> &Option<Vec<String>>
The audiences for the Web Identity Token.
Sourcepub fn build(self) -> Result<RegisteredAzureIdentityDetails, BuildError>
pub fn build(self) -> Result<RegisteredAzureIdentityDetails, BuildError>
Consumes the builder and constructs a RegisteredAzureIdentityDetails.
This method will fail if any of the following fields are not set: