#[non_exhaustive]pub struct RegisteredServiceBuilder { /* private fields */ }Expand description
A builder for RegisteredService.
Implementations
Sourceimpl RegisteredServiceBuilder
impl RegisteredServiceBuilder
Sourcepub fn service_id(self, input: impl Into<String>) -> Self
pub fn service_id(self, input: impl Into<String>) -> Self
The unique identifier of a service. This field is required.
Sourcepub fn set_service_id(self, input: Option<String>) -> Self
pub fn set_service_id(self, input: Option<String>) -> Self
The unique identifier of a service.
Sourcepub fn get_service_id(&self) -> &Option<String>
pub fn get_service_id(&self) -> &Option<String>
The unique identifier of a service.
Sourcepub fn service_type(self, input: Service) -> Self
pub fn service_type(self, input: Service) -> Self
The service type e.g github or dynatrace This field is required.
Sourcepub fn set_service_type(self, input: Option<Service>) -> Self
pub fn set_service_type(self, input: Option<Service>) -> Self
The service type e.g github or dynatrace
Sourcepub fn get_service_type(&self) -> &Option<Service>
pub fn get_service_type(&self) -> &Option<Service>
The service type e.g github or dynatrace
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The display name of the registered service.
Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The display name of the registered service.
Sourcepub fn accessible_resources(self, input: Document) -> Self
pub fn accessible_resources(self, input: Document) -> Self
Appends an item to accessible_resources.
To override the contents of this collection use set_accessible_resources.
List of accessible resources for this service.
Sourcepub fn set_accessible_resources(self, input: Option<Vec<Document>>) -> Self
pub fn set_accessible_resources(self, input: Option<Vec<Document>>) -> Self
List of accessible resources for this service.
Sourcepub fn get_accessible_resources(&self) -> &Option<Vec<Document>>
pub fn get_accessible_resources(&self) -> &Option<Vec<Document>>
List of accessible resources for this service.
Sourcepub fn additional_service_details(self, input: AdditionalServiceDetails) -> Self
pub fn additional_service_details(self, input: AdditionalServiceDetails) -> Self
Additional details specific to the service type.
Sourcepub fn set_additional_service_details(
self,
input: Option<AdditionalServiceDetails>,
) -> Self
pub fn set_additional_service_details( self, input: Option<AdditionalServiceDetails>, ) -> Self
Additional details specific to the service type.
Sourcepub fn get_additional_service_details(
&self,
) -> &Option<AdditionalServiceDetails>
pub fn get_additional_service_details( &self, ) -> &Option<AdditionalServiceDetails>
Additional details specific to the service type.
Sourcepub fn kms_key_arn(self, input: impl Into<String>) -> Self
pub fn kms_key_arn(self, input: impl Into<String>) -> Self
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn set_kms_key_arn(self, input: Option<String>) -> Self
pub fn set_kms_key_arn(self, input: Option<String>) -> Self
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn get_kms_key_arn(&self) -> &Option<String>
pub fn get_kms_key_arn(&self) -> &Option<String>
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn private_connection_name(self, input: impl Into<String>) -> Self
pub fn private_connection_name(self, input: impl Into<String>) -> Self
The name of the private connection used for VPC connectivity.
Sourcepub fn set_private_connection_name(self, input: Option<String>) -> Self
pub fn set_private_connection_name(self, input: Option<String>) -> Self
The name of the private connection used for VPC connectivity.
Sourcepub fn get_private_connection_name(&self) -> &Option<String>
pub fn get_private_connection_name(&self) -> &Option<String>
The name of the private connection used for VPC connectivity.
Sourcepub fn build(self) -> Result<RegisteredService, BuildError>
pub fn build(self) -> Result<RegisteredService, BuildError>
Consumes the builder and constructs a RegisteredService.
This method will fail if any of the following fields are not set: