SendMessageContentBlockStopEventBuilder

Struct SendMessageContentBlockStopEventBuilder 

#[non_exhaustive]
pub struct SendMessageContentBlockStopEventBuilder { /* private fields */ }
Implementations

Source

impl SendMessageContentBlockStopEventBuilder

pub fn index(self, input: i32) -> Self

Zero-based index of the content block

pub fn set_index(self, input: Option<i32>) -> Self

Zero-based index of the content block

pub fn get_index(&self) -> &Option<i32>

Zero-based index of the content block

pub fn type(self, input: impl Into<String>) -> Self

The type of content in this block

pub fn set_type(self, input: Option<String>) -> Self

The type of content in this block

pub fn get_type(&self) -> &Option<String>

The type of content in this block

pub fn text(self, input: impl Into<String>) -> Self

The accumulated complete content text

pub fn set_text(self, input: Option<String>) -> Self

The accumulated complete content text

pub fn get_text(&self) -> &Option<String>

The accumulated complete content text

pub fn last(self, input: bool) -> Self

Whether this is the final content block in the response

pub fn set_last(self, input: Option<bool>) -> Self

Whether this is the final content block in the response

pub fn get_last(&self) -> &Option<bool>

Whether this is the final content block in the response

pub fn sequence_number(self, input: i32) -> Self

Event sequence number

pub fn set_sequence_number(self, input: Option<i32>) -> Self

Event sequence number

pub fn get_sequence_number(&self) -> &Option<i32>

Event sequence number

pub fn build(self) -> SendMessageContentBlockStopEvent

Consumes the builder and constructs a SendMessageContentBlockStopEvent.