#[non_exhaustive]pub struct ServiceManagedInputBuilder { /* private fields */ }Expand description
A builder for ServiceManagedInput.
Implementations
Sourceimpl ServiceManagedInputBuilder
impl ServiceManagedInputBuilder
Sourcepub fn host_address(self, input: impl Into<String>) -> Self
pub fn host_address(self, input: impl Into<String>) -> Self
IP address or DNS name of the target resource. This field is required.
Sourcepub fn set_host_address(self, input: Option<String>) -> Self
pub fn set_host_address(self, input: Option<String>) -> Self
IP address or DNS name of the target resource.
Sourcepub fn get_host_address(&self) -> &Option<String>
pub fn get_host_address(&self) -> &Option<String>
IP address or DNS name of the target resource.
Sourcepub fn vpc_id(self, input: impl Into<String>) -> Self
pub fn vpc_id(self, input: impl Into<String>) -> Self
VPC to create the service-managed Resource Gateway in. This field is required.
Sourcepub fn set_vpc_id(self, input: Option<String>) -> Self
pub fn set_vpc_id(self, input: Option<String>) -> Self
VPC to create the service-managed Resource Gateway in.
Sourcepub fn get_vpc_id(&self) -> &Option<String>
pub fn get_vpc_id(&self) -> &Option<String>
VPC to create the service-managed Resource Gateway in.
Sourcepub fn subnet_ids(self, input: impl Into<String>) -> Self
pub fn subnet_ids(self, input: impl Into<String>) -> Self
Appends an item to subnet_ids.
To override the contents of this collection use set_subnet_ids.
Subnets that the service-managed Resource Gateway will span.
Sourcepub fn set_subnet_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_subnet_ids(self, input: Option<Vec<String>>) -> Self
Subnets that the service-managed Resource Gateway will span.
Sourcepub fn get_subnet_ids(&self) -> &Option<Vec<String>>
pub fn get_subnet_ids(&self) -> &Option<Vec<String>>
Subnets that the service-managed Resource Gateway will span.
Sourcepub fn security_group_ids(self, input: impl Into<String>) -> Self
pub fn security_group_ids(self, input: impl Into<String>) -> Self
Appends an item to security_group_ids.
To override the contents of this collection use set_security_group_ids.
Security groups to attach to the service-managed Resource Gateway. If not specified, a default security group is created.
Sourcepub fn set_security_group_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_security_group_ids(self, input: Option<Vec<String>>) -> Self
Security groups to attach to the service-managed Resource Gateway. If not specified, a default security group is created.
Sourcepub fn get_security_group_ids(&self) -> &Option<Vec<String>>
pub fn get_security_group_ids(&self) -> &Option<Vec<String>>
Security groups to attach to the service-managed Resource Gateway. If not specified, a default security group is created.
Sourcepub fn ip_address_type(self, input: IpAddressType) -> Self
pub fn ip_address_type(self, input: IpAddressType) -> Self
IP address type of the service-managed Resource Gateway.
Sourcepub fn set_ip_address_type(self, input: Option<IpAddressType>) -> Self
pub fn set_ip_address_type(self, input: Option<IpAddressType>) -> Self
IP address type of the service-managed Resource Gateway.
Sourcepub fn get_ip_address_type(&self) -> &Option<IpAddressType>
pub fn get_ip_address_type(&self) -> &Option<IpAddressType>
IP address type of the service-managed Resource Gateway.
Sourcepub fn ipv4_addresses_per_eni(self, input: i32) -> Self
pub fn ipv4_addresses_per_eni(self, input: i32) -> Self
Number of IPv4 addresses in each ENI for the service-managed Resource Gateway.
Sourcepub fn set_ipv4_addresses_per_eni(self, input: Option<i32>) -> Self
pub fn set_ipv4_addresses_per_eni(self, input: Option<i32>) -> Self
Number of IPv4 addresses in each ENI for the service-managed Resource Gateway.
Sourcepub fn get_ipv4_addresses_per_eni(&self) -> &Option<i32>
pub fn get_ipv4_addresses_per_eni(&self) -> &Option<i32>
Number of IPv4 addresses in each ENI for the service-managed Resource Gateway.
Sourcepub fn port_ranges(self, input: impl Into<String>) -> Self
pub fn port_ranges(self, input: impl Into<String>) -> Self
Appends an item to port_ranges.
To override the contents of this collection use set_port_ranges.
TCP port ranges that a consumer can use to access the resource.
Sourcepub fn set_port_ranges(self, input: Option<Vec<String>>) -> Self
pub fn set_port_ranges(self, input: Option<Vec<String>>) -> Self
TCP port ranges that a consumer can use to access the resource.
Sourcepub fn get_port_ranges(&self) -> &Option<Vec<String>>
pub fn get_port_ranges(&self) -> &Option<Vec<String>>
TCP port ranges that a consumer can use to access the resource.
Sourcepub fn certificate(self, input: impl Into<String>) -> Self
pub fn certificate(self, input: impl Into<String>) -> Self
Certificate for the Private Connection.
Sourcepub fn set_certificate(self, input: Option<String>) -> Self
pub fn set_certificate(self, input: Option<String>) -> Self
Certificate for the Private Connection.
Sourcepub fn get_certificate(&self) -> &Option<String>
pub fn get_certificate(&self) -> &Option<String>
Certificate for the Private Connection.
Sourcepub fn build(self) -> Result<ServiceManagedInput, BuildError>
pub fn build(self) -> Result<ServiceManagedInput, BuildError>
Consumes the builder and constructs a ServiceManagedInput.
This method will fail if any of the following fields are not set: