#[non_exhaustive]pub struct ServiceNowOAuthClientCredentialsConfigBuilder { /* private fields */ }Expand description
A builder for ServiceNowOAuthClientCredentialsConfig.
Implementations
Sourceimpl ServiceNowOAuthClientCredentialsConfigBuilder
impl ServiceNowOAuthClientCredentialsConfigBuilder
Sourcepub fn client_name(self, input: impl Into<String>) -> Self
pub fn client_name(self, input: impl Into<String>) -> Self
User friendly OAuth client name specified by end user.
Sourcepub fn set_client_name(self, input: Option<String>) -> Self
pub fn set_client_name(self, input: Option<String>) -> Self
User friendly OAuth client name specified by end user.
Sourcepub fn get_client_name(&self) -> &Option<String>
pub fn get_client_name(&self) -> &Option<String>
User friendly OAuth client name specified by end user.
Sourcepub fn client_id(self, input: impl Into<String>) -> Self
pub fn client_id(self, input: impl Into<String>) -> Self
OAuth client ID for authenticating with the service. This field is required.
Sourcepub fn set_client_id(self, input: Option<String>) -> Self
pub fn set_client_id(self, input: Option<String>) -> Self
OAuth client ID for authenticating with the service.
Sourcepub fn get_client_id(&self) -> &Option<String>
pub fn get_client_id(&self) -> &Option<String>
OAuth client ID for authenticating with the service.
Sourcepub fn exchange_parameters(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn exchange_parameters( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to exchange_parameters.
To override the contents of this collection use set_exchange_parameters.
OAuth token exchange parameters for authenticating with the service.
Sourcepub fn set_exchange_parameters(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_exchange_parameters( self, input: Option<HashMap<String, String>>, ) -> Self
OAuth token exchange parameters for authenticating with the service.
Sourcepub fn get_exchange_parameters(&self) -> &Option<HashMap<String, String>>
pub fn get_exchange_parameters(&self) -> &Option<HashMap<String, String>>
OAuth token exchange parameters for authenticating with the service.
Sourcepub fn client_secret(self, input: impl Into<String>) -> Self
pub fn client_secret(self, input: impl Into<String>) -> Self
OAuth client secret for authenticating with the service. This field is required.
Sourcepub fn set_client_secret(self, input: Option<String>) -> Self
pub fn set_client_secret(self, input: Option<String>) -> Self
OAuth client secret for authenticating with the service.
Sourcepub fn get_client_secret(&self) -> &Option<String>
pub fn get_client_secret(&self) -> &Option<String>
OAuth client secret for authenticating with the service.
Sourcepub fn build(self) -> Result<ServiceNowOAuthClientCredentialsConfig, BuildError>
pub fn build(self) -> Result<ServiceNowOAuthClientCredentialsConfig, BuildError>
Consumes the builder and constructs a ServiceNowOAuthClientCredentialsConfig.
This method will fail if any of the following fields are not set: