#[non_exhaustive]pub enum AssetContent {
File(AssetFileContent),
Zip(AssetZipContent),
#[non_exhaustive] Unknown,
}Expand description
Content for an asset, either a single file or a zip bundle
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
File(AssetFileContent)
A single file with path and content
Zip(AssetZipContent)
A zip file containing multiple files
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl AssetContent
impl AssetContent
Sourcepub fn as_file(&self) -> Result<&AssetFileContent, &Self>
pub fn as_file(&self) -> Result<&AssetFileContent, &Self>
Tries to convert the enum instance into File, extracting the inner AssetFileContent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn as_zip(&self) -> Result<&AssetZipContent, &Self>
pub fn as_zip(&self) -> Result<&AssetZipContent, &Self>
Tries to convert the enum instance into Zip, extracting the inner AssetZipContent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.