McpServerAuthorizationConfig

Enum McpServerAuthorizationConfig 

#[non_exhaustive]
pub enum McpServerAuthorizationConfig { ApiKey(McpServerApiKeyConfig), AuthorizationDiscovery(McpServerAuthorizationDiscoveryConfig), BearerToken(McpServerBearerTokenConfig), OAuth3Lo(McpServerOAuth3LoConfig), OAuthClientCredentials(McpServerOAuthClientCredentialsConfig),
#[non_exhaustive]
Unknown, }
Authorization configuration options for MCP server, supporting OAuth, API key, bearer token, and authorization discovery methods.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ApiKey(McpServerApiKeyConfig)

MCP server configuration with API key authentication.



AuthorizationDiscovery(McpServerAuthorizationDiscoveryConfig)

MCP server authorization discovery configuration.



BearerToken(McpServerBearerTokenConfig)

MCP server configuration with Bearer token (RFC 6750).



OAuth3Lo(McpServerOAuth3LoConfig)

MCP server configuration with OAuth 3LO.



OAuthClientCredentials(McpServerOAuthClientCredentialsConfig)

MCP server configuration with OAuth client credentials.



#[non_exhaustive]
Unknown

The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version. An unknown enum variant

Note: If you encounter this error, consider upgrading your SDK to the latest version. The Unknown variant represents cases where the server sent a value that wasn’t recognized by the client. This can happen when the server adds new functionality, but the client has not been updated. To investigate this, consider turning on debug logging to print the raw HTTP response.

Implementations

Source

impl McpServerAuthorizationConfig

pub fn as_api_key(&self) -> Result<&McpServerApiKeyConfig, &Self>

Tries to convert the enum instance into ApiKey, extracting the inner McpServerApiKeyConfig. Returns Err(&Self) if it can’t be converted.

pub fn is_api_key(&self) -> bool

Returns true if this is a ApiKey.

pub fn as_authorization_discovery( &self, ) -> Result<&McpServerAuthorizationDiscoveryConfig, &Self>

Tries to convert the enum instance into AuthorizationDiscovery, extracting the inner McpServerAuthorizationDiscoveryConfig. Returns Err(&Self) if it can’t be converted.

pub fn is_authorization_discovery(&self) -> bool

Returns true if this is a AuthorizationDiscovery.

pub fn as_bearer_token(&self) -> Result<&McpServerBearerTokenConfig, &Self>

Tries to convert the enum instance into BearerToken, extracting the inner McpServerBearerTokenConfig. Returns Err(&Self) if it can’t be converted.

pub fn is_bearer_token(&self) -> bool

Returns true if this is a BearerToken.

pub fn as_o_auth3_lo(&self) -> Result<&McpServerOAuth3LoConfig, &Self>

Tries to convert the enum instance into OAuth3Lo, extracting the inner McpServerOAuth3LoConfig. Returns Err(&Self) if it can’t be converted.

pub fn is_o_auth3_lo(&self) -> bool

Returns true if this is a OAuth3Lo.

pub fn as_o_auth_client_credentials( &self, ) -> Result<&McpServerOAuthClientCredentialsConfig, &Self>

Tries to convert the enum instance into OAuthClientCredentials, extracting the inner McpServerOAuthClientCredentialsConfig. Returns Err(&Self) if it can’t be converted.

pub fn is_o_auth_client_credentials(&self) -> bool

Returns true if this is a OAuthClientCredentials.

pub fn is_unknown(&self) -> bool

Returns true if the enum instance is the Unknown variant.