#[non_exhaustive]pub enum Message {
AssistantMessage(Vec<AssistantMessageBlock>),
UserMessage(Vec<UserMessageBlock>),
#[non_exhaustive] Unknown,
}Expand description
A message in a conversation, either from the user or the assistant.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AssistantMessage(Vec<AssistantMessageBlock>)
A message from the assistant.
UserMessage(Vec<UserMessageBlock>)
A message from the user.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl Message
impl Message
Sourcepub fn as_assistant_message(&self) -> Result<&Vec<AssistantMessageBlock>, &Self>
pub fn as_assistant_message(&self) -> Result<&Vec<AssistantMessageBlock>, &Self>
Tries to convert the enum instance into AssistantMessage, extracting the inner Vec.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_assistant_message(&self) -> bool
pub fn is_assistant_message(&self) -> bool
Returns true if this is a AssistantMessage.
Sourcepub fn as_user_message(&self) -> Result<&Vec<UserMessageBlock>, &Self>
pub fn as_user_message(&self) -> Result<&Vec<UserMessageBlock>, &Self>
Tries to convert the enum instance into UserMessage, extracting the inner Vec.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_user_message(&self) -> bool
pub fn is_user_message(&self) -> bool
Returns true if this is a UserMessage.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.