#[non_exhaustive]pub enum NewRelicServiceAuthorizationConfig {
ApiKey(NewRelicApiKeyConfig),
#[non_exhaustive] Unknown,
}Expand description
Authorization configuration options for New Relic service.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApiKey(NewRelicApiKeyConfig)
New Relic API Key authentication (apiKey, accountId, region).
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl NewRelicServiceAuthorizationConfig
impl NewRelicServiceAuthorizationConfig
Sourcepub fn as_api_key(&self) -> Result<&NewRelicApiKeyConfig, &Self>
pub fn as_api_key(&self) -> Result<&NewRelicApiKeyConfig, &Self>
Tries to convert the enum instance into ApiKey, extracting the inner NewRelicApiKeyConfig.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_api_key(&self) -> bool
pub fn is_api_key(&self) -> bool
Returns true if this is a ApiKey.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.