#[non_exhaustive]pub enum RemoteAgentAuthorizationConfig {
ApiKey(RemoteAgentApiKeyConfig),
BearerToken(RemoteAgentBearerTokenConfig),
OAuthClientCredentials(RemoteAgentOAuthClientCredentialsConfig),
#[non_exhaustive] Unknown,
}Expand description
Authorization configuration for remote A2A agents with token-based auth (API key, OAuth, bearer token).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApiKey(RemoteAgentApiKeyConfig)
Remote agent configuration with API key authentication.
BearerToken(RemoteAgentBearerTokenConfig)
Remote agent configuration with Bearer token (RFC 6750).
OAuthClientCredentials(RemoteAgentOAuthClientCredentialsConfig)
Remote agent configuration with OAuth client credentials.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl RemoteAgentAuthorizationConfig
impl RemoteAgentAuthorizationConfig
Sourcepub fn as_api_key(&self) -> Result<&RemoteAgentApiKeyConfig, &Self>
pub fn as_api_key(&self) -> Result<&RemoteAgentApiKeyConfig, &Self>
Tries to convert the enum instance into ApiKey, extracting the inner RemoteAgentApiKeyConfig.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_api_key(&self) -> bool
pub fn is_api_key(&self) -> bool
Returns true if this is a ApiKey.
Sourcepub fn as_bearer_token(&self) -> Result<&RemoteAgentBearerTokenConfig, &Self>
pub fn as_bearer_token(&self) -> Result<&RemoteAgentBearerTokenConfig, &Self>
Tries to convert the enum instance into BearerToken, extracting the inner RemoteAgentBearerTokenConfig.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_bearer_token(&self) -> bool
pub fn is_bearer_token(&self) -> bool
Returns true if this is a BearerToken.
Sourcepub fn as_o_auth_client_credentials(
&self,
) -> Result<&RemoteAgentOAuthClientCredentialsConfig, &Self>
pub fn as_o_auth_client_credentials( &self, ) -> Result<&RemoteAgentOAuthClientCredentialsConfig, &Self>
Tries to convert the enum instance into OAuthClientCredentials, extracting the inner RemoteAgentOAuthClientCredentialsConfig.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_o_auth_client_credentials(&self) -> bool
pub fn is_o_auth_client_credentials(&self) -> bool
Returns true if this is a OAuthClientCredentials.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.