#[non_exhaustive]pub enum SendMessageEvents {
ContentBlockDelta(SendMessageContentBlockDeltaEvent),
ContentBlockStart(SendMessageContentBlockStartEvent),
ContentBlockStop(SendMessageContentBlockStopEvent),
Heartbeat(SendMessageHeartbeatEvent),
ResponseCompleted(SendMessageResponseCompletedEvent),
ResponseCreated(SendMessageResponseCreatedEvent),
ResponseFailed(SendMessageResponseFailedEvent),
ResponseInProgress(SendMessageResponseInProgressEvent),
Summary(SendMessageSummaryEvent),
#[non_exhaustive] Unknown,
}Expand description
Event stream for chat message responses using the content block model. Events follow a lifecycle: responseCreated -> responseInProgress -> (contentBlockStart/contentBlockDelta/contentBlockStop events) -> responseCompleted|responseFailed SendMessage always uses content block mode — legacy per-field events (outputTextDelta, functionCallArgumentsDelta, etc.) are not emitted.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ContentBlockDelta(SendMessageContentBlockDeltaEvent)
Emitted for each incremental content delta within a content block
ContentBlockStart(SendMessageContentBlockStartEvent)
Emitted when a new content block starts
ContentBlockStop(SendMessageContentBlockStopEvent)
Emitted when a content block is complete
Heartbeat(SendMessageHeartbeatEvent)
Heartbeat event sent periodically to keep the connection alive during idle periods
ResponseCompleted(SendMessageResponseCompletedEvent)
Emitted when the response completes successfully
ResponseCreated(SendMessageResponseCreatedEvent)
Emitted when the response is created
ResponseFailed(SendMessageResponseFailedEvent)
Emitted when the response fails
ResponseInProgress(SendMessageResponseInProgressEvent)
Emitted while the response is being generated
Summary(SendMessageSummaryEvent)
Emitted to provide a summary of agent actions
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl SendMessageEvents
impl SendMessageEvents
Sourcepub fn as_content_block_delta(
&self,
) -> Result<&SendMessageContentBlockDeltaEvent, &Self>
pub fn as_content_block_delta( &self, ) -> Result<&SendMessageContentBlockDeltaEvent, &Self>
Tries to convert the enum instance into ContentBlockDelta, extracting the inner SendMessageContentBlockDeltaEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_content_block_delta(&self) -> bool
pub fn is_content_block_delta(&self) -> bool
Returns true if this is a ContentBlockDelta.
Sourcepub fn as_content_block_start(
&self,
) -> Result<&SendMessageContentBlockStartEvent, &Self>
pub fn as_content_block_start( &self, ) -> Result<&SendMessageContentBlockStartEvent, &Self>
Tries to convert the enum instance into ContentBlockStart, extracting the inner SendMessageContentBlockStartEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_content_block_start(&self) -> bool
pub fn is_content_block_start(&self) -> bool
Returns true if this is a ContentBlockStart.
Sourcepub fn as_content_block_stop(
&self,
) -> Result<&SendMessageContentBlockStopEvent, &Self>
pub fn as_content_block_stop( &self, ) -> Result<&SendMessageContentBlockStopEvent, &Self>
Tries to convert the enum instance into ContentBlockStop, extracting the inner SendMessageContentBlockStopEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_content_block_stop(&self) -> bool
pub fn is_content_block_stop(&self) -> bool
Returns true if this is a ContentBlockStop.
Sourcepub fn as_heartbeat(&self) -> Result<&SendMessageHeartbeatEvent, &Self>
pub fn as_heartbeat(&self) -> Result<&SendMessageHeartbeatEvent, &Self>
Tries to convert the enum instance into Heartbeat, extracting the inner SendMessageHeartbeatEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_heartbeat(&self) -> bool
pub fn is_heartbeat(&self) -> bool
Returns true if this is a Heartbeat.
Sourcepub fn as_response_completed(
&self,
) -> Result<&SendMessageResponseCompletedEvent, &Self>
pub fn as_response_completed( &self, ) -> Result<&SendMessageResponseCompletedEvent, &Self>
Tries to convert the enum instance into ResponseCompleted, extracting the inner SendMessageResponseCompletedEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_response_completed(&self) -> bool
pub fn is_response_completed(&self) -> bool
Returns true if this is a ResponseCompleted.
Sourcepub fn as_response_created(
&self,
) -> Result<&SendMessageResponseCreatedEvent, &Self>
pub fn as_response_created( &self, ) -> Result<&SendMessageResponseCreatedEvent, &Self>
Tries to convert the enum instance into ResponseCreated, extracting the inner SendMessageResponseCreatedEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_response_created(&self) -> bool
pub fn is_response_created(&self) -> bool
Returns true if this is a ResponseCreated.
Sourcepub fn as_response_failed(
&self,
) -> Result<&SendMessageResponseFailedEvent, &Self>
pub fn as_response_failed( &self, ) -> Result<&SendMessageResponseFailedEvent, &Self>
Tries to convert the enum instance into ResponseFailed, extracting the inner SendMessageResponseFailedEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_response_failed(&self) -> bool
pub fn is_response_failed(&self) -> bool
Returns true if this is a ResponseFailed.
Sourcepub fn as_response_in_progress(
&self,
) -> Result<&SendMessageResponseInProgressEvent, &Self>
pub fn as_response_in_progress( &self, ) -> Result<&SendMessageResponseInProgressEvent, &Self>
Tries to convert the enum instance into ResponseInProgress, extracting the inner SendMessageResponseInProgressEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_response_in_progress(&self) -> bool
pub fn is_response_in_progress(&self) -> bool
Returns true if this is a ResponseInProgress.
Sourcepub fn as_summary(&self) -> Result<&SendMessageSummaryEvent, &Self>
pub fn as_summary(&self) -> Result<&SendMessageSummaryEvent, &Self>
Tries to convert the enum instance into Summary, extracting the inner SendMessageSummaryEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_summary(&self) -> bool
pub fn is_summary(&self) -> bool
Returns true if this is a Summary.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.