ServiceConfiguration

Enum ServiceConfiguration 

#[non_exhaustive]
pub enum ServiceConfiguration {
Show 14 variants Aws(AwsConfiguration), Azure(AzureConfiguration), Azuredevops(AzureDevOpsConfiguration), Dynatrace(DynatraceConfiguration), EventChannel(EventChannelConfiguration), Github(GitHubConfiguration), Gitlab(GitLabConfiguration), Mcpservergrafana(McpServerGrafanaConfiguration), Mcpservernewrelic(McpServerNewRelicConfiguration), Pagerduty(PagerDutyConfiguration), Servicenow(ServiceNowConfiguration), Slack(SlackConfiguration), SourceAws(SourceAwsConfiguration),
#[non_exhaustive]
Unknown,
}
Union of all supported service configuration types. Each service has its own specific configuration structure.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Aws(AwsConfiguration)

AWS monitor account configuration.



Azure(AzureConfiguration)

Azure subscription integration configuration.



Azuredevops(AzureDevOpsConfiguration)

Azure DevOps project integration configuration.



Dynatrace(DynatraceConfiguration)

Dynatrace monitoring integration configuration.



EventChannel(EventChannelConfiguration)

Event Channel instance integration configuration.



Github(GitHubConfiguration)

GitHub repository integration configuration.



Gitlab(GitLabConfiguration)

GitLab project integration configuration.



Mcpservergrafana(McpServerGrafanaConfiguration)

Grafana MCP server integration configuration.



Mcpservernewrelic(McpServerNewRelicConfiguration)

NewRelic instance integration configuration.



Pagerduty(PagerDutyConfiguration)

PagerDuty integration configuration



Servicenow(ServiceNowConfiguration)

ServiceNow instance integration configuration.



Slack(SlackConfiguration)

Slack workspace integration configuration.



SourceAws(SourceAwsConfiguration)

AWS source account configuration for monitoring resources.



#[non_exhaustive]
Unknown

The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version. An unknown enum variant

Note: If you encounter this error, consider upgrading your SDK to the latest version. The Unknown variant represents cases where the server sent a value that wasn’t recognized by the client. This can happen when the server adds new functionality, but the client has not been updated. To investigate this, consider turning on debug logging to print the raw HTTP response.

Implementations

Source

impl ServiceConfiguration

pub fn as_aws(&self) -> Result<&AwsConfiguration, &Self>

Tries to convert the enum instance into Aws, extracting the inner AwsConfiguration. Returns Err(&Self) if it can’t be converted.

pub fn is_aws(&self) -> bool

Returns true if this is a Aws.

pub fn as_azure(&self) -> Result<&AzureConfiguration, &Self>

Tries to convert the enum instance into Azure, extracting the inner AzureConfiguration. Returns Err(&Self) if it can’t be converted.

pub fn is_azure(&self) -> bool

Returns true if this is a Azure.

pub fn as_azuredevops(&self) -> Result<&AzureDevOpsConfiguration, &Self>

Tries to convert the enum instance into Azuredevops, extracting the inner AzureDevOpsConfiguration. Returns Err(&Self) if it can’t be converted.

pub fn is_azuredevops(&self) -> bool

Returns true if this is a Azuredevops.

pub fn as_dynatrace(&self) -> Result<&DynatraceConfiguration, &Self>

Tries to convert the enum instance into Dynatrace, extracting the inner DynatraceConfiguration. Returns Err(&Self) if it can’t be converted.

pub fn is_dynatrace(&self) -> bool

Returns true if this is a Dynatrace.

pub fn as_event_channel(&self) -> Result<&EventChannelConfiguration, &Self>

Tries to convert the enum instance into EventChannel, extracting the inner EventChannelConfiguration. Returns Err(&Self) if it can’t be converted.

pub fn is_event_channel(&self) -> bool

Returns true if this is a EventChannel.

pub fn as_github(&self) -> Result<&GitHubConfiguration, &Self>

Tries to convert the enum instance into Github, extracting the inner GitHubConfiguration. Returns Err(&Self) if it can’t be converted.

pub fn is_github(&self) -> bool

Returns true if this is a Github.

pub fn as_gitlab(&self) -> Result<&GitLabConfiguration, &Self>

Tries to convert the enum instance into Gitlab, extracting the inner GitLabConfiguration. Returns Err(&Self) if it can’t be converted.

pub fn is_gitlab(&self) -> bool

Returns true if this is a Gitlab.

pub fn as_mcpservergrafana( &self, ) -> Result<&McpServerGrafanaConfiguration, &Self>

Tries to convert the enum instance into Mcpservergrafana, extracting the inner McpServerGrafanaConfiguration. Returns Err(&Self) if it can’t be converted.

pub fn is_mcpservergrafana(&self) -> bool

Returns true if this is a Mcpservergrafana.

pub fn as_mcpservernewrelic( &self, ) -> Result<&McpServerNewRelicConfiguration, &Self>

Tries to convert the enum instance into Mcpservernewrelic, extracting the inner McpServerNewRelicConfiguration. Returns Err(&Self) if it can’t be converted.

pub fn is_mcpservernewrelic(&self) -> bool

Returns true if this is a Mcpservernewrelic.

pub fn as_pagerduty(&self) -> Result<&PagerDutyConfiguration, &Self>

Tries to convert the enum instance into Pagerduty, extracting the inner PagerDutyConfiguration. Returns Err(&Self) if it can’t be converted.

pub fn is_pagerduty(&self) -> bool

Returns true if this is a Pagerduty.

pub fn as_servicenow(&self) -> Result<&ServiceNowConfiguration, &Self>

Tries to convert the enum instance into Servicenow, extracting the inner ServiceNowConfiguration. Returns Err(&Self) if it can’t be converted.

pub fn is_servicenow(&self) -> bool

Returns true if this is a Servicenow.

pub fn as_slack(&self) -> Result<&SlackConfiguration, &Self>

Tries to convert the enum instance into Slack, extracting the inner SlackConfiguration. Returns Err(&Self) if it can’t be converted.

pub fn is_slack(&self) -> bool

Returns true if this is a Slack.

pub fn as_source_aws(&self) -> Result<&SourceAwsConfiguration, &Self>

Tries to convert the enum instance into SourceAws, extracting the inner SourceAwsConfiguration. Returns Err(&Self) if it can’t be converted.

pub fn is_source_aws(&self) -> bool

Returns true if this is a SourceAws.

pub fn is_unknown(&self) -> bool

Returns true if the enum instance is the Unknown variant.