#[non_exhaustive]pub enum ServiceDetails {
Azureidentity(RegisteredAzureIdentityDetails),
Dynatrace(DynatraceServiceDetails),
EventChannel(EventChannelDetails),
Gitlab(GitLabDetails),
Mcpserver(McpServerDetails),
Mcpserverdatadog(DatadogServiceDetails),
Mcpservergrafana(GrafanaServiceDetails),
Mcpservernewrelic(NewRelicServiceDetails),
Mcpserversplunk(McpServerDetails),
Pagerduty(PagerDutyDetails),
Servicenow(ServiceNowServiceDetails),
#[non_exhaustive] Unknown,
}Expand description
Union of service-specific configuration details for service registration.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Azureidentity(RegisteredAzureIdentityDetails)
Azure integration with AWS Outbound Identity Federation specific service details.
Dynatrace(DynatraceServiceDetails)
Dynatrace-specific service details.
EventChannel(EventChannelDetails)
Event Channel specific service details.
Gitlab(GitLabDetails)
GitLab-specific service details.
Mcpserver(McpServerDetails)
MCP server-specific service details.
Mcpserverdatadog(DatadogServiceDetails)
Datadog MCP server-specific service details.
Mcpservergrafana(GrafanaServiceDetails)
Datadog MCP server-specific service details.
Mcpservernewrelic(NewRelicServiceDetails)
New Relic-specific service details.
Mcpserversplunk(McpServerDetails)
Splunk MCP server-specific service details.
Pagerduty(PagerDutyDetails)
PagerDuty specific service details.
Servicenow(ServiceNowServiceDetails)
ServiceNow-specific service details.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl ServiceDetails
impl ServiceDetails
Sourcepub fn as_azureidentity(&self) -> Result<&RegisteredAzureIdentityDetails, &Self>
pub fn as_azureidentity(&self) -> Result<&RegisteredAzureIdentityDetails, &Self>
Tries to convert the enum instance into Azureidentity, extracting the inner RegisteredAzureIdentityDetails.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_azureidentity(&self) -> bool
pub fn is_azureidentity(&self) -> bool
Returns true if this is a Azureidentity.
Sourcepub fn as_dynatrace(&self) -> Result<&DynatraceServiceDetails, &Self>
pub fn as_dynatrace(&self) -> Result<&DynatraceServiceDetails, &Self>
Tries to convert the enum instance into Dynatrace, extracting the inner DynatraceServiceDetails.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_dynatrace(&self) -> bool
pub fn is_dynatrace(&self) -> bool
Returns true if this is a Dynatrace.
Sourcepub fn as_event_channel(&self) -> Result<&EventChannelDetails, &Self>
pub fn as_event_channel(&self) -> Result<&EventChannelDetails, &Self>
Tries to convert the enum instance into EventChannel, extracting the inner EventChannelDetails.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_event_channel(&self) -> bool
pub fn is_event_channel(&self) -> bool
Returns true if this is a EventChannel.
Sourcepub fn as_gitlab(&self) -> Result<&GitLabDetails, &Self>
pub fn as_gitlab(&self) -> Result<&GitLabDetails, &Self>
Tries to convert the enum instance into Gitlab, extracting the inner GitLabDetails.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn as_mcpserver(&self) -> Result<&McpServerDetails, &Self>
pub fn as_mcpserver(&self) -> Result<&McpServerDetails, &Self>
Tries to convert the enum instance into Mcpserver, extracting the inner McpServerDetails.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_mcpserver(&self) -> bool
pub fn is_mcpserver(&self) -> bool
Returns true if this is a Mcpserver.
Sourcepub fn as_mcpserverdatadog(&self) -> Result<&DatadogServiceDetails, &Self>
pub fn as_mcpserverdatadog(&self) -> Result<&DatadogServiceDetails, &Self>
Tries to convert the enum instance into Mcpserverdatadog, extracting the inner DatadogServiceDetails.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_mcpserverdatadog(&self) -> bool
pub fn is_mcpserverdatadog(&self) -> bool
Returns true if this is a Mcpserverdatadog.
Sourcepub fn as_mcpservergrafana(&self) -> Result<&GrafanaServiceDetails, &Self>
pub fn as_mcpservergrafana(&self) -> Result<&GrafanaServiceDetails, &Self>
Tries to convert the enum instance into Mcpservergrafana, extracting the inner GrafanaServiceDetails.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_mcpservergrafana(&self) -> bool
pub fn is_mcpservergrafana(&self) -> bool
Returns true if this is a Mcpservergrafana.
Sourcepub fn as_mcpservernewrelic(&self) -> Result<&NewRelicServiceDetails, &Self>
pub fn as_mcpservernewrelic(&self) -> Result<&NewRelicServiceDetails, &Self>
Tries to convert the enum instance into Mcpservernewrelic, extracting the inner NewRelicServiceDetails.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_mcpservernewrelic(&self) -> bool
pub fn is_mcpservernewrelic(&self) -> bool
Returns true if this is a Mcpservernewrelic.
Sourcepub fn as_mcpserversplunk(&self) -> Result<&McpServerDetails, &Self>
pub fn as_mcpserversplunk(&self) -> Result<&McpServerDetails, &Self>
Tries to convert the enum instance into Mcpserversplunk, extracting the inner McpServerDetails.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_mcpserversplunk(&self) -> bool
pub fn is_mcpserversplunk(&self) -> bool
Returns true if this is a Mcpserversplunk.
Sourcepub fn as_pagerduty(&self) -> Result<&PagerDutyDetails, &Self>
pub fn as_pagerduty(&self) -> Result<&PagerDutyDetails, &Self>
Tries to convert the enum instance into Pagerduty, extracting the inner PagerDutyDetails.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_pagerduty(&self) -> bool
pub fn is_pagerduty(&self) -> bool
Returns true if this is a Pagerduty.
Sourcepub fn as_servicenow(&self) -> Result<&ServiceNowServiceDetails, &Self>
pub fn as_servicenow(&self) -> Result<&ServiceNowServiceDetails, &Self>
Tries to convert the enum instance into Servicenow, extracting the inner ServiceNowServiceDetails.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_servicenow(&self) -> bool
pub fn is_servicenow(&self) -> bool
Returns true if this is a Servicenow.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.