#[non_exhaustive]pub struct AgentSpace {
pub name: String,
pub description: Option<String>,
pub locale: Option<String>,
pub created_at: DateTime,
pub updated_at: DateTime,
pub kms_key_arn: Option<String>,
pub agent_space_id: String,
}Expand description
Represents a complete AgentSpace with all its properties, timestamps, encryption settings, and unique identifier.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the AgentSpace.
description: Option<String>The description of the AgentSpace.
locale: Option<String>The locale for the AgentSpace, which determines the language used in agent responses.
created_at: DateTimeThe timestamp when the resource was created.
updated_at: DateTimeThe timestamp when the resource was last updated.
kms_key_arn: Option<String>The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
agent_space_id: StringThe unique identifier of the AgentSpace
Implementations
Sourceimpl AgentSpace
impl AgentSpace
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the AgentSpace.
Sourcepub fn locale(&self) -> Option<&str>
pub fn locale(&self) -> Option<&str>
The locale for the AgentSpace, which determines the language used in agent responses.
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
The timestamp when the resource was created.
Sourcepub fn updated_at(&self) -> &DateTime
pub fn updated_at(&self) -> &DateTime
The timestamp when the resource was last updated.
Sourcepub fn kms_key_arn(&self) -> Option<&str>
pub fn kms_key_arn(&self) -> Option<&str>
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn agent_space_id(&self) -> &str
pub fn agent_space_id(&self) -> &str
The unique identifier of the AgentSpace
Sourceimpl AgentSpace
impl AgentSpace
Sourcepub fn builder() -> AgentSpaceBuilder
pub fn builder() -> AgentSpaceBuilder
Creates a new builder-style object to manufacture AgentSpace.