#[non_exhaustive]pub struct ChatParticipantConnection {
pub initial_contact_id: String,
pub participant_id: String,
pub participant_token: String,
}Expand description
Represents a chat participant connection with all its properties and metadata
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.initial_contact_id: StringThe identifier of the contact in this instance of Amazon Connect
participant_id: StringThe identifier for a chat participant
participant_token: StringThe token used by the chat participant to call CreateParticipantConnection
Implementations
Sourceimpl ChatParticipantConnection
impl ChatParticipantConnection
Sourcepub fn initial_contact_id(&self) -> &str
pub fn initial_contact_id(&self) -> &str
The identifier of the contact in this instance of Amazon Connect
Sourcepub fn participant_id(&self) -> &str
pub fn participant_id(&self) -> &str
The identifier for a chat participant
Sourcepub fn participant_token(&self) -> &str
pub fn participant_token(&self) -> &str
The token used by the chat participant to call CreateParticipantConnection
Sourceimpl ChatParticipantConnection
impl ChatParticipantConnection
Sourcepub fn builder() -> ChatParticipantConnectionBuilder
pub fn builder() -> ChatParticipantConnectionBuilder
Creates a new builder-style object to manufacture ChatParticipantConnection.