#[non_exhaustive]pub struct Execution {
pub agent_space_id: String,
pub execution_id: String,
pub parent_execution_id: Option<String>,
pub agent_sub_task: String,
pub created_at: DateTime,
pub updated_at: DateTime,
pub execution_status: ExecutionStatus,
pub agent_type: Option<String>,
pub uid: Option<String>,
}Expand description
Represents an execution instance with its lifecycle information
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: StringThe unique identifier for the agent space containing this execution
execution_id: StringThe unique identifier for this execution
parent_execution_id: Option<String>The identifier of the parent execution, if this is a child execution
agent_sub_task: StringThe specific subtask being executed by the agent
created_at: DateTimeTimestamp when this execution was created
updated_at: DateTimeTimestamp when this execution was last updated
execution_status: ExecutionStatusThe current status of this execution
agent_type: Option<String>The type of agent that performed this execution.
uid: Option<String>The unique identifier for the user session associated with this execution
Implementations
Sourceimpl Execution
impl Execution
Sourcepub fn agent_space_id(&self) -> &str
pub fn agent_space_id(&self) -> &str
The unique identifier for the agent space containing this execution
Sourcepub fn execution_id(&self) -> &str
pub fn execution_id(&self) -> &str
The unique identifier for this execution
Sourcepub fn parent_execution_id(&self) -> Option<&str>
pub fn parent_execution_id(&self) -> Option<&str>
The identifier of the parent execution, if this is a child execution
Sourcepub fn agent_sub_task(&self) -> &str
pub fn agent_sub_task(&self) -> &str
The specific subtask being executed by the agent
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
Timestamp when this execution was created
Sourcepub fn updated_at(&self) -> &DateTime
pub fn updated_at(&self) -> &DateTime
Timestamp when this execution was last updated
Sourcepub fn execution_status(&self) -> &ExecutionStatus
pub fn execution_status(&self) -> &ExecutionStatus
The current status of this execution
Sourcepub fn agent_type(&self) -> Option<&str>
pub fn agent_type(&self) -> Option<&str>
The type of agent that performed this execution.