#[non_exhaustive]pub struct Goal {Show 13 fields
pub agent_space_arn: String,
pub goal_id: String,
pub title: String,
pub content: Option<GoalContent>,
pub status: GoalStatus,
pub goal_type: GoalType,
pub created_at: DateTime,
pub updated_at: DateTime,
pub last_evaluated_at: Option<DateTime>,
pub last_task_id: Option<String>,
pub last_successful_task_id: Option<String>,
pub version: i32,
pub evaluation_schedule: Option<GoalSchedule>,
}Expand description
Represents a goal with all its properties and metadata
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_arn: StringThe unique identifier for the agent space containing this goal
goal_id: StringThe unique identifier for this goal
title: StringThe title of the goal
content: Option<GoalContent>Content of the goal
status: GoalStatusCurrent status of the goal itself
goal_type: GoalTypeType of goal based on its origin
created_at: DateTimeTimestamp when this goal was created
updated_at: DateTimeTimestamp when this goal was last updated
last_evaluated_at: Option<DateTime>Timestamp when the goal was last evaluated
last_task_id: Option<String>ID of the most recent task associated with this goal
last_successful_task_id: Option<String>ID of the most recent successful task associated with this goal
version: i32Version number for optimistic locking
evaluation_schedule: Option<GoalSchedule>Goal Schedule. Allows to schedule the goal to run periodically, as well as disable a goal temporarily
Implementations
Sourceimpl Goal
impl Goal
Sourcepub fn agent_space_arn(&self) -> &str
pub fn agent_space_arn(&self) -> &str
The unique identifier for the agent space containing this goal
Sourcepub fn content(&self) -> Option<&GoalContent>
pub fn content(&self) -> Option<&GoalContent>
Content of the goal
Sourcepub fn status(&self) -> &GoalStatus
pub fn status(&self) -> &GoalStatus
Current status of the goal itself
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
Timestamp when this goal was created
Sourcepub fn updated_at(&self) -> &DateTime
pub fn updated_at(&self) -> &DateTime
Timestamp when this goal was last updated
Sourcepub fn last_evaluated_at(&self) -> Option<&DateTime>
pub fn last_evaluated_at(&self) -> Option<&DateTime>
Timestamp when the goal was last evaluated
Sourcepub fn last_task_id(&self) -> Option<&str>
pub fn last_task_id(&self) -> Option<&str>
ID of the most recent task associated with this goal
Sourcepub fn last_successful_task_id(&self) -> Option<&str>
pub fn last_successful_task_id(&self) -> Option<&str>
ID of the most recent successful task associated with this goal
Sourcepub fn evaluation_schedule(&self) -> Option<&GoalSchedule>
pub fn evaluation_schedule(&self) -> Option<&GoalSchedule>
Goal Schedule. Allows to schedule the goal to run periodically, as well as disable a goal temporarily