#[non_exhaustive]pub struct McpServerBearerTokenConfig {
pub token_name: String,
pub token_value: String,
pub authorization_header: String,
}Expand description
Bearer token configuration for MCP server (RFC 6750).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.token_name: StringUser friendly bearer token name specified by end user.
token_value: StringBearer token value in alphanumeric for authenticating with the service.
HTTP header name to send the bearer token in requests to the service. Defaults to ‘Authorization’ per RFC 6750.
Implementations
Sourceimpl McpServerBearerTokenConfig
impl McpServerBearerTokenConfig
Sourcepub fn token_name(&self) -> &str
pub fn token_name(&self) -> &str
User friendly bearer token name specified by end user.
Sourcepub fn token_value(&self) -> &str
pub fn token_value(&self) -> &str
Bearer token value in alphanumeric for authenticating with the service.
HTTP header name to send the bearer token in requests to the service. Defaults to ‘Authorization’ per RFC 6750.
Sourceimpl McpServerBearerTokenConfig
impl McpServerBearerTokenConfig
Sourcepub fn builder() -> McpServerBearerTokenConfigBuilder
pub fn builder() -> McpServerBearerTokenConfigBuilder
Creates a new builder-style object to manufacture McpServerBearerTokenConfig.