McpServerOAuth3LoConfig

Struct McpServerOAuth3LoConfig 

#[non_exhaustive]
pub struct McpServerOAuth3LoConfig { pub client_name: Option<String>, pub client_id: String, pub exchange_parameters: Option<HashMap<String, String>>, pub return_to_endpoint: String, pub authorization_url: String, pub exchange_url: String, pub client_secret: Option<String>, pub support_code_challenge: bool, pub scopes: Option<Vec<String>>, }
OAuth 3-legged authorization configuration for MCP server.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
client_name: Option<String>

User friendly OAuth client name specified by end user.

client_id: String

OAuth client ID for authenticating with the service.

exchange_parameters: Option<HashMap<String, String>>

OAuth token exchange parameters for authenticating with the service.

return_to_endpoint: String

The endpoint to return to after OAuth flow completes (must be AWS console domain)

authorization_url: String

OAuth authorization URL for 3LO authentication.

exchange_url: String

OAuth token exchange URL.

client_secret: Option<String>

OAuth client secret for authenticating with the service. Required for confidential clients or when PKCE is not supported. Optional for public clients using PKCE.

support_code_challenge: bool

Whether the service supports PKCE (Proof Key for Code Exchange) for enhanced security during the OAuth flow.

scopes: Option<Vec<String>>

OAuth scopes for 3LO authentication. The service will always request scope offline_access.

Implementations

Source

impl McpServerOAuth3LoConfig

pub fn client_name(&self) -> Option<&str>

User friendly OAuth client name specified by end user.

pub fn client_id(&self) -> &str

OAuth client ID for authenticating with the service.

pub fn exchange_parameters(&self) -> Option<&HashMap<String, String>>

OAuth token exchange parameters for authenticating with the service.

pub fn return_to_endpoint(&self) -> &str

The endpoint to return to after OAuth flow completes (must be AWS console domain)

pub fn authorization_url(&self) -> &str

OAuth authorization URL for 3LO authentication.

pub fn exchange_url(&self) -> &str

OAuth token exchange URL.

pub fn client_secret(&self) -> Option<&str>

OAuth client secret for authenticating with the service. Required for confidential clients or when PKCE is not supported. Optional for public clients using PKCE.

pub fn support_code_challenge(&self) -> bool

Whether the service supports PKCE (Proof Key for Code Exchange) for enhanced security during the OAuth flow.

pub fn scopes(&self) -> &[String]

OAuth scopes for 3LO authentication. The service will always request scope offline_access.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .scopes.is_none().

Source

impl McpServerOAuth3LoConfig

pub fn builder() -> McpServerOAuth3LoConfigBuilder

Creates a new builder-style object to manufacture McpServerOAuth3LoConfig.