#[non_exhaustive]pub struct McpServerOAuthClientCredentialsConfig {
pub client_name: Option<String>,
pub client_id: String,
pub exchange_parameters: Option<HashMap<String, String>>,
pub client_secret: String,
pub exchange_url: String,
pub scopes: Option<Vec<String>>,
}Expand description
OAuth client credentials configuration for MCP server.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_name: Option<String>User friendly OAuth client name specified by end user.
client_id: StringOAuth client ID for authenticating with the service.
exchange_parameters: Option<HashMap<String, String>>OAuth token exchange parameters for authenticating with the service.
client_secret: StringOAuth client secret for authenticating with the service.
exchange_url: StringOAuth token exchange URL.
scopes: Option<Vec<String>>OAuth scopes for 3LO authentication. The service will always request scope offline_access.
Implementations
Sourceimpl McpServerOAuthClientCredentialsConfig
impl McpServerOAuthClientCredentialsConfig
Sourcepub fn client_name(&self) -> Option<&str>
pub fn client_name(&self) -> Option<&str>
User friendly OAuth client name specified by end user.
Sourcepub fn exchange_parameters(&self) -> Option<&HashMap<String, String>>
pub fn exchange_parameters(&self) -> Option<&HashMap<String, String>>
OAuth token exchange parameters for authenticating with the service.
Sourcepub fn client_secret(&self) -> &str
pub fn client_secret(&self) -> &str
OAuth client secret for authenticating with the service.
Sourcepub fn exchange_url(&self) -> &str
pub fn exchange_url(&self) -> &str
OAuth token exchange URL.
Sourceimpl McpServerOAuthClientCredentialsConfig
impl McpServerOAuthClientCredentialsConfig
Sourcepub fn builder() -> McpServerOAuthClientCredentialsConfigBuilder
pub fn builder() -> McpServerOAuthClientCredentialsConfigBuilder
Creates a new builder-style object to manufacture McpServerOAuthClientCredentialsConfig.