#[non_exhaustive]pub struct NewRelicApiKeyConfig {
pub api_key: String,
pub account_id: String,
pub region: NewRelicRegion,
pub application_ids: Option<Vec<String>>,
pub entity_guids: Option<Vec<String>>,
pub alert_policy_ids: Option<Vec<String>>,
}Expand description
API key authentication configuration for New Relic service.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.api_key: StringNew Relic User API Key
account_id: StringNew Relic Account ID
region: NewRelicRegionNew Relic region (US or EU)
application_ids: Option<Vec<String>>List of monitored APM application IDs in New Relic
entity_guids: Option<Vec<String>>List of globally unique IDs for New Relic resources (apps, hosts, services)
alert_policy_ids: Option<Vec<String>>List of alert policy IDs grouping related conditions
Implementations
Sourceimpl NewRelicApiKeyConfig
impl NewRelicApiKeyConfig
Sourcepub fn account_id(&self) -> &str
pub fn account_id(&self) -> &str
New Relic Account ID
Sourcepub fn region(&self) -> &NewRelicRegion
pub fn region(&self) -> &NewRelicRegion
New Relic region (US or EU)
Sourcepub fn application_ids(&self) -> &[String]
pub fn application_ids(&self) -> &[String]
List of monitored APM application IDs in New Relic
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .application_ids.is_none().
Sourcepub fn entity_guids(&self) -> &[String]
pub fn entity_guids(&self) -> &[String]
List of globally unique IDs for New Relic resources (apps, hosts, services)
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .entity_guids.is_none().
Sourcepub fn alert_policy_ids(&self) -> &[String]
pub fn alert_policy_ids(&self) -> &[String]
List of alert policy IDs grouping related conditions
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .alert_policy_ids.is_none().
Sourceimpl NewRelicApiKeyConfig
impl NewRelicApiKeyConfig
Sourcepub fn builder() -> NewRelicApiKeyConfigBuilder
pub fn builder() -> NewRelicApiKeyConfigBuilder
Creates a new builder-style object to manufacture NewRelicApiKeyConfig.