#[non_exhaustive]pub struct PrivateConnectionSummary {
pub name: String,
pub type: PrivateConnectionType,
pub resource_gateway_id: Option<String>,
pub host_address: Option<String>,
pub vpc_id: Option<String>,
pub resource_configuration_id: Option<String>,
pub status: PrivateConnectionStatus,
pub certificate_expiry_time: Option<DateTime>,
}Expand description
Summary of a Private Connection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the Private Connection.
type: PrivateConnectionTypeThe type of the Private Connection.
resource_gateway_id: Option<String>The service-managed Resource Gateway ARN. Only present for service-managed Private Connections.
host_address: Option<String>IP address or DNS name of the target resource. Only present for service-managed Private Connections.
vpc_id: Option<String>VPC identifier of the service-managed Resource Gateway. Only present for service-managed Private Connections.
resource_configuration_id: Option<String>The Resource Configuration ARN. Only present for self-managed Private Connections.
status: PrivateConnectionStatusThe status of the Private Connection.
certificate_expiry_time: Option<DateTime>The expiry time of the certificate associated with the Private Connection. Only present when a certificate is associated.
Implementations
Sourceimpl PrivateConnectionSummary
impl PrivateConnectionSummary
Sourcepub fn type(&self) -> &PrivateConnectionType
pub fn type(&self) -> &PrivateConnectionType
The type of the Private Connection.
Sourcepub fn resource_gateway_id(&self) -> Option<&str>
pub fn resource_gateway_id(&self) -> Option<&str>
The service-managed Resource Gateway ARN. Only present for service-managed Private Connections.
Sourcepub fn host_address(&self) -> Option<&str>
pub fn host_address(&self) -> Option<&str>
IP address or DNS name of the target resource. Only present for service-managed Private Connections.
Sourcepub fn vpc_id(&self) -> Option<&str>
pub fn vpc_id(&self) -> Option<&str>
VPC identifier of the service-managed Resource Gateway. Only present for service-managed Private Connections.
Sourcepub fn resource_configuration_id(&self) -> Option<&str>
pub fn resource_configuration_id(&self) -> Option<&str>
The Resource Configuration ARN. Only present for self-managed Private Connections.
Sourcepub fn status(&self) -> &PrivateConnectionStatus
pub fn status(&self) -> &PrivateConnectionStatus
The status of the Private Connection.
Sourcepub fn certificate_expiry_time(&self) -> Option<&DateTime>
pub fn certificate_expiry_time(&self) -> Option<&DateTime>
The expiry time of the certificate associated with the Private Connection. Only present when a certificate is associated.
Sourceimpl PrivateConnectionSummary
impl PrivateConnectionSummary
Sourcepub fn builder() -> PrivateConnectionSummaryBuilder
pub fn builder() -> PrivateConnectionSummaryBuilder
Creates a new builder-style object to manufacture PrivateConnectionSummary.