#[non_exhaustive]pub struct Recommendation {Show 13 fields
pub agent_space_arn: String,
pub recommendation_id: String,
pub task_id: String,
pub goal_id: Option<String>,
pub title: String,
pub content: Option<RecommendationContent>,
pub status: RecommendationStatus,
pub priority: RecommendationPriority,
pub goal_version: Option<i64>,
pub additional_context: Option<String>,
pub created_at: DateTime,
pub updated_at: DateTime,
pub version: i64,
}Expand description
Represents a recommendation with all its properties and metadata
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_arn: StringARN of the agent space this recommendation belongs to
recommendation_id: StringThe unique identifier for this recommendation
task_id: StringID of the task that generated the recommendation
goal_id: Option<String>ID of the goal this recommendation is associated with
title: StringThe title of the recommendation
content: Option<RecommendationContent>Content of the recommendation
status: RecommendationStatusCurrent status of the recommendation
priority: RecommendationPriorityPriority level of the recommendation
goal_version: Option<i64>Version of the goal at the time this recommendation was generated
additional_context: Option<String>Additional context for recommendation
created_at: DateTimeTimestamp when this recommendation was created
updated_at: DateTimeTimestamp when this recommendation was last updated
version: i64Version number for optimistic locking
Implementations
Sourceimpl Recommendation
impl Recommendation
Sourcepub fn agent_space_arn(&self) -> &str
pub fn agent_space_arn(&self) -> &str
ARN of the agent space this recommendation belongs to
Sourcepub fn recommendation_id(&self) -> &str
pub fn recommendation_id(&self) -> &str
The unique identifier for this recommendation
Sourcepub fn content(&self) -> Option<&RecommendationContent>
pub fn content(&self) -> Option<&RecommendationContent>
Content of the recommendation
Sourcepub fn status(&self) -> &RecommendationStatus
pub fn status(&self) -> &RecommendationStatus
Current status of the recommendation
Sourcepub fn priority(&self) -> &RecommendationPriority
pub fn priority(&self) -> &RecommendationPriority
Priority level of the recommendation
Sourcepub fn goal_version(&self) -> Option<i64>
pub fn goal_version(&self) -> Option<i64>
Version of the goal at the time this recommendation was generated
Sourcepub fn additional_context(&self) -> Option<&str>
pub fn additional_context(&self) -> Option<&str>
Additional context for recommendation
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
Timestamp when this recommendation was created
Sourcepub fn updated_at(&self) -> &DateTime
pub fn updated_at(&self) -> &DateTime
Timestamp when this recommendation was last updated
Sourceimpl Recommendation
impl Recommendation
Sourcepub fn builder() -> RecommendationBuilder
pub fn builder() -> RecommendationBuilder
Creates a new builder-style object to manufacture Recommendation.