#[non_exhaustive]pub struct ReferenceInput {
pub system: String,
pub title: Option<String>,
pub reference_id: String,
pub reference_url: String,
pub association_id: String,
}Expand description
Reference information linking a task to external systems - for input with validation
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.system: StringThe name of the external system
title: Option<String>Optional title for the reference
reference_id: StringThe unique identifier in the external system
reference_url: StringURL to access the reference in the external system
association_id: StringAssociation identifier of the external system
Implementations
Sourceimpl ReferenceInput
impl ReferenceInput
Sourcepub fn reference_id(&self) -> &str
pub fn reference_id(&self) -> &str
The unique identifier in the external system
Sourcepub fn reference_url(&self) -> &str
pub fn reference_url(&self) -> &str
URL to access the reference in the external system
Sourcepub fn association_id(&self) -> &str
pub fn association_id(&self) -> &str
Association identifier of the external system
Sourceimpl ReferenceInput
impl ReferenceInput
Sourcepub fn builder() -> ReferenceInputBuilder
pub fn builder() -> ReferenceInputBuilder
Creates a new builder-style object to manufacture ReferenceInput.