#[non_exhaustive]pub struct RegisteredService {
pub service_id: String,
pub service_type: Service,
pub name: Option<String>,
pub accessible_resources: Option<Vec<Document>>,
pub additional_service_details: Option<AdditionalServiceDetails>,
pub kms_key_arn: Option<String>,
pub private_connection_name: Option<String>,
}Expand description
Represents a registered service with its configuration and accessible resources.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service_id: StringThe unique identifier of a service.
service_type: ServiceThe service type e.g github or dynatrace
name: Option<String>The display name of the registered service.
accessible_resources: Option<Vec<Document>>List of accessible resources for this service.
additional_service_details: Option<AdditionalServiceDetails>Additional details specific to the service type.
kms_key_arn: Option<String>The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
private_connection_name: Option<String>The name of the private connection used for VPC connectivity.
Implementations
Sourceimpl RegisteredService
impl RegisteredService
Sourcepub fn service_id(&self) -> &str
pub fn service_id(&self) -> &str
The unique identifier of a service.
Sourcepub fn service_type(&self) -> &Service
pub fn service_type(&self) -> &Service
The service type e.g github or dynatrace
Sourcepub fn accessible_resources(&self) -> &[Document]
pub fn accessible_resources(&self) -> &[Document]
List of accessible resources for this service.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .accessible_resources.is_none().
Sourcepub fn additional_service_details(&self) -> Option<&AdditionalServiceDetails>
pub fn additional_service_details(&self) -> Option<&AdditionalServiceDetails>
Additional details specific to the service type.
Sourcepub fn kms_key_arn(&self) -> Option<&str>
pub fn kms_key_arn(&self) -> Option<&str>
The ARN of the AWS Key Management Service (AWS KMS) customer managed key that’s used to encrypt resources.
Sourcepub fn private_connection_name(&self) -> Option<&str>
pub fn private_connection_name(&self) -> Option<&str>
The name of the private connection used for VPC connectivity.
Sourceimpl RegisteredService
impl RegisteredService
Sourcepub fn builder() -> RegisteredServiceBuilder
pub fn builder() -> RegisteredServiceBuilder
Creates a new builder-style object to manufacture RegisteredService.