#[non_exhaustive]pub struct ServiceManagedInput {
pub host_address: String,
pub vpc_id: String,
pub subnet_ids: Vec<String>,
pub security_group_ids: Option<Vec<String>>,
pub ip_address_type: Option<IpAddressType>,
pub ipv4_addresses_per_eni: Option<i32>,
pub port_ranges: Option<Vec<String>>,
pub certificate: Option<String>,
}Expand description
Configuration for a service-managed Private Connection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.host_address: StringIP address or DNS name of the target resource.
vpc_id: StringVPC to create the service-managed Resource Gateway in.
subnet_ids: Vec<String>Subnets that the service-managed Resource Gateway will span.
security_group_ids: Option<Vec<String>>Security groups to attach to the service-managed Resource Gateway. If not specified, a default security group is created.
ip_address_type: Option<IpAddressType>IP address type of the service-managed Resource Gateway.
ipv4_addresses_per_eni: Option<i32>Number of IPv4 addresses in each ENI for the service-managed Resource Gateway.
port_ranges: Option<Vec<String>>TCP port ranges that a consumer can use to access the resource.
certificate: Option<String>Certificate for the Private Connection.
Implementations
Sourceimpl ServiceManagedInput
impl ServiceManagedInput
Sourcepub fn host_address(&self) -> &str
pub fn host_address(&self) -> &str
IP address or DNS name of the target resource.
Sourcepub fn subnet_ids(&self) -> &[String]
pub fn subnet_ids(&self) -> &[String]
Subnets that the service-managed Resource Gateway will span.
Sourcepub fn security_group_ids(&self) -> &[String]
pub fn security_group_ids(&self) -> &[String]
Security groups to attach to the service-managed Resource Gateway. If not specified, a default security group is created.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .security_group_ids.is_none().
Sourcepub fn ip_address_type(&self) -> Option<&IpAddressType>
pub fn ip_address_type(&self) -> Option<&IpAddressType>
IP address type of the service-managed Resource Gateway.
Sourcepub fn ipv4_addresses_per_eni(&self) -> Option<i32>
pub fn ipv4_addresses_per_eni(&self) -> Option<i32>
Number of IPv4 addresses in each ENI for the service-managed Resource Gateway.
Sourcepub fn port_ranges(&self) -> &[String]
pub fn port_ranges(&self) -> &[String]
TCP port ranges that a consumer can use to access the resource.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .port_ranges.is_none().
Sourcepub fn certificate(&self) -> Option<&str>
pub fn certificate(&self) -> Option<&str>
Certificate for the Private Connection.
Sourceimpl ServiceManagedInput
impl ServiceManagedInput
Sourcepub fn builder() -> ServiceManagedInputBuilder
pub fn builder() -> ServiceManagedInputBuilder
Creates a new builder-style object to manufacture ServiceManagedInput.