#[non_exhaustive]pub struct ServiceNowOAuthClientCredentialsConfig {
pub client_name: Option<String>,
pub client_id: String,
pub exchange_parameters: Option<HashMap<String, String>>,
pub client_secret: String,
}Expand description
OAuth client credentials configuration for ServiceNow.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_name: Option<String>User friendly OAuth client name specified by end user.
client_id: StringOAuth client ID for authenticating with the service.
exchange_parameters: Option<HashMap<String, String>>OAuth token exchange parameters for authenticating with the service.
client_secret: StringOAuth client secret for authenticating with the service.
Implementations
Sourceimpl ServiceNowOAuthClientCredentialsConfig
impl ServiceNowOAuthClientCredentialsConfig
Sourcepub fn client_name(&self) -> Option<&str>
pub fn client_name(&self) -> Option<&str>
User friendly OAuth client name specified by end user.
Sourcepub fn exchange_parameters(&self) -> Option<&HashMap<String, String>>
pub fn exchange_parameters(&self) -> Option<&HashMap<String, String>>
OAuth token exchange parameters for authenticating with the service.
Sourcepub fn client_secret(&self) -> &str
pub fn client_secret(&self) -> &str
OAuth client secret for authenticating with the service.
Sourceimpl ServiceNowOAuthClientCredentialsConfig
impl ServiceNowOAuthClientCredentialsConfig
Sourcepub fn builder() -> ServiceNowOAuthClientCredentialsConfigBuilder
pub fn builder() -> ServiceNowOAuthClientCredentialsConfigBuilder
Creates a new builder-style object to manufacture ServiceNowOAuthClientCredentialsConfig.