#[non_exhaustive]pub struct SlackBidirectionalConfiguration {
pub role_arn: String,
pub enabled: Option<bool>,
}Expand description
Configuration for bidirectional Slack communication.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.role_arn: StringIAM role ARN that AWS DevOps Agent assumes to exchange messages with your Slack workspace on behalf of this association.
enabled: Option<bool>Whether bidirectional communication is enabled for this association. When you set this value to true, you can mention the agent in a configured Slack channel and it responds in that channel. When you omit this value or set it to false, the agent ignores mentions and only sends notifications.
Implementations
Sourceimpl SlackBidirectionalConfiguration
impl SlackBidirectionalConfiguration
Sourcepub fn role_arn(&self) -> &str
pub fn role_arn(&self) -> &str
IAM role ARN that AWS DevOps Agent assumes to exchange messages with your Slack workspace on behalf of this association.
Sourcepub fn enabled(&self) -> Option<bool>
pub fn enabled(&self) -> Option<bool>
Whether bidirectional communication is enabled for this association. When you set this value to true, you can mention the agent in a configured Slack channel and it responds in that channel. When you omit this value or set it to false, the agent ignores mentions and only sends notifications.
Sourceimpl SlackBidirectionalConfiguration
impl SlackBidirectionalConfiguration
Sourcepub fn builder() -> SlackBidirectionalConfigurationBuilder
pub fn builder() -> SlackBidirectionalConfigurationBuilder
Creates a new builder-style object to manufacture SlackBidirectionalConfiguration.