Types for the AssociateService operation.
Modules
- builders
- Builders
Structs
- Associate
Service - Orchestration and serialization glue logic for
AssociateService. - Associate
Service Input - Input for creating a new service association within an AgentSpace.
- Associate
Service Output - Output containing the newly created association and optional webhook configuration.
Enums
- Associate
Service Error - Error type for the
AssociateServiceErroroperation.