#[non_exhaustive]pub struct RecommendationBuilder { /* private fields */ }Expand description
A builder for Recommendation.
Implementations
Sourceimpl RecommendationBuilder
impl RecommendationBuilder
Sourcepub fn agent_space_arn(self, input: impl Into<String>) -> Self
pub fn agent_space_arn(self, input: impl Into<String>) -> Self
ARN of the agent space this recommendation belongs to This field is required.
Sourcepub fn set_agent_space_arn(self, input: Option<String>) -> Self
pub fn set_agent_space_arn(self, input: Option<String>) -> Self
ARN of the agent space this recommendation belongs to
Sourcepub fn get_agent_space_arn(&self) -> &Option<String>
pub fn get_agent_space_arn(&self) -> &Option<String>
ARN of the agent space this recommendation belongs to
Sourcepub fn recommendation_id(self, input: impl Into<String>) -> Self
pub fn recommendation_id(self, input: impl Into<String>) -> Self
The unique identifier for this recommendation This field is required.
Sourcepub fn set_recommendation_id(self, input: Option<String>) -> Self
pub fn set_recommendation_id(self, input: Option<String>) -> Self
The unique identifier for this recommendation
Sourcepub fn get_recommendation_id(&self) -> &Option<String>
pub fn get_recommendation_id(&self) -> &Option<String>
The unique identifier for this recommendation
Sourcepub fn task_id(self, input: impl Into<String>) -> Self
pub fn task_id(self, input: impl Into<String>) -> Self
ID of the task that generated the recommendation This field is required.
Sourcepub fn set_task_id(self, input: Option<String>) -> Self
pub fn set_task_id(self, input: Option<String>) -> Self
ID of the task that generated the recommendation
Sourcepub fn get_task_id(&self) -> &Option<String>
pub fn get_task_id(&self) -> &Option<String>
ID of the task that generated the recommendation
Sourcepub fn goal_id(self, input: impl Into<String>) -> Self
pub fn goal_id(self, input: impl Into<String>) -> Self
ID of the goal this recommendation is associated with
Sourcepub fn set_goal_id(self, input: Option<String>) -> Self
pub fn set_goal_id(self, input: Option<String>) -> Self
ID of the goal this recommendation is associated with
Sourcepub fn get_goal_id(&self) -> &Option<String>
pub fn get_goal_id(&self) -> &Option<String>
ID of the goal this recommendation is associated with
Sourcepub fn title(self, input: impl Into<String>) -> Self
pub fn title(self, input: impl Into<String>) -> Self
The title of the recommendation This field is required.
Sourcepub fn content(self, input: RecommendationContent) -> Self
pub fn content(self, input: RecommendationContent) -> Self
Content of the recommendation This field is required.
Sourcepub fn set_content(self, input: Option<RecommendationContent>) -> Self
pub fn set_content(self, input: Option<RecommendationContent>) -> Self
Content of the recommendation
Sourcepub fn get_content(&self) -> &Option<RecommendationContent>
pub fn get_content(&self) -> &Option<RecommendationContent>
Content of the recommendation
Sourcepub fn status(self, input: RecommendationStatus) -> Self
pub fn status(self, input: RecommendationStatus) -> Self
Current status of the recommendation This field is required.
Sourcepub fn set_status(self, input: Option<RecommendationStatus>) -> Self
pub fn set_status(self, input: Option<RecommendationStatus>) -> Self
Current status of the recommendation
Sourcepub fn get_status(&self) -> &Option<RecommendationStatus>
pub fn get_status(&self) -> &Option<RecommendationStatus>
Current status of the recommendation
Sourcepub fn priority(self, input: RecommendationPriority) -> Self
pub fn priority(self, input: RecommendationPriority) -> Self
Priority level of the recommendation This field is required.
Sourcepub fn set_priority(self, input: Option<RecommendationPriority>) -> Self
pub fn set_priority(self, input: Option<RecommendationPriority>) -> Self
Priority level of the recommendation
Sourcepub fn get_priority(&self) -> &Option<RecommendationPriority>
pub fn get_priority(&self) -> &Option<RecommendationPriority>
Priority level of the recommendation
Sourcepub fn goal_version(self, input: i64) -> Self
pub fn goal_version(self, input: i64) -> Self
Version of the goal at the time this recommendation was generated
Sourcepub fn set_goal_version(self, input: Option<i64>) -> Self
pub fn set_goal_version(self, input: Option<i64>) -> Self
Version of the goal at the time this recommendation was generated
Sourcepub fn get_goal_version(&self) -> &Option<i64>
pub fn get_goal_version(&self) -> &Option<i64>
Version of the goal at the time this recommendation was generated
Sourcepub fn additional_context(self, input: impl Into<String>) -> Self
pub fn additional_context(self, input: impl Into<String>) -> Self
Additional context for recommendation
Sourcepub fn set_additional_context(self, input: Option<String>) -> Self
pub fn set_additional_context(self, input: Option<String>) -> Self
Additional context for recommendation
Sourcepub fn get_additional_context(&self) -> &Option<String>
pub fn get_additional_context(&self) -> &Option<String>
Additional context for recommendation
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
Timestamp when this recommendation was created This field is required.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
Timestamp when this recommendation was created
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
Timestamp when this recommendation was created
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
Timestamp when this recommendation was last updated This field is required.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
Timestamp when this recommendation was last updated
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
Timestamp when this recommendation was last updated
Sourcepub fn version(self, input: i64) -> Self
pub fn version(self, input: i64) -> Self
Version number for optimistic locking This field is required.
Sourcepub fn set_version(self, input: Option<i64>) -> Self
pub fn set_version(self, input: Option<i64>) -> Self
Version number for optimistic locking
Sourcepub fn get_version(&self) -> &Option<i64>
pub fn get_version(&self) -> &Option<i64>
Version number for optimistic locking
Sourcepub fn build(self) -> Result<Recommendation, BuildError>
pub fn build(self) -> Result<Recommendation, BuildError>
Consumes the builder and constructs a Recommendation.
This method will fail if any of the following fields are not set: