#[non_exhaustive]pub struct TaskBuilder { /* private fields */ }Expand description
A builder for Task.
Implementations
Sourceimpl TaskBuilder
impl TaskBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier for the agent space containing this task This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier for the agent space containing this task
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier for the agent space containing this task
Sourcepub fn task_id(self, input: impl Into<String>) -> Self
pub fn task_id(self, input: impl Into<String>) -> Self
The unique identifier for this task This field is required.
Sourcepub fn set_task_id(self, input: Option<String>) -> Self
pub fn set_task_id(self, input: Option<String>) -> Self
The unique identifier for this task
Sourcepub fn get_task_id(&self) -> &Option<String>
pub fn get_task_id(&self) -> &Option<String>
The unique identifier for this task
Sourcepub fn execution_id(self, input: impl Into<String>) -> Self
pub fn execution_id(self, input: impl Into<String>) -> Self
The execution ID associated with this task, if any
Sourcepub fn set_execution_id(self, input: Option<String>) -> Self
pub fn set_execution_id(self, input: Option<String>) -> Self
The execution ID associated with this task, if any
Sourcepub fn get_execution_id(&self) -> &Option<String>
pub fn get_execution_id(&self) -> &Option<String>
The execution ID associated with this task, if any
Sourcepub fn title(self, input: impl Into<String>) -> Self
pub fn title(self, input: impl Into<String>) -> Self
The title of the task This field is required.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
Optional detailed description of the task
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
Optional detailed description of the task
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
Optional detailed description of the task
Sourcepub fn reference(self, input: ReferenceOutput) -> Self
pub fn reference(self, input: ReferenceOutput) -> Self
Optional reference information linking this task to external systems
Sourcepub fn set_reference(self, input: Option<ReferenceOutput>) -> Self
pub fn set_reference(self, input: Option<ReferenceOutput>) -> Self
Optional reference information linking this task to external systems
Sourcepub fn get_reference(&self) -> &Option<ReferenceOutput>
pub fn get_reference(&self) -> &Option<ReferenceOutput>
Optional reference information linking this task to external systems
Sourcepub fn set_task_type(self, input: Option<TaskType>) -> Self
pub fn set_task_type(self, input: Option<TaskType>) -> Self
The type of this task
Sourcepub fn get_task_type(&self) -> &Option<TaskType>
pub fn get_task_type(&self) -> &Option<TaskType>
The type of this task
Sourcepub fn priority(self, input: Priority) -> Self
pub fn priority(self, input: Priority) -> Self
The priority level of this task This field is required.
Sourcepub fn set_priority(self, input: Option<Priority>) -> Self
pub fn set_priority(self, input: Option<Priority>) -> Self
The priority level of this task
Sourcepub fn get_priority(&self) -> &Option<Priority>
pub fn get_priority(&self) -> &Option<Priority>
The priority level of this task
Sourcepub fn status(self, input: TaskStatus) -> Self
pub fn status(self, input: TaskStatus) -> Self
The current status of this task This field is required.
Sourcepub fn set_status(self, input: Option<TaskStatus>) -> Self
pub fn set_status(self, input: Option<TaskStatus>) -> Self
The current status of this task
Sourcepub fn get_status(&self) -> &Option<TaskStatus>
pub fn get_status(&self) -> &Option<TaskStatus>
The current status of this task
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
Timestamp when this task was created This field is required.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
Timestamp when this task was created
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
Timestamp when this task was created
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
Timestamp when this task was last updated This field is required.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
Timestamp when this task was last updated
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
Timestamp when this task was last updated
Sourcepub fn version(self, input: i32) -> Self
pub fn version(self, input: i32) -> Self
Version number for optimistic locking This field is required.
Sourcepub fn set_version(self, input: Option<i32>) -> Self
pub fn set_version(self, input: Option<i32>) -> Self
Version number for optimistic locking
Sourcepub fn get_version(&self) -> &Option<i32>
pub fn get_version(&self) -> &Option<i32>
Version number for optimistic locking
Sourcepub fn support_metadata(self, input: Document) -> Self
pub fn support_metadata(self, input: Document) -> Self
Optional support metadata for the task
Sourcepub fn set_support_metadata(self, input: Option<Document>) -> Self
pub fn set_support_metadata(self, input: Option<Document>) -> Self
Optional support metadata for the task
Sourcepub fn get_support_metadata(&self) -> &Option<Document>
pub fn get_support_metadata(&self) -> &Option<Document>
Optional support metadata for the task
Sourcepub fn set_metadata(self, input: Option<Document>) -> Self
pub fn set_metadata(self, input: Option<Document>) -> Self
Optional metadata for the task
Sourcepub fn get_metadata(&self) -> &Option<Document>
pub fn get_metadata(&self) -> &Option<Document>
Optional metadata for the task
Sourcepub fn primary_task_id(self, input: impl Into<String>) -> Self
pub fn primary_task_id(self, input: impl Into<String>) -> Self
The task ID of the primary investigation this task is linked to
Sourcepub fn set_primary_task_id(self, input: Option<String>) -> Self
pub fn set_primary_task_id(self, input: Option<String>) -> Self
The task ID of the primary investigation this task is linked to
Sourcepub fn get_primary_task_id(&self) -> &Option<String>
pub fn get_primary_task_id(&self) -> &Option<String>
The task ID of the primary investigation this task is linked to
Sourcepub fn status_reason(self, input: impl Into<String>) -> Self
pub fn status_reason(self, input: impl Into<String>) -> Self
Explanation for why the task status was changed (e.g., linked reason)
Sourcepub fn set_status_reason(self, input: Option<String>) -> Self
pub fn set_status_reason(self, input: Option<String>) -> Self
Explanation for why the task status was changed (e.g., linked reason)
Sourcepub fn get_status_reason(&self) -> &Option<String>
pub fn get_status_reason(&self) -> &Option<String>
Explanation for why the task status was changed (e.g., linked reason)
Sourcepub fn has_linked_tasks(self, input: bool) -> Self
pub fn has_linked_tasks(self, input: bool) -> Self
Indicates if this task has other tasks linked to it
Sourcepub fn set_has_linked_tasks(self, input: Option<bool>) -> Self
pub fn set_has_linked_tasks(self, input: Option<bool>) -> Self
Indicates if this task has other tasks linked to it
Sourcepub fn get_has_linked_tasks(&self) -> &Option<bool>
pub fn get_has_linked_tasks(&self) -> &Option<bool>
Indicates if this task has other tasks linked to it