#[non_exhaustive]pub struct McpServerOAuth3LoConfig {
pub client_name: Option<String>,
pub client_id: String,
pub exchange_parameters: Option<HashMap<String, String>>,
pub return_to_endpoint: String,
pub authorization_url: String,
pub exchange_url: String,
pub client_secret: Option<String>,
pub support_code_challenge: bool,
pub scopes: Option<Vec<String>>,
}Expand description
OAuth 3-legged authorization configuration for MCP server.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_name: Option<String>User friendly OAuth client name specified by end user.
client_id: StringOAuth client ID for authenticating with the service.
exchange_parameters: Option<HashMap<String, String>>OAuth token exchange parameters for authenticating with the service.
return_to_endpoint: StringThe endpoint to return to after OAuth flow completes (must be AWS console domain)
OAuth authorization URL for 3LO authentication.
exchange_url: StringOAuth token exchange URL.
client_secret: Option<String>OAuth client secret for authenticating with the service. Required for confidential clients or when PKCE is not supported. Optional for public clients using PKCE.
support_code_challenge: boolWhether the service supports PKCE (Proof Key for Code Exchange) for enhanced security during the OAuth flow.
scopes: Option<Vec<String>>OAuth scopes for 3LO authentication. The service will always request scope offline_access.
Implementations
Sourceimpl McpServerOAuth3LoConfig
impl McpServerOAuth3LoConfig
Sourcepub fn client_name(&self) -> Option<&str>
pub fn client_name(&self) -> Option<&str>
User friendly OAuth client name specified by end user.
Sourcepub fn exchange_parameters(&self) -> Option<&HashMap<String, String>>
pub fn exchange_parameters(&self) -> Option<&HashMap<String, String>>
OAuth token exchange parameters for authenticating with the service.
Sourcepub fn return_to_endpoint(&self) -> &str
pub fn return_to_endpoint(&self) -> &str
The endpoint to return to after OAuth flow completes (must be AWS console domain)
OAuth authorization URL for 3LO authentication.
Sourcepub fn exchange_url(&self) -> &str
pub fn exchange_url(&self) -> &str
OAuth token exchange URL.
Sourcepub fn client_secret(&self) -> Option<&str>
pub fn client_secret(&self) -> Option<&str>
OAuth client secret for authenticating with the service. Required for confidential clients or when PKCE is not supported. Optional for public clients using PKCE.
Sourcepub fn support_code_challenge(&self) -> bool
pub fn support_code_challenge(&self) -> bool
Whether the service supports PKCE (Proof Key for Code Exchange) for enhanced security during the OAuth flow.
Sourceimpl McpServerOAuth3LoConfig
impl McpServerOAuth3LoConfig
Sourcepub fn builder() -> McpServerOAuth3LoConfigBuilder
pub fn builder() -> McpServerOAuth3LoConfigBuilder
Creates a new builder-style object to manufacture McpServerOAuth3LoConfig.